package org.jboss.errai.marshalling.client.api;

import ch.apkern.achilles.api.client.exception.ExceptionElement;
import ch.apkern.achilles.api.client.exception.ServerException;
import ch.apkern.achilles.api.client.exception.ValidationException;
import ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum;
import ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum.Info;
import ch.apkern.achilles.api.shared.validation.ValidationResult;
import ch.apkern.achilles.api.shared.validation.ValidationStateEnum;
import ch.apkern.achilles.apisecurity.client.session.ClientSessionDto;
import ch.apkern.achilles.apisecurity.client.session.ClientSessionUser;
import ch.apkern.achilles.apisecurity.client.session.enumeration.SessionStateEnum;
import ch.apkern.achilles.concurrency.client.internal.model.ClientInstanceId;
import ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer;
import ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer.LockBroadcastEventEntry;
import ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer;
import ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer.EventCase;
import ch.apkern.achilles.concurrency.client.internal.transfer.PersistEventTransfer;
import ch.apkern.achilles.concurrency.client.internal.transfer.SingleFieldEventInformation;
import ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer;
import ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer.ValueBroadcastEventEntry;
import ch.apkern.achilles.dto.shared.entity.address.AddressDto;
import ch.apkern.achilles.dto.shared.entity.address.CityDto;
import ch.apkern.achilles.dto.shared.entity.address.CountryDto;
import ch.apkern.achilles.dto.shared.entity.address.LegalPersonDto;
import ch.apkern.achilles.dto.shared.entity.address.NaturalPersonDto;
import ch.apkern.achilles.dto.shared.entity.address.PersonDto;
import ch.apkern.achilles.dto.shared.entity.address.RegionDto;
import ch.apkern.achilles.dto.shared.entity.base.ValidityDto;
import ch.apkern.achilles.dto.shared.entity.core.CommentDto;
import ch.apkern.achilles.dto.shared.entity.core.GroupDto;
import ch.apkern.achilles.dto.shared.entity.core.GroupItemDto;
import ch.apkern.achilles.dto.shared.entity.core.MandatorDto;
import ch.apkern.achilles.dto.shared.entity.core.MetaFieldDeclarationDto;
import ch.apkern.achilles.dto.shared.entity.core.MetaFieldValueDto;
import ch.apkern.achilles.dto.shared.entity.core.ModificationDto;
import ch.apkern.achilles.dto.shared.entity.core.ParameterSetDto;
import ch.apkern.achilles.dto.shared.entity.core.UserDto;
import ch.apkern.achilles.dto.shared.entity.core.UserGroupDto;
import ch.apkern.achilles.dto.shared.entity.core.ValueFormatDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.AnalysisLibraryDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.BiometricDataLibraryDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.CalculatedResultTypeDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.DiagramDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryDivisionDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryOverrideDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.NumericResultTypeDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.QualabToleranceDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.ResultTypeDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionResultTypeDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SubstanceDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TariffDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TextResultTypeDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupMapDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitOverrideDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.AnalysisMeasuringDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.BiometricDataMeasuringDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.ExternalLaboratoryMeasuringDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.InternalLaboratoryMeasuringDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.MeasuringDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.PatientIdentificationDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.DeviceQualityMeasuringDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ManufacturerResultReferenceDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ReferenceSolutionLotDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.NumericResultDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.ResultDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.SelectionResultDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.TextResultDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.AgeDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.BaseReferenceDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandGroupReferenceDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandLibraryReferenceDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandReferenceDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.ResultReferenceDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.provider.AutomaticDeviceProviderDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.provider.BiometricTypeDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceProviderDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceTypeDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.provider.ManualDeviceProviderDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.provider.MeasurandGroupDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.provider.ProviderDto;
import ch.apkern.achilles.dto.shared.entity.laboratory.provider.masterdata.ExternalProviderDto;
import ch.apkern.achilles.dto.shared.entity.patient.PatientDto;
import ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceDto;
import ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceGroupItemDto;
import ch.apkern.achilles.dto.shared.entity.patient.TreatmentDto;
import ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.LibraryTypeEnum;
import ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.ResultTypeEnum;
import ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.detail.reference.list.MeasurandReferenceCommunicationDto;
import ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.list.LibraryListDto;
import ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.reference.ReferenceRangeDetailSelectionValueDto;
import ch.apkern.achilles.dto.shared.module.core.preferences.user.UserManagementDto;
import ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDto;
import ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDtoList;
import ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDto;
import ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDtoList;
import ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDto;
import ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDtoList;
import ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDisplayDtoList;
import ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDtoList;
import ch.apkern.achilles.dto.shared.module.laboratory.MeasuringTypeEnum;
import ch.apkern.achilles.dto.shared.module.laboratory.ReferenceArrowEnum;
import ch.apkern.achilles.dto.shared.module.laboratory.SimpleDateFilterCriteriaDto;
import ch.apkern.achilles.dto.shared.module.laboratory.devices.instruments.DevicesInstrumentsDto;
import ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxDto;
import ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDetailDto;
import ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDto;
import ch.apkern.achilles.dto.shared.module.laboratory.inbox.detail.InboxDetailDto;
import ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDto;
import ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDtoList;
import ch.apkern.achilles.dto.shared.module.laboratory.library.LibrarySearchDto;
import ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDto;
import ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDtoList;
import ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuring2Dto;
import ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuringDtoList;
import ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryMeasuringDisplayDto;
import ch.apkern.achilles.dto.shared.module.laboratory.quality.ManufacturerResultReferenceViewDto;
import ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringDateFilterTypeEnum;
import ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalReferenceValuesDto;
import ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalValuesDto;
import ch.apkern.achilles.dto.shared.module.laboratory.quality.ReferenceSolutionLotDtoList;
import ch.apkern.achilles.dto.shared.module.patient.PatientDetailDto;
import ch.apkern.achilles.dto.shared.module.patient.PatientPersonDto;
import ch.apkern.achilles.dto.shared.module.patient.PersonAddressDto;
import ch.apkern.achilles.dto.shared.module.patient.SuggestionDtoList;
import ch.apkern.achilles.dto.shared.module.search.SearchCriteriaDto;
import ch.apkern.achilles.dto.shared.module.search.SearchParameter;
import ch.apkern.achilles.dto.shared.module.search.criteria.LaboratorySearchCriterionEnum;
import ch.apkern.achilles.dto.shared.module.search.criteria.MeasurandLibrarySearchCriterionEnum;
import ch.apkern.achilles.dto.shared.module.search.criteria.SearchCriterionEnum;
import ch.apkern.achilles.i18n.client.TranslatableEnum;
import ch.apkern.achilles.model.shared.entity.analysis.result.reference.AgeUnitEnum;
import ch.apkern.achilles.model.shared.entity.core.GroupTypeEnum;
import ch.apkern.achilles.model.shared.entity.core.LanguageEnum;
import ch.apkern.achilles.model.shared.entity.core.MetaFieldTypeEnum;
import ch.apkern.achilles.model.shared.entity.core.ParameterSetTypeEnum;
import ch.apkern.achilles.model.shared.entity.core.SexEnum;
import ch.apkern.achilles.model.shared.entity.laboratory.LaboratoryTypeEnum;
import ch.apkern.achilles.model.shared.entity.patient.PersonReferenceTypeEnum;
import java.io.IOException;
import java.util.AbstractMap;
import java.util.ConcurrentModificationException;
import java.util.EmptyStackException;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.SortedMap;
import java.util.TreeMap;
import javax.enterprise.context.Dependent;
import org.jboss.errai.bus.client.api.base.MessageDeliveryFailure;
import org.jboss.errai.bus.client.api.base.TransportIOException;
import org.jboss.errai.enterprise.client.cdi.events.BusReadyEvent;
import org.jboss.errai.marshalling.client.api.json.EJArray;
import org.jboss.errai.marshalling.client.api.json.EJObject;
import org.jboss.errai.marshalling.client.api.json.EJValue;
import org.jboss.errai.marshalling.client.marshallers.BigDecimalMarshaller;
import org.jboss.errai.marshalling.client.marshallers.BigIntegerMarshaller;
import org.jboss.errai.marshalling.client.marshallers.BooleanMarshaller;
import org.jboss.errai.marshalling.client.marshallers.ByteMarshaller;
import org.jboss.errai.marshalling.client.marshallers.CharacterMarshaller;
import org.jboss.errai.marshalling.client.marshallers.DateMarshaller;
import org.jboss.errai.marshalling.client.marshallers.DoubleMarshaller;
import org.jboss.errai.marshalling.client.marshallers.FloatMarshaller;
import org.jboss.errai.marshalling.client.marshallers.IntegerMarshaller;
import org.jboss.errai.marshalling.client.marshallers.LinkedHashSetMarshaller;
import org.jboss.errai.marshalling.client.marshallers.LinkedListMarshaller;
import org.jboss.errai.marshalling.client.marshallers.LinkedMapMarshaller;
import org.jboss.errai.marshalling.client.marshallers.ListMarshaller;
import org.jboss.errai.marshalling.client.marshallers.LongMarshaller;
import org.jboss.errai.marshalling.client.marshallers.MapMarshaller;
import org.jboss.errai.marshalling.client.marshallers.ObjectMarshaller;
import org.jboss.errai.marshalling.client.marshallers.PriorityQueueMarshaller;
import org.jboss.errai.marshalling.client.marshallers.QualifyingMarshallerWrapper;
import org.jboss.errai.marshalling.client.marshallers.QueueMarshaller;
import org.jboss.errai.marshalling.client.marshallers.SQLDateMarshaller;
import org.jboss.errai.marshalling.client.marshallers.SetMarshaller;
import org.jboss.errai.marshalling.client.marshallers.ShortMarshaller;
import org.jboss.errai.marshalling.client.marshallers.SortedMapMarshaller;
import org.jboss.errai.marshalling.client.marshallers.SortedSetMarshaller;
import org.jboss.errai.marshalling.client.marshallers.StringBufferMarshaller;
import org.jboss.errai.marshalling.client.marshallers.StringBuilderMarshaller;
import org.jboss.errai.marshalling.client.marshallers.StringMarshaller;
import org.jboss.errai.marshalling.client.marshallers.TimeMarshaller;
import org.jboss.errai.marshalling.client.marshallers.TimestampMarshaller;
@Dependent public class MarshallerFactoryImpl implements MarshallerFactory {
  private Map<String, Marshaller> marshallers = new HashMap<String, Marshaller>();
  private FloatMarshaller java_lang_Float;
  private LinkedListMarshaller java_util_LinkedList;
  private LongMarshaller java_lang_Long;
  private ShortMarshaller java_lang_Short;
  private QualifyingMarshallerWrapper<LinkedHashMap> java_util_LinkedHashMap;
  private QualifyingMarshallerWrapper<Map> java_util_Map;
  private IntegerMarshaller java_lang_Integer;
  private TimestampMarshaller java_sql_Timestamp;
  private TimeMarshaller java_sql_Time;
  private BigIntegerMarshaller java_math_BigInteger;
  private ListMarshaller java_util_Vector;
  private SortedSetMarshaller java_util_SortedSet;
  private QualifyingMarshallerWrapper<AbstractMap> java_util_AbstractMap;
  private StringBuilderMarshaller java_lang_StringBuilder;
  private BooleanMarshaller java_lang_Boolean;
  private StringMarshaller java_lang_String;
  private QualifyingMarshallerWrapper<HashMap> java_util_HashMap;
  private ByteMarshaller java_lang_Byte;
  private SetMarshaller java_util_HashSet;
  private QueueMarshaller java_util_Queue;
  private ObjectMarshaller java_lang_Object;
  private QualifyingMarshallerWrapper<SortedMap> java_util_SortedMap;
  private SQLDateMarshaller java_sql_Date;
  private SetMarshaller java_util_AbstractSet;
  private ListMarshaller java_util_Stack;
  private DateMarshaller java_util_Date;
  private LinkedHashSetMarshaller java_util_LinkedHashSet;
  private CharacterMarshaller java_lang_Character;
  private PriorityQueueMarshaller java_util_PriorityQueue;
  private ListMarshaller java_util_List;
  private QueueMarshaller java_util_AbstractQueue;
  private DoubleMarshaller java_lang_Double;
  private SortedSetMarshaller java_util_TreeSet;
  private BigDecimalMarshaller java_math_BigDecimal;
  private StringBufferMarshaller java_lang_StringBuffer;
  private QualifyingMarshallerWrapper<TreeMap> java_util_TreeMap;
  private ListMarshaller java_util_AbstractList;
  private SetMarshaller java_util_Set;
  private ListMarshaller java_util_ArrayList;
  private Marshaller<SubstanceDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SubstanceDto;
  private Marshaller<GroupDto> ch_apkern_achilles_dto_shared_entity_core_GroupDto;
  private Marshaller<GroupItemDto> ch_apkern_achilles_dto_shared_entity_core_GroupItemDto;
  private Marshaller<DiagramDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto;
  private Marshaller<LibraryDivisionDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto;
  private Marshaller<UserGroupDto> ch_apkern_achilles_dto_shared_entity_core_UserGroupDto;
  private Marshaller<UserDto> ch_apkern_achilles_dto_shared_entity_core_UserDto;
  private Marshaller<ModificationDto> ch_apkern_achilles_dto_shared_entity_core_ModificationDto;
  private Marshaller<ResultTypeDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_ResultTypeDto;
  private Marshaller<AnalysisLibraryDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_AnalysisLibraryDto;
  private Marshaller<QualabToleranceDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_QualabToleranceDto;
  private QualifyingMarshallerWrapper<StackTraceElement[]> arrayOf_java_lang_StackTraceElement_D1;
  private Marshaller<Throwable> java_lang_Throwable;
  private Marshaller<IllegalArgumentException> java_lang_IllegalArgumentException;
  private Marshaller<UnsupportedOperationException> java_lang_UnsupportedOperationException;
  private Marshaller<CountryDto> ch_apkern_achilles_dto_shared_entity_address_CountryDto;
  private Marshaller<RegionDto> ch_apkern_achilles_dto_shared_entity_address_RegionDto;
  private Marshaller<CityDto> ch_apkern_achilles_dto_shared_entity_address_CityDto;
  private Marshaller<AddressDto> ch_apkern_achilles_dto_shared_entity_address_AddressDto;
  private Marshaller<NaturalPersonDto> ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto;
  private Marshaller<PatientDto> ch_apkern_achilles_dto_shared_entity_patient_PatientDto;
  private Marshaller<PatientIdentificationDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto;
  private Marshaller<ProviderDto> ch_apkern_achilles_dto_shared_entity_laboratory_provider_ProviderDto;
  private Marshaller<MandatorDto> ch_apkern_achilles_dto_shared_entity_core_MandatorDto;
  private Marshaller<InboxDto> ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxDto;
  private Marshaller<MeasurandGroupDto> ch_apkern_achilles_dto_shared_entity_laboratory_provider_MeasurandGroupDto;
  private Marshaller<IOException> java_io_IOException;
  private Marshaller<MeasuringTypeEnum> ch_apkern_achilles_dto_shared_module_laboratory_MeasuringTypeEnum;
  private Marshaller<TreatmentDto> ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto;
  private Marshaller<AnalysisMeasuringDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_AnalysisMeasuringDto;
  private Marshaller<UnitGroupDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitGroupDto;
  private Marshaller<UnitDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto;
  private Marshaller<MeasurandLibraryDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_MeasurandLibraryDto;
  private Marshaller<UnitGroupMapDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitGroupMapDto;
  private Marshaller<LaboratoryTypeEnum> ch_apkern_achilles_model_shared_entity_laboratory_LaboratoryTypeEnum;
  private Marshaller<SelectionDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto;
  private Marshaller<MeasuringDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_MeasuringDto;
  private Marshaller<SelectionValueDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionValueDto;
  private Marshaller<ReferenceRangeDetailSelectionValueDto> ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_reference_ReferenceRangeDetailSelectionValueDto;
  private Marshaller<ParameterSetDto> ch_apkern_achilles_dto_shared_entity_core_ParameterSetDto;
  private Marshaller<MetaFieldDeclarationDto> ch_apkern_achilles_dto_shared_entity_core_MetaFieldDeclarationDto;
  private Marshaller<MetaFieldValueDto> ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto;
  private Marshaller<SuggestionDtoList> ch_apkern_achilles_dto_shared_module_patient_SuggestionDtoList;
  private Marshaller<ValidationException> ch_apkern_achilles_api_client_exception_ValidationException;
  private Marshaller<Info> ch_apkern_achilles_api_shared_validation_ExceptionTypeEnum$Info;
  private Marshaller<StringIndexOutOfBoundsException> java_lang_StringIndexOutOfBoundsException;
  private Marshaller<EmptyStackException> java_util_EmptyStackException;
  private Marshaller<AgeUnitEnum> ch_apkern_achilles_model_shared_entity_analysis_result_reference_AgeUnitEnum;
  private Marshaller<LockBroadcastEventTransfer> ch_apkern_achilles_concurrency_client_internal_transfer_LockBroadcastEventTransfer;
  private Marshaller<MeasurandReferenceDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_MeasurandReferenceDto;
  private Marshaller<ResultDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_ResultDto;
  private Marshaller<DetailResultDto> ch_apkern_achilles_dto_shared_module_laboratory_DetailResultDto;
  private Marshaller<NullPointerException> java_lang_NullPointerException;
  private Marshaller<DeviceTypeDto> ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceTypeDto;
  private Marshaller<LaboratoryDeviceProviderDto> ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryDeviceProviderDto;
  private Marshaller<MeasuringStatisticalReferenceValuesDto> ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto;
  private Marshaller<MeasuringStatisticalValuesDto> ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalValuesDto;
  private Marshaller<TransportIOException> org_jboss_errai_bus_client_api_base_TransportIOException;
  private Marshaller<LaboratoryDeviceQualityMeasuringDtoList> ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryDeviceQualityMeasuringDtoList;
  private Marshaller<AgeDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_AgeDto;
  private Marshaller<BaseReferenceDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_BaseReferenceDto;
  private Marshaller<ValidationResult> ch_apkern_achilles_api_shared_validation_ValidationResult;
  private Marshaller<ReferenceArrowEnum> ch_apkern_achilles_dto_shared_module_laboratory_ReferenceArrowEnum;
  private Marshaller<UserManagementDto> ch_apkern_achilles_dto_shared_module_core_preferences_user_UserManagementDto;
  private Marshaller<SearchCriteriaDto> ch_apkern_achilles_dto_shared_module_search_SearchCriteriaDto;
  private Marshaller<LibraryTypeEnum> ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_LibraryTypeEnum;
  private Marshaller<MessageDeliveryFailure> org_jboss_errai_bus_client_api_base_MessageDeliveryFailure;
  private Marshaller<MeasurandReferenceCommunicationDto> ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_detail_reference_list_MeasurandReferenceCommunicationDto;
  private Marshaller<ClientInstanceId> ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId;
  private Marshaller<LockEventTransfer> ch_apkern_achilles_concurrency_client_internal_transfer_LockEventTransfer;
  private Marshaller<PersonDto> ch_apkern_achilles_dto_shared_entity_address_PersonDto;
  private Marshaller<BiometricDataMeasuringDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_BiometricDataMeasuringDto;
  private Marshaller<LaboratoryDeviceProviderDtoList> ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryDeviceProviderDtoList;
  private Marshaller<SexEnum> ch_apkern_achilles_model_shared_entity_core_SexEnum;
  private Marshaller<ClientSessionUser> ch_apkern_achilles_apisecurity_client_session_ClientSessionUser;
  private Marshaller<ClientSessionDto> ch_apkern_achilles_apisecurity_client_session_ClientSessionDto;
  private Marshaller<ValidityDto> ch_apkern_achilles_dto_shared_entity_base_ValidityDto;
  private Marshaller<ExceptionElement> ch_apkern_achilles_api_client_exception_ExceptionElement;
  private Marshaller<CommentDto> ch_apkern_achilles_dto_shared_entity_core_CommentDto;
  private Marshaller<SessionStateEnum> ch_apkern_achilles_apisecurity_client_session_enumeration_SessionStateEnum;
  private Marshaller<InboxListDetailDto> ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxListDetailDto;
  private Marshaller<PersonReferenceTypeEnum> ch_apkern_achilles_model_shared_entity_patient_PersonReferenceTypeEnum;
  private Marshaller<InboxListDto> ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxListDto;
  private Marshaller<AutomaticDeviceProviderDto> ch_apkern_achilles_dto_shared_entity_laboratory_provider_AutomaticDeviceProviderDto;
  private Marshaller<InboxDetailDto> ch_apkern_achilles_dto_shared_module_laboratory_inbox_detail_InboxDetailDto;
  private Marshaller<ValueBroadcastEventEntry> ch_apkern_achilles_concurrency_client_internal_transfer_ValueBroadcastEventTransfer$ValueBroadcastEventEntry;
  private Marshaller<ManufacturerResultReferenceViewDto> ch_apkern_achilles_dto_shared_module_laboratory_quality_ManufacturerResultReferenceViewDto;
  private Marshaller<BusReadyEvent> org_jboss_errai_enterprise_client_cdi_events_BusReadyEvent;
  private Marshaller<BiometricDataLibraryDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_BiometricDataLibraryDto;
  private Marshaller<TextResultTypeDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_TextResultTypeDto;
  private Marshaller<MeasuringDtoList> ch_apkern_achilles_dto_shared_module_laboratory_MeasuringDtoList;
  private Marshaller<MeasuringDateFilterTypeEnum> ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringDateFilterTypeEnum;
  private Marshaller<ValueFormatDto> ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto;
  private Marshaller<NumericResultTypeDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_NumericResultTypeDto;
  private Marshaller<UnitOverrideDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitOverrideDto;
  private Marshaller<ValueLibraryDto> ch_apkern_achilles_dto_shared_module_laboratory_library_ValueLibraryDto;
  private Marshaller<LaboratoryMeasuringDtoList> ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryMeasuringDtoList;
  private Marshaller<PersistEventTransfer> ch_apkern_achilles_concurrency_client_internal_transfer_PersistEventTransfer;
  private Marshaller<ExternalProviderDto> ch_apkern_achilles_dto_shared_entity_laboratory_provider_masterdata_ExternalProviderDto;
  private Marshaller<SearchParameter> ch_apkern_achilles_dto_shared_module_search_SearchParameter;
  private Marshaller<SimpleDateFilterCriteriaDto> ch_apkern_achilles_dto_shared_module_laboratory_SimpleDateFilterCriteriaDto;
  private Marshaller<PersonReferenceGroupItemDto> ch_apkern_achilles_dto_shared_entity_patient_PersonReferenceGroupItemDto;
  private Marshaller<LaboratoryMeasuringDto> ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryMeasuringDto;
  private Marshaller<LibraryListDto> ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_list_LibraryListDto;
  private Marshaller<DetailResultDtoList> ch_apkern_achilles_dto_shared_module_laboratory_DetailResultDtoList;
  private Marshaller<LegalPersonDto> ch_apkern_achilles_dto_shared_entity_address_LegalPersonDto;
  private Marshaller<NumericResultDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_NumericResultDto;
  private Marshaller<AssertionError> java_lang_AssertionError;
  private Marshaller<ArrayStoreException> java_lang_ArrayStoreException;
  private Marshaller<ValueBroadcastEventTransfer> ch_apkern_achilles_concurrency_client_internal_transfer_ValueBroadcastEventTransfer;
  private Marshaller<ValidationStateEnum> ch_apkern_achilles_api_shared_validation_ValidationStateEnum;
  private Marshaller<LaboratorySearchCriterionEnum> ch_apkern_achilles_dto_shared_module_search_criteria_LaboratorySearchCriterionEnum;
  private Marshaller<PatientDetailDto> ch_apkern_achilles_dto_shared_module_patient_PatientDetailDto;
  private Marshaller<ReferenceSolutionLotDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ReferenceSolutionLotDto;
  private Marshaller<StackTraceElement> java_lang_StackTraceElement;
  private Marshaller<ResultReferenceDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_ResultReferenceDto;
  private Marshaller<MetaFieldTypeEnum> ch_apkern_achilles_model_shared_entity_core_MetaFieldTypeEnum;
  private Marshaller<RuntimeException> java_lang_RuntimeException;
  private Marshaller<PersonAddressDto> ch_apkern_achilles_dto_shared_module_patient_PersonAddressDto;
  private Marshaller<DeviceProviderDto> ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceProviderDto;
  private Marshaller<ExternalLaboratoryMeasuringDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_ExternalLaboratoryMeasuringDto;
  private Marshaller<NegativeArraySizeException> java_lang_NegativeArraySizeException;
  private Marshaller<CalculatedResultTypeDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_CalculatedResultTypeDto;
  private Marshaller<BiometricTypeDto> ch_apkern_achilles_dto_shared_entity_laboratory_provider_BiometricTypeDto;
  private Marshaller<ResultTypeEnum> ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_ResultTypeEnum;
  private Marshaller<MeasurandLibrarySearchCriterionEnum> ch_apkern_achilles_dto_shared_module_search_criteria_MeasurandLibrarySearchCriterionEnum;
  private Marshaller<SelectionResultDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_SelectionResultDto;
  private Marshaller<ManufacturerResultReferenceDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ManufacturerResultReferenceDto;
  private Marshaller<LibraryOverrideDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryOverrideDto;
  private Marshaller<LibraryDtoList> ch_apkern_achilles_dto_shared_module_laboratory_library_LibraryDtoList;
  private Marshaller<PersonReferenceDto> ch_apkern_achilles_dto_shared_entity_patient_PersonReferenceDto;
  private Marshaller<DeviceQualityMeasuringDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_DeviceQualityMeasuringDto;
  private Marshaller<GroupTypeEnum> ch_apkern_achilles_model_shared_entity_core_GroupTypeEnum;
  private Marshaller<EventCase> ch_apkern_achilles_concurrency_client_internal_transfer_LockEventTransfer$EventCase;
  private Marshaller<InternalLaboratoryMeasuringDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_InternalLaboratoryMeasuringDto;
  private Marshaller<MeasurandGroupReferenceDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_MeasurandGroupReferenceDto;
  private Marshaller<ParameterSetTypeEnum> ch_apkern_achilles_model_shared_entity_core_ParameterSetTypeEnum;
  private Marshaller<LaboratoryDeviceQualityMeasuring2Dto> ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryDeviceQualityMeasuring2Dto;
  private Marshaller<LibraryDto> ch_apkern_achilles_dto_shared_module_laboratory_library_LibraryDto;
  private Marshaller<ClassCastException> java_lang_ClassCastException;
  private Marshaller<LanguageEnum> ch_apkern_achilles_model_shared_entity_core_LanguageEnum;
  private Marshaller<SelectionResultTypeDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionResultTypeDto;
  private Marshaller<IndexOutOfBoundsException> java_lang_IndexOutOfBoundsException;
  private Marshaller<TextResultDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_TextResultDto;
  private Marshaller<LibrarySearchDto> ch_apkern_achilles_dto_shared_module_laboratory_library_LibrarySearchDto;
  private Marshaller<ServerException> ch_apkern_achilles_api_client_exception_ServerException;
  private Marshaller<ConcurrentModificationException> java_util_ConcurrentModificationException;
  private Marshaller<TariffDto> ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_TariffDto;
  private Marshaller<MeasurandLibraryReferenceDto> ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_MeasurandLibraryReferenceDto;
  private Marshaller<ExceptionTypeEnum> ch_apkern_achilles_api_shared_validation_ExceptionTypeEnum;
  private Marshaller<MeasuringDisplayDtoList> ch_apkern_achilles_dto_shared_module_laboratory_MeasuringDisplayDtoList;
  private Marshaller<PatientPersonDto> ch_apkern_achilles_dto_shared_module_patient_PatientPersonDto;
  private Marshaller<ReferenceSolutionLotDtoList> ch_apkern_achilles_dto_shared_module_laboratory_quality_ReferenceSolutionLotDtoList;
  private Marshaller<ManualDeviceProviderDto> ch_apkern_achilles_dto_shared_entity_laboratory_provider_ManualDeviceProviderDto;
  private Marshaller<ValueLibraryDtoList> ch_apkern_achilles_dto_shared_module_laboratory_library_ValueLibraryDtoList;
  private Marshaller<LockBroadcastEventEntry> ch_apkern_achilles_concurrency_client_internal_transfer_LockBroadcastEventTransfer$LockBroadcastEventEntry;
  private Marshaller<ArithmeticException> java_lang_ArithmeticException;
  private Marshaller<LaboratoryMeasuringDisplayDto> ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryMeasuringDisplayDto;
  private Marshaller<DevicesInstrumentsDto> ch_apkern_achilles_dto_shared_module_laboratory_devices_instruments_DevicesInstrumentsDto;
  private QualifyingMarshallerWrapper<Object[]> arrayOf_java_lang_Object_D1;
  private QualifyingMarshallerWrapper<String[]> arrayOf_java_lang_String_D1;
  private QualifyingMarshallerWrapper<int[]> arrayOf_int_D1;
  private QualifyingMarshallerWrapper<long[]> arrayOf_long_D1;
  private QualifyingMarshallerWrapper<double[]> arrayOf_double_D1;
  private QualifyingMarshallerWrapper<float[]> arrayOf_float_D1;
  private QualifyingMarshallerWrapper<short[]> arrayOf_short_D1;
  private QualifyingMarshallerWrapper<boolean[]> arrayOf_boolean_D1;
  private QualifyingMarshallerWrapper<byte[]> arrayOf_byte_D1;
  private QualifyingMarshallerWrapper<char[]> arrayOf_char_D1;
  private QualifyingMarshallerWrapper<Integer[]> arrayOf_java_lang_Integer_D1;
  private QualifyingMarshallerWrapper<Long[]> arrayOf_java_lang_Long_D1;
  private QualifyingMarshallerWrapper<Double[]> arrayOf_java_lang_Double_D1;
  private QualifyingMarshallerWrapper<Float[]> arrayOf_java_lang_Float_D1;
  private QualifyingMarshallerWrapper<Short[]> arrayOf_java_lang_Short_D1;
  private QualifyingMarshallerWrapper<Boolean[]> arrayOf_java_lang_Boolean_D1;
  private QualifyingMarshallerWrapper<Byte[]> arrayOf_java_lang_Byte_D1;
  private QualifyingMarshallerWrapper<Character[]> arrayOf_java_lang_Character_D1;
  public MarshallerFactoryImpl() {
    java_lang_Float = new FloatMarshaller();
    marshallers.put("java.lang.Float", java_lang_Float);
    java_util_LinkedList = new LinkedListMarshaller();
    marshallers.put("java.util.LinkedList", java_util_LinkedList);
    java_lang_Long = new LongMarshaller();
    marshallers.put("java.lang.Long", java_lang_Long);
    java_lang_Short = new ShortMarshaller();
    marshallers.put("java.lang.Short", java_lang_Short);
    java_util_LinkedHashMap = new QualifyingMarshallerWrapper(new LinkedMapMarshaller());
    marshallers.put("java.util.LinkedHashMap", java_util_LinkedHashMap);
    java_util_Map = new QualifyingMarshallerWrapper(new MapMarshaller());
    marshallers.put("java.util.Map", java_util_Map);
    marshallers.put("java.util.Collections$SingletonMap", java_util_Map);
    marshallers.put("java.util.AbstractMap", java_util_Map);
    marshallers.put("java.util.Collections$SynchronizedMap", java_util_Map);
    marshallers.put("java.util.HashMap", java_util_Map);
    marshallers.put("java.util.Collections$UnmodifiableMap", java_util_Map);
    marshallers.put("java.util.Collections$EmptyMap", java_util_Map);
    java_lang_Integer = new IntegerMarshaller();
    marshallers.put("java.lang.Integer", java_lang_Integer);
    java_sql_Timestamp = new TimestampMarshaller();
    marshallers.put("java.sql.Timestamp", java_sql_Timestamp);
    java_sql_Time = new TimeMarshaller();
    marshallers.put("java.sql.Time", java_sql_Time);
    java_math_BigInteger = new BigIntegerMarshaller();
    marshallers.put("java.math.BigInteger", java_math_BigInteger);
    java_util_Vector = new ListMarshaller();
    marshallers.put("java.util.Vector", java_util_Vector);
    java_util_SortedSet = new SortedSetMarshaller();
    marshallers.put("java.util.SortedSet", java_util_SortedSet);
    marshallers.put("java.util.Collections$UnmodifiableSortedSet", java_util_SortedSet);
    marshallers.put("java.util.TreeSet", java_util_SortedSet);
    marshallers.put("java.util.Collections$SynchronizedSortedSet", java_util_SortedSet);
    java_util_AbstractMap = new QualifyingMarshallerWrapper(new MapMarshaller());
    marshallers.put("java.util.AbstractMap", java_util_AbstractMap);
    java_lang_StringBuilder = new StringBuilderMarshaller();
    marshallers.put("java.lang.StringBuilder", java_lang_StringBuilder);
    java_lang_Boolean = new BooleanMarshaller();
    marshallers.put("java.lang.Boolean", java_lang_Boolean);
    java_lang_String = new StringMarshaller();
    marshallers.put("java.lang.String", java_lang_String);
    java_util_HashMap = new QualifyingMarshallerWrapper(new MapMarshaller());
    marshallers.put("java.util.HashMap", java_util_HashMap);
    java_lang_Byte = new ByteMarshaller();
    marshallers.put("java.lang.Byte", java_lang_Byte);
    java_util_HashSet = new SetMarshaller();
    marshallers.put("java.util.HashSet", java_util_HashSet);
    java_util_Queue = new QueueMarshaller();
    marshallers.put("java.util.Queue", java_util_Queue);
    marshallers.put("java.util.AbstractQueue", java_util_Queue);
    java_lang_Object = new ObjectMarshaller();
    marshallers.put("java.lang.Object", java_lang_Object);
    java_util_SortedMap = new QualifyingMarshallerWrapper(new SortedMapMarshaller());
    marshallers.put("java.util.SortedMap", java_util_SortedMap);
    marshallers.put("java.util.Collections$SynchronizedSortedMap", java_util_SortedMap);
    marshallers.put("java.util.Collections$UnmodifiableSortedMap", java_util_SortedMap);
    marshallers.put("java.util.TreeMap", java_util_SortedMap);
    java_sql_Date = new SQLDateMarshaller();
    marshallers.put("java.sql.Date", java_sql_Date);
    java_util_AbstractSet = new SetMarshaller();
    marshallers.put("java.util.AbstractSet", java_util_AbstractSet);
    java_util_Stack = new ListMarshaller();
    marshallers.put("java.util.Stack", java_util_Stack);
    java_util_Date = new DateMarshaller();
    marshallers.put("java.util.Date", java_util_Date);
    java_util_LinkedHashSet = new LinkedHashSetMarshaller();
    marshallers.put("java.util.LinkedHashSet", java_util_LinkedHashSet);
    java_lang_Character = new CharacterMarshaller();
    marshallers.put("java.lang.Character", java_lang_Character);
    java_util_PriorityQueue = new PriorityQueueMarshaller();
    marshallers.put("java.util.PriorityQueue", java_util_PriorityQueue);
    java_util_List = new ListMarshaller();
    marshallers.put("java.util.List", java_util_List);
    marshallers.put("java.util.Collections$SynchronizedRandomAccessList", java_util_List);
    marshallers.put("java.util.Collections$UnmodifiableRandomAccessList", java_util_List);
    marshallers.put("java.util.Stack", java_util_List);
    marshallers.put("java.util.Vector", java_util_List);
    marshallers.put("java.util.ArrayList", java_util_List);
    marshallers.put("java.util.Collections$SingletonList", java_util_List);
    marshallers.put("java.util.Collections$SynchronizedList", java_util_List);
    marshallers.put("java.util.Collections$UnmodifiableList", java_util_List);
    marshallers.put("java.util.Collections$EmptyList", java_util_List);
    marshallers.put("java.util.Arrays$ArrayList", java_util_List);
    marshallers.put("java.util.AbstractList", java_util_List);
    java_util_AbstractQueue = new QueueMarshaller();
    marshallers.put("java.util.AbstractQueue", java_util_AbstractQueue);
    java_lang_Double = new DoubleMarshaller();
    marshallers.put("java.lang.Double", java_lang_Double);
    java_util_TreeSet = new SortedSetMarshaller();
    marshallers.put("java.util.TreeSet", java_util_TreeSet);
    java_math_BigDecimal = new BigDecimalMarshaller();
    marshallers.put("java.math.BigDecimal", java_math_BigDecimal);
    java_lang_StringBuffer = new StringBufferMarshaller();
    marshallers.put("java.lang.StringBuffer", java_lang_StringBuffer);
    java_util_TreeMap = new QualifyingMarshallerWrapper(new SortedMapMarshaller());
    marshallers.put("java.util.TreeMap", java_util_TreeMap);
    java_util_AbstractList = new ListMarshaller();
    marshallers.put("java.util.AbstractList", java_util_AbstractList);
    java_util_Set = new SetMarshaller();
    marshallers.put("java.util.Set", java_util_Set);
    marshallers.put("java.util.Collections$SynchronizedSet", java_util_Set);
    marshallers.put("java.util.Collections$UnmodifiableSet", java_util_Set);
    marshallers.put("java.util.Collections$EmptySet", java_util_Set);
    marshallers.put("java.util.Collections$SingletonSet", java_util_Set);
    marshallers.put("java.util.AbstractSet", java_util_Set);
    marshallers.put("java.util.HashSet", java_util_Set);
    java_util_ArrayList = new ListMarshaller();
    marshallers.put("java.util.ArrayList", java_util_ArrayList);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SubstanceDto = new Marshaller<SubstanceDto>() {
      private SubstanceDto[] EMPTY_ARRAY = new SubstanceDto[0];
      public SubstanceDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SubstanceDto.class;
      }
      public SubstanceDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(SubstanceDto.class, objId);
          }
          SubstanceDto entity = new SubstanceDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SubstanceDto", t);
        }
      }
      public String marshall(SubstanceDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SubstanceDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SubstanceDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SubstanceDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SubstanceDto);
    ch_apkern_achilles_dto_shared_entity_core_GroupDto = new Marshaller<GroupDto>() {
      private GroupDto[] EMPTY_ARRAY = new GroupDto[0];
      public GroupDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return GroupDto.class;
      }
      public GroupDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(GroupDto.class, objId);
          }
          GroupDto entity = new GroupDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("type")) && (!obj.get("type").isNull())) {
            entity.setType(obj.get("type").isObject() != null ? Enum.valueOf(GroupTypeEnum.class, obj.get("type").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("type").isString() != null ? Enum.valueOf(GroupTypeEnum.class, obj.get("type").isString().stringValue()) : null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.GroupDto", t);
        }
      }
      public String marshall(GroupDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.GroupDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.GroupDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"type\" : ").append(a0.getType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.GroupTypeEnum\",\"^EnumStringValue\":\"").append(a0.getType().name()).append("\"}") : "null").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.GroupDto", ch_apkern_achilles_dto_shared_entity_core_GroupDto);
    ch_apkern_achilles_dto_shared_entity_core_GroupItemDto = new Marshaller<GroupItemDto>() {
      private GroupItemDto[] EMPTY_ARRAY = new GroupItemDto[0];
      public GroupItemDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return GroupItemDto.class;
      }
      public GroupItemDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(GroupItemDto.class, objId);
          }
          GroupItemDto entity = new GroupItemDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("group")) && (!obj.get("group").isNull())) {
            entity.setGroup(ch_apkern_achilles_dto_shared_entity_core_GroupDto.demarshall(obj.get("group"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.GroupItemDto", t);
        }
      }
      public String marshall(GroupItemDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.GroupItemDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(768).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.GroupItemDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"group\" : ").append(ch_apkern_achilles_dto_shared_entity_core_GroupDto.marshall(a0.getGroup(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.GroupItemDto", ch_apkern_achilles_dto_shared_entity_core_GroupItemDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto = new Marshaller<DiagramDto>() {
      private DiagramDto[] EMPTY_ARRAY = new DiagramDto[0];
      public DiagramDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return DiagramDto.class;
      }
      public DiagramDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(DiagramDto.class, objId);
          }
          DiagramDto entity = new DiagramDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("scaleMinimum")) && (!obj.get("scaleMinimum").isNull())) {
            entity.setScaleMinimum(java_math_BigDecimal.demarshall(obj.get("scaleMinimum"), a1));
          }
          if ((obj.containsKey("scaleMaximum")) && (!obj.get("scaleMaximum").isNull())) {
            entity.setScaleMaximum(java_math_BigDecimal.demarshall(obj.get("scaleMaximum"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.DiagramDto", t);
        }
      }
      public String marshall(DiagramDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.DiagramDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.DiagramDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"scaleMinimum\" : ").append(java_math_BigDecimal.marshall(a0.getScaleMinimum(), a1)).append(",").append("\"scaleMaximum\" : ").append(java_math_BigDecimal.marshall(a0.getScaleMaximum(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.DiagramDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto = new Marshaller<LibraryDivisionDto>() {
      private LibraryDivisionDto[] EMPTY_ARRAY = new LibraryDivisionDto[0];
      public LibraryDivisionDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LibraryDivisionDto.class;
      }
      public LibraryDivisionDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LibraryDivisionDto.class, objId);
          }
          LibraryDivisionDto entity = new LibraryDivisionDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("sortCode")) && (!obj.get("sortCode").isNull())) {
            entity.setSortCode(java_lang_Integer.demarshall(obj.get("sortCode"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryDivisionDto", t);
        }
      }
      public String marshall(LibraryDivisionDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryDivisionDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(512).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryDivisionDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"sortCode\" : ").append(java_lang_Integer.marshall(a0.getSortCode(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryDivisionDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto);
    ch_apkern_achilles_dto_shared_entity_core_UserGroupDto = new Marshaller<UserGroupDto>() {
      private UserGroupDto[] EMPTY_ARRAY = new UserGroupDto[0];
      public UserGroupDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return UserGroupDto.class;
      }
      public UserGroupDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(UserGroupDto.class, objId);
          }
          UserGroupDto entity = new UserGroupDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.UserGroupDto", t);
        }
      }
      public String marshall(UserGroupDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.UserGroupDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.UserGroupDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.UserGroupDto", ch_apkern_achilles_dto_shared_entity_core_UserGroupDto);
    ch_apkern_achilles_dto_shared_entity_core_UserDto = new Marshaller<UserDto>() {
      private UserDto[] EMPTY_ARRAY = new UserDto[0];
      public UserDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return UserDto.class;
      }
      public UserDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(UserDto.class, objId);
          }
          UserDto entity = new UserDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("signature")) && (!obj.get("signature").isNull())) {
            entity.setSignature(java_lang_String.demarshall(obj.get("signature"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("passwordEncrypted")) && (!obj.get("passwordEncrypted").isNull())) {
            entity.setPasswordEncrypted(java_lang_String.demarshall(obj.get("passwordEncrypted"), a1));
          }
          if ((obj.containsKey("group")) && (!obj.get("group").isNull())) {
            entity.setGroup(ch_apkern_achilles_dto_shared_entity_core_UserGroupDto.demarshall(obj.get("group"), a1));
          }
          if ((obj.containsKey("mandatorList")) && (!obj.get("mandatorList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.core.MandatorDto");
            entity.setMandatorList(java_util_List.demarshall(obj.get("mandatorList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.UserDto", t);
        }
      }
      public String marshall(UserDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.UserDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1152).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.UserDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"signature\" : ").append(java_lang_String.marshall(a0.getSignature(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"passwordEncrypted\" : ").append(java_lang_String.marshall(a0.getPasswordEncrypted(), a1)).append(",").append("\"group\" : ").append(ch_apkern_achilles_dto_shared_entity_core_UserGroupDto.marshall(a0.getGroup(), a1)).append(",").append("\"mandatorList\" : ").append(java_util_List.marshall(a0.getMandatorList(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.UserDto", ch_apkern_achilles_dto_shared_entity_core_UserDto);
    ch_apkern_achilles_dto_shared_entity_core_ModificationDto = new Marshaller<ModificationDto>() {
      private ModificationDto[] EMPTY_ARRAY = new ModificationDto[0];
      public ModificationDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ModificationDto.class;
      }
      public ModificationDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ModificationDto.class, objId);
          }
          ModificationDto entity = new ModificationDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("user")) && (!obj.get("user").isNull())) {
            entity.setUser(ch_apkern_achilles_dto_shared_entity_core_UserDto.demarshall(obj.get("user"), a1));
          }
          if ((obj.containsKey("date")) && (!obj.get("date").isNull())) {
            entity.setDate(java_util_Date.demarshall(obj.get("date"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.ModificationDto", t);
        }
      }
      public String marshall(ModificationDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.ModificationDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1536).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.ModificationDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"user\" : ").append(ch_apkern_achilles_dto_shared_entity_core_UserDto.marshall(a0.getUser(), a1)).append(",").append("\"date\" : ").append(java_util_Date.marshall(a0.getDate(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.ModificationDto", ch_apkern_achilles_dto_shared_entity_core_ModificationDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_ResultTypeDto = new Marshaller<ResultTypeDto>() {
      private ResultTypeDto[] EMPTY_ARRAY = new ResultTypeDto[0];
      public ResultTypeDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ResultTypeDto.class;
      }
      public ResultTypeDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ResultTypeDto.class, objId);
          }
          ResultTypeDto entity = new ResultTypeDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.ResultTypeDto", t);
        }
      }
      public String marshall(ResultTypeDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.ResultTypeDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.ResultTypeDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.ResultTypeDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_ResultTypeDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_AnalysisLibraryDto = new Marshaller<AnalysisLibraryDto>() {
      private AnalysisLibraryDto[] EMPTY_ARRAY = new AnalysisLibraryDto[0];
      public AnalysisLibraryDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return AnalysisLibraryDto.class;
      }
      public AnalysisLibraryDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(AnalysisLibraryDto.class, objId);
          }
          AnalysisLibraryDto entity = new AnalysisLibraryDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("substance")) && (!obj.get("substance").isNull())) {
            entity.setSubstance(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SubstanceDto.demarshall(obj.get("substance"), a1));
          }
          if ((obj.containsKey("measuringMethod")) && (!obj.get("measuringMethod").isNull())) {
            entity.setMeasuringMethod(ch_apkern_achilles_dto_shared_entity_core_GroupItemDto.demarshall(obj.get("measuringMethod"), a1));
          }
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("diagram")) && (!obj.get("diagram").isNull())) {
            entity.setDiagram(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.demarshall(obj.get("diagram"), a1));
          }
          if ((obj.containsKey("division")) && (!obj.get("division").isNull())) {
            entity.setDivision(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.demarshall(obj.get("division"), a1));
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("modificated")) && (!obj.get("modificated").isNull())) {
            entity.setModificated(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("modificated"), a1));
          }
          if ((obj.containsKey("resultType")) && (!obj.get("resultType").isNull())) {
            entity.setResultType((ResultTypeDto) java_lang_Object.demarshall(ResultTypeDto.class, obj.get("resultType"), a1));
          }
          if ((obj.containsKey("sortCode")) && (!obj.get("sortCode").isNull())) {
            entity.setSortCode(java_lang_Integer.demarshall(obj.get("sortCode"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.AnalysisLibraryDto", t);
        }
      }
      public String marshall(AnalysisLibraryDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.AnalysisLibraryDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(4480).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.AnalysisLibraryDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"substance\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SubstanceDto.marshall(a0.getSubstance(), a1)).append(",").append("\"measuringMethod\" : ").append(ch_apkern_achilles_dto_shared_entity_core_GroupItemDto.marshall(a0.getMeasuringMethod(), a1)).append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"diagram\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.marshall(a0.getDiagram(), a1)).append(",").append("\"division\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.marshall(a0.getDivision(), a1)).append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"modificated\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getModificated(), a1)).append(",").append("\"resultType\" : ").append(java_lang_Object.marshall(a0.getResultType(), a1)).append(",").append("\"sortCode\" : ").append(java_lang_Integer.marshall(a0.getSortCode(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.AnalysisLibraryDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_AnalysisLibraryDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_QualabToleranceDto = new Marshaller<QualabToleranceDto>() {
      private QualabToleranceDto[] EMPTY_ARRAY = new QualabToleranceDto[0];
      public QualabToleranceDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return QualabToleranceDto.class;
      }
      public QualabToleranceDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(QualabToleranceDto.class, objId);
          }
          QualabToleranceDto entity = new QualabToleranceDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("tolerance")) && (!obj.get("tolerance").isNull())) {
            entity.setTolerance(java_math_BigDecimal.demarshall(obj.get("tolerance"), a1));
          }
          if ((obj.containsKey("analysisLibrary")) && (!obj.get("analysisLibrary").isNull())) {
            entity.setAnalysisLibrary(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_AnalysisLibraryDto.demarshall(obj.get("analysisLibrary"), a1));
          }
          if ((obj.containsKey("validFrom")) && (!obj.get("validFrom").isNull())) {
            entity.setValidFrom(java_util_Date.demarshall(obj.get("validFrom"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.QualabToleranceDto", t);
        }
      }
      public String marshall(QualabToleranceDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.QualabToleranceDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(4992).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.QualabToleranceDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"tolerance\" : ").append(java_math_BigDecimal.marshall(a0.getTolerance(), a1)).append(",").append("\"analysisLibrary\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_AnalysisLibraryDto.marshall(a0.getAnalysisLibrary(), a1)).append(",").append("\"validFrom\" : ").append(java_util_Date.marshall(a0.getValidFrom(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.QualabToleranceDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_QualabToleranceDto);
    arrayOf_java_lang_StackTraceElement_D1 = new QualifyingMarshallerWrapper(new Marshaller<StackTraceElement[]>() {
      public java.lang.StackTraceElement[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private StackTraceElement[] _demarshall1(EJArray a0, MarshallingSession a1) {
        StackTraceElement[] newArray = new StackTraceElement[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_StackTraceElement.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(StackTraceElement[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return StackTraceElement.class;
      }
      public StackTraceElement[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(StackTraceElement[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.StackTraceElement;", arrayOf_java_lang_StackTraceElement_D1);
    java_lang_Throwable = new Marshaller<Throwable>() {
      private Throwable[] EMPTY_ARRAY = new Throwable[0];
      public Throwable[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return Throwable.class;
      }
      public Throwable demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(Throwable.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          Throwable entity = new Throwable(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.Throwable", t);
        }
      }
      public String marshall(Throwable a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.Throwable\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3072).append("{\"^EncodedType\":\"java.lang.Throwable\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.Throwable", java_lang_Throwable);
    java_lang_IllegalArgumentException = new Marshaller<IllegalArgumentException>() {
      private IllegalArgumentException[] EMPTY_ARRAY = new IllegalArgumentException[0];
      public IllegalArgumentException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return IllegalArgumentException.class;
      }
      public IllegalArgumentException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(IllegalArgumentException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          IllegalArgumentException entity = new IllegalArgumentException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.IllegalArgumentException", t);
        }
      }
      public String marshall(IllegalArgumentException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.IllegalArgumentException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.IllegalArgumentException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.IllegalArgumentException", java_lang_IllegalArgumentException);
    java_lang_UnsupportedOperationException = new Marshaller<UnsupportedOperationException>() {
      private UnsupportedOperationException[] EMPTY_ARRAY = new UnsupportedOperationException[0];
      public UnsupportedOperationException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return UnsupportedOperationException.class;
      }
      public UnsupportedOperationException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(UnsupportedOperationException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          UnsupportedOperationException entity = new UnsupportedOperationException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.UnsupportedOperationException", t);
        }
      }
      public String marshall(UnsupportedOperationException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.UnsupportedOperationException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.UnsupportedOperationException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.UnsupportedOperationException", java_lang_UnsupportedOperationException);
    ch_apkern_achilles_dto_shared_entity_address_CountryDto = new Marshaller<CountryDto>() {
      private CountryDto[] EMPTY_ARRAY = new CountryDto[0];
      public CountryDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return CountryDto.class;
      }
      public CountryDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(CountryDto.class, objId);
          }
          CountryDto entity = new CountryDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.address.CountryDto", t);
        }
      }
      public String marshall(CountryDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.CountryDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(512).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.CountryDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.address.CountryDto", ch_apkern_achilles_dto_shared_entity_address_CountryDto);
    ch_apkern_achilles_dto_shared_entity_address_RegionDto = new Marshaller<RegionDto>() {
      private RegionDto[] EMPTY_ARRAY = new RegionDto[0];
      public RegionDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return RegionDto.class;
      }
      public RegionDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(RegionDto.class, objId);
          }
          RegionDto entity = new RegionDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("country")) && (!obj.get("country").isNull())) {
            entity.setCountry(ch_apkern_achilles_dto_shared_entity_address_CountryDto.demarshall(obj.get("country"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.address.RegionDto", t);
        }
      }
      public String marshall(RegionDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.RegionDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1024).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.RegionDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"country\" : ").append(ch_apkern_achilles_dto_shared_entity_address_CountryDto.marshall(a0.getCountry(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.address.RegionDto", ch_apkern_achilles_dto_shared_entity_address_RegionDto);
    ch_apkern_achilles_dto_shared_entity_address_CityDto = new Marshaller<CityDto>() {
      private CityDto[] EMPTY_ARRAY = new CityDto[0];
      public CityDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return CityDto.class;
      }
      public CityDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(CityDto.class, objId);
          }
          CityDto entity = new CityDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("zip")) && (!obj.get("zip").isNull())) {
            entity.setZip(java_lang_String.demarshall(obj.get("zip"), a1));
          }
          if ((obj.containsKey("region")) && (!obj.get("region").isNull())) {
            entity.setRegion(ch_apkern_achilles_dto_shared_entity_address_RegionDto.demarshall(obj.get("region"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.address.CityDto", t);
        }
      }
      public String marshall(CityDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.CityDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1536).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.CityDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"zip\" : ").append(java_lang_String.marshall(a0.getZip(), a1)).append(",").append("\"region\" : ").append(ch_apkern_achilles_dto_shared_entity_address_RegionDto.marshall(a0.getRegion(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.address.CityDto", ch_apkern_achilles_dto_shared_entity_address_CityDto);
    ch_apkern_achilles_dto_shared_entity_address_AddressDto = new Marshaller<AddressDto>() {
      private AddressDto[] EMPTY_ARRAY = new AddressDto[0];
      public AddressDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return AddressDto.class;
      }
      public AddressDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(AddressDto.class, objId);
          }
          AddressDto entity = new AddressDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("city")) && (!obj.get("city").isNull())) {
            entity.setCity(ch_apkern_achilles_dto_shared_entity_address_CityDto.demarshall(obj.get("city"), a1));
          }
          if ((obj.containsKey("street")) && (!obj.get("street").isNull())) {
            entity.setStreet(java_lang_String.demarshall(obj.get("street"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.address.AddressDto", t);
        }
      }
      public String marshall(AddressDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.AddressDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1920).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.AddressDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"city\" : ").append(ch_apkern_achilles_dto_shared_entity_address_CityDto.marshall(a0.getCity(), a1)).append(",").append("\"street\" : ").append(java_lang_String.marshall(a0.getStreet(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.address.AddressDto", ch_apkern_achilles_dto_shared_entity_address_AddressDto);
    ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto = new Marshaller<NaturalPersonDto>() {
      private NaturalPersonDto[] EMPTY_ARRAY = new NaturalPersonDto[0];
      public NaturalPersonDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return NaturalPersonDto.class;
      }
      public NaturalPersonDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(NaturalPersonDto.class, objId);
          }
          NaturalPersonDto entity = new NaturalPersonDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("firstname")) && (!obj.get("firstname").isNull())) {
            entity.setFirstname(java_lang_String.demarshall(obj.get("firstname"), a1));
          }
          if ((obj.containsKey("lastname")) && (!obj.get("lastname").isNull())) {
            entity.setLastname(java_lang_String.demarshall(obj.get("lastname"), a1));
          }
          if ((obj.containsKey("birthday")) && (!obj.get("birthday").isNull())) {
            entity.setBirthday(java_util_Date.demarshall(obj.get("birthday"), a1));
          }
          if ((obj.containsKey("ahvNumber")) && (!obj.get("ahvNumber").isNull())) {
            entity.setAhvNumber(java_lang_String.demarshall(obj.get("ahvNumber"), a1));
          }
          if ((obj.containsKey("sex")) && (!obj.get("sex").isNull())) {
            entity.setSex(obj.get("sex").isObject() != null ? Enum.valueOf(SexEnum.class, obj.get("sex").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("sex").isString() != null ? Enum.valueOf(SexEnum.class, obj.get("sex").isString().stringValue()) : null);
          }
          if ((obj.containsKey("profession")) && (!obj.get("profession").isNull())) {
            entity.setProfession(java_lang_String.demarshall(obj.get("profession"), a1));
          }
          if ((obj.containsKey("title")) && (!obj.get("title").isNull())) {
            entity.setTitle(ch_apkern_achilles_dto_shared_entity_core_GroupItemDto.demarshall(obj.get("title"), a1));
          }
          if ((obj.containsKey("address")) && (!obj.get("address").isNull())) {
            entity.setAddress(ch_apkern_achilles_dto_shared_entity_address_AddressDto.demarshall(obj.get("address"), a1));
          }
          if ((obj.containsKey("metaFieldValueList")) && (!obj.get("metaFieldValueList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.core.MetaFieldValueDto");
            entity.setMetaFieldValueList(java_util_List.demarshall(obj.get("metaFieldValueList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.address.NaturalPersonDto", t);
        }
      }
      public String marshall(NaturalPersonDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.NaturalPersonDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3840).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.NaturalPersonDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"firstname\" : ").append(java_lang_String.marshall(a0.getFirstname(), a1)).append(",").append("\"lastname\" : ").append(java_lang_String.marshall(a0.getLastname(), a1)).append(",").append("\"birthday\" : ").append(java_util_Date.marshall(a0.getBirthday(), a1)).append(",").append("\"ahvNumber\" : ").append(java_lang_String.marshall(a0.getAhvNumber(), a1)).append(",").append("\"sex\" : ").append(a0.getSex() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.SexEnum\",\"^EnumStringValue\":\"").append(a0.getSex().name()).append("\"}") : "null").append(",").append("\"profession\" : ").append(java_lang_String.marshall(a0.getProfession(), a1)).append(",").append("\"title\" : ").append(ch_apkern_achilles_dto_shared_entity_core_GroupItemDto.marshall(a0.getTitle(), a1)).append(",").append("\"address\" : ").append(ch_apkern_achilles_dto_shared_entity_address_AddressDto.marshall(a0.getAddress(), a1)).append(",").append("\"metaFieldValueList\" : ").append(java_util_List.marshall(a0.getMetaFieldValueList(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.address.NaturalPersonDto", ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto);
    ch_apkern_achilles_dto_shared_entity_patient_PatientDto = new Marshaller<PatientDto>() {
      private PatientDto[] EMPTY_ARRAY = new PatientDto[0];
      public PatientDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PatientDto.class;
      }
      public PatientDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(PatientDto.class, objId);
          }
          PatientDto entity = new PatientDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("patientNumber")) && (!obj.get("patientNumber").isNull())) {
            entity.setPatientNumber(java_lang_Integer.demarshall(obj.get("patientNumber"), a1));
          }
          if ((obj.containsKey("naturalPerson")) && (!obj.get("naturalPerson").isNull())) {
            entity.setNaturalPerson(ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto.demarshall(obj.get("naturalPerson"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.patient.PatientDto", t);
        }
      }
      public String marshall(PatientDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.patient.PatientDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(4224).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.patient.PatientDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"patientNumber\" : ").append(java_lang_Integer.marshall(a0.getPatientNumber(), a1)).append(",").append("\"naturalPerson\" : ").append(ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto.marshall(a0.getNaturalPerson(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.patient.PatientDto", ch_apkern_achilles_dto_shared_entity_patient_PatientDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto = new Marshaller<PatientIdentificationDto>() {
      private PatientIdentificationDto[] EMPTY_ARRAY = new PatientIdentificationDto[0];
      public PatientIdentificationDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PatientIdentificationDto.class;
      }
      public PatientIdentificationDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(PatientIdentificationDto.class, objId);
          }
          PatientIdentificationDto entity = new PatientIdentificationDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("number")) && (!obj.get("number").isNull())) {
            entity.setNumber(java_lang_Integer.demarshall(obj.get("number"), a1));
          }
          if ((obj.containsKey("firstname")) && (!obj.get("firstname").isNull())) {
            entity.setFirstname(java_lang_String.demarshall(obj.get("firstname"), a1));
          }
          if ((obj.containsKey("lastname")) && (!obj.get("lastname").isNull())) {
            entity.setLastname(java_lang_String.demarshall(obj.get("lastname"), a1));
          }
          if ((obj.containsKey("birthday")) && (!obj.get("birthday").isNull())) {
            entity.setBirthday(java_util_Date.demarshall(obj.get("birthday"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.PatientIdentificationDto", t);
        }
      }
      public String marshall(PatientIdentificationDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.PatientIdentificationDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.PatientIdentificationDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"number\" : ").append(java_lang_Integer.marshall(a0.getNumber(), a1)).append(",").append("\"firstname\" : ").append(java_lang_String.marshall(a0.getFirstname(), a1)).append(",").append("\"lastname\" : ").append(java_lang_String.marshall(a0.getLastname(), a1)).append(",").append("\"birthday\" : ").append(java_util_Date.marshall(a0.getBirthday(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.PatientIdentificationDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_provider_ProviderDto = new Marshaller<ProviderDto>() {
      private ProviderDto[] EMPTY_ARRAY = new ProviderDto[0];
      public ProviderDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ProviderDto.class;
      }
      public ProviderDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ProviderDto.class, objId);
          }
          ProviderDto entity = new ProviderDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("active")) && (!obj.get("active").isNull())) {
            entity.setActive(java_lang_Boolean.demarshall(obj.get("active"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.provider.ProviderDto", t);
        }
      }
      public String marshall(ProviderDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.ProviderDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(512).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.ProviderDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"active\" : ").append(java_lang_Boolean.marshall(a0.getActive(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.provider.ProviderDto", ch_apkern_achilles_dto_shared_entity_laboratory_provider_ProviderDto);
    ch_apkern_achilles_dto_shared_entity_core_MandatorDto = new Marshaller<MandatorDto>() {
      private MandatorDto[] EMPTY_ARRAY = new MandatorDto[0];
      public MandatorDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MandatorDto.class;
      }
      public MandatorDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MandatorDto.class, objId);
          }
          MandatorDto entity = new MandatorDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("user")) && (!obj.get("user").isNull())) {
            entity.setUser(ch_apkern_achilles_dto_shared_entity_core_UserDto.demarshall(obj.get("user"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.MandatorDto", t);
        }
      }
      public String marshall(MandatorDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.MandatorDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1536).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.MandatorDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"user\" : ").append(ch_apkern_achilles_dto_shared_entity_core_UserDto.marshall(a0.getUser(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.MandatorDto", ch_apkern_achilles_dto_shared_entity_core_MandatorDto);
    ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxDto = new Marshaller<InboxDto>() {
      private InboxDto[] EMPTY_ARRAY = new InboxDto[0];
      public InboxDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return InboxDto.class;
      }
      public InboxDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(InboxDto.class, objId);
          }
          InboxDto entity = new InboxDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          if ((obj.containsKey("type")) && (!obj.get("type").isNull())) {
            entity.setType(obj.get("type").isObject() != null ? Enum.valueOf(LaboratoryTypeEnum.class, obj.get("type").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("type").isString() != null ? Enum.valueOf(LaboratoryTypeEnum.class, obj.get("type").isString().stringValue()) : null);
          }
          if ((obj.containsKey("inboxViewed")) && (!obj.get("inboxViewed").isNull())) {
            entity.setInboxViewed(java_lang_Boolean.demarshall(obj.get("inboxViewed"), a1));
          }
          if ((obj.containsKey("measuringDate")) && (!obj.get("measuringDate").isNull())) {
            entity.setMeasuringDate(java_util_Date.demarshall(obj.get("measuringDate"), a1));
          }
          if ((obj.containsKey("analysisDate")) && (!obj.get("analysisDate").isNull())) {
            entity.setAnalysisDate(java_util_Date.demarshall(obj.get("analysisDate"), a1));
          }
          if ((obj.containsKey("receiveDate")) && (!obj.get("receiveDate").isNull())) {
            entity.setReceiveDate(java_util_Date.demarshall(obj.get("receiveDate"), a1));
          }
          if ((obj.containsKey("remarks")) && (!obj.get("remarks").isNull())) {
            entity.setRemarks(java_lang_String.demarshall(obj.get("remarks"), a1));
          }
          if ((obj.containsKey("resultsValid")) && (!obj.get("resultsValid").isNull())) {
            entity.setResultsValid(java_lang_Boolean.demarshall(obj.get("resultsValid"), a1));
          }
          if ((obj.containsKey("controller")) && (!obj.get("controller").isNull())) {
            entity.setController(ch_apkern_achilles_dto_shared_entity_core_UserDto.demarshall(obj.get("controller"), a1));
          }
          if ((obj.containsKey("updater")) && (!obj.get("updater").isNull())) {
            entity.setUpdater(ch_apkern_achilles_dto_shared_entity_core_UserDto.demarshall(obj.get("updater"), a1));
          }
          if ((obj.containsKey("assignedPatient")) && (!obj.get("assignedPatient").isNull())) {
            entity.setAssignedPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("assignedPatient"), a1));
          }
          if ((obj.containsKey("patientIdentification")) && (!obj.get("patientIdentification").isNull())) {
            entity.setPatientIdentification(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.demarshall(obj.get("patientIdentification"), a1));
          }
          if ((obj.containsKey("provider")) && (!obj.get("provider").isNull())) {
            entity.setProvider((ProviderDto) java_lang_Object.demarshall(ProviderDto.class, obj.get("provider"), a1));
          }
          if ((obj.containsKey("mandator")) && (!obj.get("mandator").isNull())) {
            entity.setMandator(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.demarshall(obj.get("mandator"), a1));
          }
          if ((obj.containsKey("analysisReferenceNumber")) && (!obj.get("analysisReferenceNumber").isNull())) {
            entity.setAnalysisReferenceNumber(java_lang_String.demarshall(obj.get("analysisReferenceNumber"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxDto", t);
        }
      }
      public String marshall(InboxDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(8064).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append(",").append("\"type\" : ").append(a0.getType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.laboratory.LaboratoryTypeEnum\",\"^EnumStringValue\":\"").append(a0.getType().name()).append("\"}") : "null").append(",").append("\"inboxViewed\" : ").append(java_lang_Boolean.marshall(a0.getInboxViewed(), a1)).append(",").append("\"measuringDate\" : ").append(java_util_Date.marshall(a0.getMeasuringDate(), a1)).append(",").append("\"analysisDate\" : ").append(java_util_Date.marshall(a0.getAnalysisDate(), a1)).append(",").append("\"receiveDate\" : ").append(java_util_Date.marshall(a0.getReceiveDate(), a1)).append(",").append("\"remarks\" : ").append(java_lang_String.marshall(a0.getRemarks(), a1)).append(",").append("\"resultsValid\" : ").append(java_lang_Boolean.marshall(a0.getResultsValid(), a1)).append(",").append("\"controller\" : ").append(ch_apkern_achilles_dto_shared_entity_core_UserDto.marshall(a0.getController(), a1)).append(",").append("\"updater\" : ").append(ch_apkern_achilles_dto_shared_entity_core_UserDto.marshall(a0.getUpdater(), a1)).append(",").append("\"assignedPatient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getAssignedPatient(), a1)).append(",").append("\"patientIdentification\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.marshall(a0.getPatientIdentification(), a1)).append(",").append("\"provider\" : ").append(java_lang_Object.marshall(a0.getProvider(), a1)).append(",").append("\"mandator\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.marshall(a0.getMandator(), a1)).append(",").append("\"analysisReferenceNumber\" : ").append(java_lang_String.marshall(a0.getAnalysisReferenceNumber(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxDto", ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_provider_MeasurandGroupDto = new Marshaller<MeasurandGroupDto>() {
      private MeasurandGroupDto[] EMPTY_ARRAY = new MeasurandGroupDto[0];
      public MeasurandGroupDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasurandGroupDto.class;
      }
      public MeasurandGroupDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasurandGroupDto.class, objId);
          }
          MeasurandGroupDto entity = new MeasurandGroupDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("measurandLibraryList")) && (!obj.get("measurandLibraryList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto");
            entity.setMeasurandLibraryList(java_util_List.demarshall(obj.get("measurandLibraryList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.provider.MeasurandGroupDto", t);
        }
      }
      public String marshall(MeasurandGroupDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.MeasurandGroupDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(512).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.MeasurandGroupDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"measurandLibraryList\" : ").append(java_util_List.marshall(a0.getMeasurandLibraryList(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.provider.MeasurandGroupDto", ch_apkern_achilles_dto_shared_entity_laboratory_provider_MeasurandGroupDto);
    java_io_IOException = new Marshaller<IOException>() {
      private IOException[] EMPTY_ARRAY = new IOException[0];
      public IOException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return IOException.class;
      }
      public IOException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(IOException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          IOException entity = new IOException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.io.IOException", t);
        }
      }
      public String marshall(IOException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.io.IOException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.io.IOException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.io.IOException", java_io_IOException);
    ch_apkern_achilles_dto_shared_module_laboratory_MeasuringTypeEnum = new Marshaller<MeasuringTypeEnum>() {
      private MeasuringTypeEnum[] EMPTY_ARRAY = new MeasuringTypeEnum[0];
      public MeasuringTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasuringTypeEnum.class;
      }
      public MeasuringTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          MeasuringTypeEnum entity = obj != null ? Enum.valueOf(MeasuringTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(MeasuringTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.MeasuringTypeEnum", t);
        }
      }
      public String marshall(MeasuringTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.MeasuringTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.MeasuringTypeEnum", ch_apkern_achilles_dto_shared_module_laboratory_MeasuringTypeEnum);
    ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto = new Marshaller<TreatmentDto>() {
      private TreatmentDto[] EMPTY_ARRAY = new TreatmentDto[0];
      public TreatmentDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return TreatmentDto.class;
      }
      public TreatmentDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(TreatmentDto.class, objId);
          }
          TreatmentDto entity = new TreatmentDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("patient")) && (!obj.get("patient").isNull())) {
            entity.setPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("patient"), a1));
          }
          if ((obj.containsKey("date")) && (!obj.get("date").isNull())) {
            entity.setDate(java_util_Date.demarshall(obj.get("date"), a1));
          }
          if ((obj.containsKey("mandator")) && (!obj.get("mandator").isNull())) {
            entity.setMandator(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.demarshall(obj.get("mandator"), a1));
          }
          if ((obj.containsKey("title")) && (!obj.get("title").isNull())) {
            entity.setTitle(java_lang_String.demarshall(obj.get("title"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.patient.TreatmentDto", t);
        }
      }
      public String marshall(TreatmentDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.patient.TreatmentDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(6272).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.patient.TreatmentDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"patient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getPatient(), a1)).append(",").append("\"date\" : ").append(java_util_Date.marshall(a0.getDate(), a1)).append(",").append("\"mandator\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.marshall(a0.getMandator(), a1)).append(",").append("\"title\" : ").append(java_lang_String.marshall(a0.getTitle(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.patient.TreatmentDto", ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_AnalysisMeasuringDto = new Marshaller<AnalysisMeasuringDto>() {
      private AnalysisMeasuringDto[] EMPTY_ARRAY = new AnalysisMeasuringDto[0];
      public AnalysisMeasuringDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return AnalysisMeasuringDto.class;
      }
      public AnalysisMeasuringDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(AnalysisMeasuringDto.class, objId);
          }
          AnalysisMeasuringDto entity = new AnalysisMeasuringDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("analysisDate")) && (!obj.get("analysisDate").isNull())) {
            entity.setAnalysisDate(java_util_Date.demarshall(obj.get("analysisDate"), a1));
          }
          if ((obj.containsKey("newEntry")) && (!obj.get("newEntry").isNull())) {
            entity.setNewEntry(java_lang_Boolean.demarshall(obj.get("newEntry"), a1));
          }
          if ((obj.containsKey("receiveDate")) && (!obj.get("receiveDate").isNull())) {
            entity.setReceiveDate(java_util_Date.demarshall(obj.get("receiveDate"), a1));
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("authorized")) && (!obj.get("authorized").isNull())) {
            entity.setAuthorized(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("authorized"), a1));
          }
          if ((obj.containsKey("patient")) && (!obj.get("patient").isNull())) {
            entity.setPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("patient"), a1));
          }
          if ((obj.containsKey("patientIdentification")) && (!obj.get("patientIdentification").isNull())) {
            entity.setPatientIdentification(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.demarshall(obj.get("patientIdentification"), a1));
          }
          if ((obj.containsKey("mandator")) && (!obj.get("mandator").isNull())) {
            entity.setMandator(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.demarshall(obj.get("mandator"), a1));
          }
          if ((obj.containsKey("measuringDate")) && (!obj.get("measuringDate").isNull())) {
            entity.setMeasuringDate(java_util_Date.demarshall(obj.get("measuringDate"), a1));
          }
          if ((obj.containsKey("treatment")) && (!obj.get("treatment").isNull())) {
            entity.setTreatment(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.demarshall(obj.get("treatment"), a1));
          }
          if ((obj.containsKey("manual")) && (!obj.get("manual").isNull())) {
            entity.setManual(java_lang_Boolean.demarshall(obj.get("manual"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.AnalysisMeasuringDto", t);
        }
      }
      public String marshall(AnalysisMeasuringDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.AnalysisMeasuringDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(8704).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.AnalysisMeasuringDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"analysisDate\" : ").append(java_util_Date.marshall(a0.getAnalysisDate(), a1)).append(",").append("\"newEntry\" : ").append(java_lang_Boolean.marshall(a0.getNewEntry(), a1)).append(",").append("\"receiveDate\" : ").append(java_util_Date.marshall(a0.getReceiveDate(), a1)).append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"authorized\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getAuthorized(), a1)).append(",").append("\"patient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getPatient(), a1)).append(",").append("\"patientIdentification\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.marshall(a0.getPatientIdentification(), a1)).append(",").append("\"mandator\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.marshall(a0.getMandator(), a1)).append(",").append("\"measuringDate\" : ").append(java_util_Date.marshall(a0.getMeasuringDate(), a1)).append(",").append("\"treatment\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.marshall(a0.getTreatment(), a1)).append(",").append("\"manual\" : ").append(java_lang_Boolean.marshall(a0.getManual(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.AnalysisMeasuringDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_AnalysisMeasuringDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitGroupDto = new Marshaller<UnitGroupDto>() {
      private UnitGroupDto[] EMPTY_ARRAY = new UnitGroupDto[0];
      public UnitGroupDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return UnitGroupDto.class;
      }
      public UnitGroupDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(UnitGroupDto.class, objId);
          }
          UnitGroupDto entity = new UnitGroupDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupDto", t);
        }
      }
      public String marshall(UnitGroupDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitGroupDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto = new Marshaller<UnitDto>() {
      private UnitDto[] EMPTY_ARRAY = new UnitDto[0];
      public UnitDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return UnitDto.class;
      }
      public UnitDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(UnitDto.class, objId);
          }
          UnitDto entity = new UnitDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("masterFactor")) && (!obj.get("masterFactor").isNull())) {
            entity.setMasterFactor(java_math_BigDecimal.demarshall(obj.get("masterFactor"), a1));
          }
          if ((obj.containsKey("masterOffset")) && (!obj.get("masterOffset").isNull())) {
            entity.setMasterOffset(java_math_BigDecimal.demarshall(obj.get("masterOffset"), a1));
          }
          if ((obj.containsKey("unitGroup")) && (!obj.get("unitGroup").isNull())) {
            entity.setUnitGroup(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitGroupDto.demarshall(obj.get("unitGroup"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitDto", t);
        }
      }
      public String marshall(UnitDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1024).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"masterFactor\" : ").append(java_math_BigDecimal.marshall(a0.getMasterFactor(), a1)).append(",").append("\"masterOffset\" : ").append(java_math_BigDecimal.marshall(a0.getMasterOffset(), a1)).append(",").append("\"unitGroup\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitGroupDto.marshall(a0.getUnitGroup(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_MeasurandLibraryDto = new Marshaller<MeasurandLibraryDto>() {
      private MeasurandLibraryDto[] EMPTY_ARRAY = new MeasurandLibraryDto[0];
      public MeasurandLibraryDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasurandLibraryDto.class;
      }
      public MeasurandLibraryDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasurandLibraryDto.class, objId);
          }
          MeasurandLibraryDto entity = new MeasurandLibraryDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("diagram")) && (!obj.get("diagram").isNull())) {
            entity.setDiagram(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.demarshall(obj.get("diagram"), a1));
          }
          if ((obj.containsKey("division")) && (!obj.get("division").isNull())) {
            entity.setDivision(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.demarshall(obj.get("division"), a1));
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("modificated")) && (!obj.get("modificated").isNull())) {
            entity.setModificated(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("modificated"), a1));
          }
          if ((obj.containsKey("resultType")) && (!obj.get("resultType").isNull())) {
            entity.setResultType((ResultTypeDto) java_lang_Object.demarshall(ResultTypeDto.class, obj.get("resultType"), a1));
          }
          if ((obj.containsKey("sortCode")) && (!obj.get("sortCode").isNull())) {
            entity.setSortCode(java_lang_Integer.demarshall(obj.get("sortCode"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto", t);
        }
      }
      public String marshall(MeasurandLibraryDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3328).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"diagram\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.marshall(a0.getDiagram(), a1)).append(",").append("\"division\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.marshall(a0.getDivision(), a1)).append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"modificated\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getModificated(), a1)).append(",").append("\"resultType\" : ").append(java_lang_Object.marshall(a0.getResultType(), a1)).append(",").append("\"sortCode\" : ").append(java_lang_Integer.marshall(a0.getSortCode(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_MeasurandLibraryDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitGroupMapDto = new Marshaller<UnitGroupMapDto>() {
      private UnitGroupMapDto[] EMPTY_ARRAY = new UnitGroupMapDto[0];
      public UnitGroupMapDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return UnitGroupMapDto.class;
      }
      public UnitGroupMapDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(UnitGroupMapDto.class, objId);
          }
          UnitGroupMapDto entity = new UnitGroupMapDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("destinationUnit")) && (!obj.get("destinationUnit").isNull())) {
            entity.setDestinationUnit(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.demarshall(obj.get("destinationUnit"), a1));
          }
          if ((obj.containsKey("factor")) && (!obj.get("factor").isNull())) {
            entity.setFactor(java_lang_Integer.demarshall(obj.get("factor"), a1));
          }
          if ((obj.containsKey("measurandLibrary")) && (!obj.get("measurandLibrary").isNull())) {
            entity.setMeasurandLibrary((MeasurandLibraryDto) java_lang_Object.demarshall(MeasurandLibraryDto.class, obj.get("measurandLibrary"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupMapDto", t);
        }
      }
      public String marshall(UnitGroupMapDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupMapDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1536).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupMapDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"destinationUnit\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.marshall(a0.getDestinationUnit(), a1)).append(",").append("\"factor\" : ").append(java_lang_Integer.marshall(a0.getFactor(), a1)).append(",").append("\"measurandLibrary\" : ").append(java_lang_Object.marshall(a0.getMeasurandLibrary(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitGroupMapDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitGroupMapDto);
    ch_apkern_achilles_model_shared_entity_laboratory_LaboratoryTypeEnum = new Marshaller<LaboratoryTypeEnum>() {
      private LaboratoryTypeEnum[] EMPTY_ARRAY = new LaboratoryTypeEnum[0];
      public LaboratoryTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LaboratoryTypeEnum.class;
      }
      public LaboratoryTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          LaboratoryTypeEnum entity = obj != null ? Enum.valueOf(LaboratoryTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(LaboratoryTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.model.shared.entity.laboratory.LaboratoryTypeEnum", t);
        }
      }
      public String marshall(LaboratoryTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.laboratory.LaboratoryTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.model.shared.entity.laboratory.LaboratoryTypeEnum", ch_apkern_achilles_model_shared_entity_laboratory_LaboratoryTypeEnum);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto = new Marshaller<SelectionDto>() {
      private SelectionDto[] EMPTY_ARRAY = new SelectionDto[0];
      public SelectionDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SelectionDto.class;
      }
      public SelectionDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(SelectionDto.class, objId);
          }
          SelectionDto entity = new SelectionDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionDto", t);
        }
      }
      public String marshall(SelectionDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_MeasuringDto = new Marshaller<MeasuringDto>() {
      private MeasuringDto[] EMPTY_ARRAY = new MeasuringDto[0];
      public MeasuringDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasuringDto.class;
      }
      public MeasuringDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasuringDto.class, objId);
          }
          MeasuringDto entity = new MeasuringDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("measuringDate")) && (!obj.get("measuringDate").isNull())) {
            entity.setMeasuringDate(java_util_Date.demarshall(obj.get("measuringDate"), a1));
          }
          if ((obj.containsKey("treatment")) && (!obj.get("treatment").isNull())) {
            entity.setTreatment(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.demarshall(obj.get("treatment"), a1));
          }
          if ((obj.containsKey("manual")) && (!obj.get("manual").isNull())) {
            entity.setManual(java_lang_Boolean.demarshall(obj.get("manual"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.MeasuringDto", t);
        }
      }
      public String marshall(MeasuringDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.MeasuringDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(6784).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.MeasuringDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"measuringDate\" : ").append(java_util_Date.marshall(a0.getMeasuringDate(), a1)).append(",").append("\"treatment\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.marshall(a0.getTreatment(), a1)).append(",").append("\"manual\" : ").append(java_lang_Boolean.marshall(a0.getManual(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.MeasuringDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_MeasuringDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionValueDto = new Marshaller<SelectionValueDto>() {
      private SelectionValueDto[] EMPTY_ARRAY = new SelectionValueDto[0];
      public SelectionValueDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SelectionValueDto.class;
      }
      public SelectionValueDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(SelectionValueDto.class, objId);
          }
          SelectionValueDto entity = new SelectionValueDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("text")) && (!obj.get("text").isNull())) {
            entity.setText(java_lang_String.demarshall(obj.get("text"), a1));
          }
          if ((obj.containsKey("sortCode")) && (!obj.get("sortCode").isNull())) {
            entity.setSortCode(java_lang_Integer.demarshall(obj.get("sortCode"), a1));
          }
          if ((obj.containsKey("selection")) && (!obj.get("selection").isNull())) {
            entity.setSelection(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto.demarshall(obj.get("selection"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto", t);
        }
      }
      public String marshall(SelectionValueDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(896).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"text\" : ").append(java_lang_String.marshall(a0.getText(), a1)).append(",").append("\"sortCode\" : ").append(java_lang_Integer.marshall(a0.getSortCode(), a1)).append(",").append("\"selection\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto.marshall(a0.getSelection(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionValueDto);
    ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_reference_ReferenceRangeDetailSelectionValueDto = new Marshaller<ReferenceRangeDetailSelectionValueDto>() {
      private ReferenceRangeDetailSelectionValueDto[] EMPTY_ARRAY = new ReferenceRangeDetailSelectionValueDto[0];
      public ReferenceRangeDetailSelectionValueDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ReferenceRangeDetailSelectionValueDto.class;
      }
      public ReferenceRangeDetailSelectionValueDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ReferenceRangeDetailSelectionValueDto.class, objId);
          }
          ReferenceRangeDetailSelectionValueDto entity = new ReferenceRangeDetailSelectionValueDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("selectionValue")) && (!obj.get("selectionValue").isNull())) {
            entity.setSelectionValue(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionValueDto.demarshall(obj.get("selectionValue"), a1));
          }
          if ((obj.containsKey("active")) && (!obj.get("active").isNull())) {
            entity.setActive(java_lang_Boolean.demarshall(obj.get("active"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.reference.ReferenceRangeDetailSelectionValueDto", t);
        }
      }
      public String marshall(ReferenceRangeDetailSelectionValueDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.reference.ReferenceRangeDetailSelectionValueDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1152).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.reference.ReferenceRangeDetailSelectionValueDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"selectionValue\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionValueDto.marshall(a0.getSelectionValue(), a1)).append(",").append("\"active\" : ").append(java_lang_Boolean.marshall(a0.getActive(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.reference.ReferenceRangeDetailSelectionValueDto", ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_reference_ReferenceRangeDetailSelectionValueDto);
    ch_apkern_achilles_dto_shared_entity_core_ParameterSetDto = new Marshaller<ParameterSetDto>() {
      private ParameterSetDto[] EMPTY_ARRAY = new ParameterSetDto[0];
      public ParameterSetDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ParameterSetDto.class;
      }
      public ParameterSetDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ParameterSetDto.class, objId);
          }
          ParameterSetDto entity = new ParameterSetDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("type")) && (!obj.get("type").isNull())) {
            entity.setType(obj.get("type").isObject() != null ? Enum.valueOf(ParameterSetTypeEnum.class, obj.get("type").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("type").isString() != null ? Enum.valueOf(ParameterSetTypeEnum.class, obj.get("type").isString().stringValue()) : null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.ParameterSetDto", t);
        }
      }
      public String marshall(ParameterSetDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.ParameterSetDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.ParameterSetDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"type\" : ").append(a0.getType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.ParameterSetTypeEnum\",\"^EnumStringValue\":\"").append(a0.getType().name()).append("\"}") : "null").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.ParameterSetDto", ch_apkern_achilles_dto_shared_entity_core_ParameterSetDto);
    ch_apkern_achilles_dto_shared_entity_core_MetaFieldDeclarationDto = new Marshaller<MetaFieldDeclarationDto>() {
      private MetaFieldDeclarationDto[] EMPTY_ARRAY = new MetaFieldDeclarationDto[0];
      public MetaFieldDeclarationDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MetaFieldDeclarationDto.class;
      }
      public MetaFieldDeclarationDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MetaFieldDeclarationDto.class, objId);
          }
          MetaFieldDeclarationDto entity = new MetaFieldDeclarationDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("className")) && (!obj.get("className").isNull())) {
            entity.setClassName(java_lang_String.demarshall(obj.get("className"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("parameterSet")) && (!obj.get("parameterSet").isNull())) {
            entity.setParameterSet(ch_apkern_achilles_dto_shared_entity_core_ParameterSetDto.demarshall(obj.get("parameterSet"), a1));
          }
          if ((obj.containsKey("dataType")) && (!obj.get("dataType").isNull())) {
            entity.setDataType(obj.get("dataType").isObject() != null ? Enum.valueOf(MetaFieldTypeEnum.class, obj.get("dataType").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("dataType").isString() != null ? Enum.valueOf(MetaFieldTypeEnum.class, obj.get("dataType").isString().stringValue()) : null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.MetaFieldDeclarationDto", t);
        }
      }
      public String marshall(MetaFieldDeclarationDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.MetaFieldDeclarationDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1024).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.MetaFieldDeclarationDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"className\" : ").append(java_lang_String.marshall(a0.getClassName(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"parameterSet\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ParameterSetDto.marshall(a0.getParameterSet(), a1)).append(",").append("\"dataType\" : ").append(a0.getDataType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.MetaFieldTypeEnum\",\"^EnumStringValue\":\"").append(a0.getDataType().name()).append("\"}") : "null").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.MetaFieldDeclarationDto", ch_apkern_achilles_dto_shared_entity_core_MetaFieldDeclarationDto);
    ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto = new Marshaller<MetaFieldValueDto>() {
      private MetaFieldValueDto[] EMPTY_ARRAY = new MetaFieldValueDto[0];
      public MetaFieldValueDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MetaFieldValueDto.class;
      }
      public MetaFieldValueDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MetaFieldValueDto.class, objId);
          }
          MetaFieldValueDto entity = new MetaFieldValueDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("metaFieldDeclarationDto")) && (!obj.get("metaFieldDeclarationDto").isNull())) {
            entity.setMetaFieldDeclarationDto(ch_apkern_achilles_dto_shared_entity_core_MetaFieldDeclarationDto.demarshall(obj.get("metaFieldDeclarationDto"), a1));
          }
          if ((obj.containsKey("value")) && (!obj.get("value").isNull())) {
            entity.setValue(java_lang_String.demarshall(obj.get("value"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.MetaFieldValueDto", t);
        }
      }
      public String marshall(MetaFieldValueDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.MetaFieldValueDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1408).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.MetaFieldValueDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"metaFieldDeclarationDto\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MetaFieldDeclarationDto.marshall(a0.getMetaFieldDeclarationDto(), a1)).append(",").append("\"value\" : ").append(java_lang_String.marshall(a0.getValue(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.MetaFieldValueDto", ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto);
    ch_apkern_achilles_dto_shared_module_patient_SuggestionDtoList = new Marshaller<SuggestionDtoList>() {
      private SuggestionDtoList[] EMPTY_ARRAY = new SuggestionDtoList[0];
      public SuggestionDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SuggestionDtoList.class;
      }
      public SuggestionDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(SuggestionDtoList.class, objId);
          }
          SuggestionDtoList entity = new SuggestionDtoList();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("suggestionList")) && (!obj.get("suggestionList").isNull())) {
            a1.setAssumedElementType("java.lang.String");
            entity.setSuggestionList(java_util_List.demarshall(obj.get("suggestionList"), a1));
            a1.setAssumedElementType(null);
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.patient.SuggestionDtoList", t);
        }
      }
      public String marshall(SuggestionDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.patient.SuggestionDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.patient.SuggestionDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"suggestionList\" : ").append(java_util_List.marshall(a0.getSuggestionList(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.patient.SuggestionDtoList", ch_apkern_achilles_dto_shared_module_patient_SuggestionDtoList);
    ch_apkern_achilles_api_client_exception_ValidationException = new Marshaller<ValidationException>() {
      private ValidationException[] EMPTY_ARRAY = new ValidationException[0];
      public ValidationException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ValidationException.class;
      }
      public ValidationException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ValidationException.class, objId);
          }
          ValidationException entity = new ValidationException();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("validationResultSet")) && (!obj.get("validationResultSet").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.api.shared.validation.ValidationResult");
            entity.setValidationResultSet(java_util_Set.demarshall(obj.get("validationResultSet"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.api.client.exception.ValidationException", t);
        }
      }
      public String marshall(ValidationException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.api.client.exception.ValidationException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(4096).append("{\"^EncodedType\":\"ch.apkern.achilles.api.client.exception.ValidationException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"validationResultSet\" : ").append(java_util_Set.marshall(a0.getValidationResultSet(), a1)).append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.api.client.exception.ValidationException", ch_apkern_achilles_api_client_exception_ValidationException);
    ch_apkern_achilles_api_shared_validation_ExceptionTypeEnum$Info = new Marshaller<Info>() {
      private Info[] EMPTY_ARRAY = new Info[0];
      public Info[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return Info.class;
      }
      public Info demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          Info entity = obj != null ? Enum.valueOf(Info.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(Info.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum$Info", t);
        }
      }
      public String marshall(Info a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum$Info\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum$Info", ch_apkern_achilles_api_shared_validation_ExceptionTypeEnum$Info);
    marshallers.put("ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum.Info", ch_apkern_achilles_api_shared_validation_ExceptionTypeEnum$Info);
    java_lang_StringIndexOutOfBoundsException = new Marshaller<StringIndexOutOfBoundsException>() {
      private StringIndexOutOfBoundsException[] EMPTY_ARRAY = new StringIndexOutOfBoundsException[0];
      public StringIndexOutOfBoundsException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return StringIndexOutOfBoundsException.class;
      }
      public StringIndexOutOfBoundsException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(StringIndexOutOfBoundsException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          StringIndexOutOfBoundsException entity = new StringIndexOutOfBoundsException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.StringIndexOutOfBoundsException", t);
        }
      }
      public String marshall(StringIndexOutOfBoundsException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.StringIndexOutOfBoundsException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.StringIndexOutOfBoundsException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.StringIndexOutOfBoundsException", java_lang_StringIndexOutOfBoundsException);
    java_util_EmptyStackException = new Marshaller<EmptyStackException>() {
      private EmptyStackException[] EMPTY_ARRAY = new EmptyStackException[0];
      public EmptyStackException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return EmptyStackException.class;
      }
      public EmptyStackException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(EmptyStackException.class, objId);
          }
          EmptyStackException entity = new EmptyStackException();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.util.EmptyStackException", t);
        }
      }
      public String marshall(EmptyStackException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.util.EmptyStackException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.util.EmptyStackException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.util.EmptyStackException", java_util_EmptyStackException);
    ch_apkern_achilles_model_shared_entity_analysis_result_reference_AgeUnitEnum = new Marshaller<AgeUnitEnum>() {
      private AgeUnitEnum[] EMPTY_ARRAY = new AgeUnitEnum[0];
      public AgeUnitEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return AgeUnitEnum.class;
      }
      public AgeUnitEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          AgeUnitEnum entity = obj != null ? Enum.valueOf(AgeUnitEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(AgeUnitEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.model.shared.entity.analysis.result.reference.AgeUnitEnum", t);
        }
      }
      public String marshall(AgeUnitEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.analysis.result.reference.AgeUnitEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.model.shared.entity.analysis.result.reference.AgeUnitEnum", ch_apkern_achilles_model_shared_entity_analysis_result_reference_AgeUnitEnum);
    ch_apkern_achilles_concurrency_client_internal_transfer_LockBroadcastEventTransfer = new Marshaller<LockBroadcastEventTransfer>() {
      private LockBroadcastEventTransfer[] EMPTY_ARRAY = new LockBroadcastEventTransfer[0];
      public LockBroadcastEventTransfer[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LockBroadcastEventTransfer.class;
      }
      public LockBroadcastEventTransfer demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LockBroadcastEventTransfer.class, objId);
          }
          final ClientInstanceId c0 = ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.demarshall(obj.get("clientInstanceId"), a1);
          final EventCase c1 = obj.get("eventCase").isObject() != null ? Enum.valueOf(EventCase.class, obj.get("eventCase").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("eventCase").isString() != null ? Enum.valueOf(EventCase.class, obj.get("eventCase").isString().stringValue()) : null;
          final String c2 = java_lang_String.demarshall(obj.get("editor"), a1);
          a1.setAssumedElementType("ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer$LockBroadcastEventEntry");
          final Set<LockBroadcastEventEntry> c3 = java_util_Set.demarshall(obj.get("lockBroadcastEventEntries"), a1);
          a1.setAssumedElementType(null);
          LockBroadcastEventTransfer entity = new LockBroadcastEventTransfer(c0, c1, c2, c3);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer", t);
        }
      }
      public String marshall(LockBroadcastEventTransfer a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(768).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"clientInstanceId\" : ").append(ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.marshall(a0.getClientInstanceId(), a1)).append(",").append("\"eventCase\" : ").append(a0.getEventCase() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer$EventCase\",\"^EnumStringValue\":\"").append(a0.getEventCase().name()).append("\"}") : "null").append(",").append("\"editor\" : ").append(java_lang_String.marshall(a0.getEditor(), a1)).append(",").append("\"lockBroadcastEventEntries\" : ").append(java_util_Set.marshall(a0.getLockBroadcastEventEntries(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer", ch_apkern_achilles_concurrency_client_internal_transfer_LockBroadcastEventTransfer);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_MeasurandReferenceDto = new Marshaller<MeasurandReferenceDto>() {
      private MeasurandReferenceDto[] EMPTY_ARRAY = new MeasurandReferenceDto[0];
      public MeasurandReferenceDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasurandReferenceDto.class;
      }
      public MeasurandReferenceDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasurandReferenceDto.class, objId);
          }
          MeasurandReferenceDto entity = new MeasurandReferenceDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("selectionInToleranceList")) && (!obj.get("selectionInToleranceList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto");
            entity.setSelectionInToleranceList(java_util_List.demarshall(obj.get("selectionInToleranceList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("lowerBound")) && (!obj.get("lowerBound").isNull())) {
            entity.setLowerBound(java_math_BigDecimal.demarshall(obj.get("lowerBound"), a1));
          }
          if ((obj.containsKey("upperBound")) && (!obj.get("upperBound").isNull())) {
            entity.setUpperBound(java_math_BigDecimal.demarshall(obj.get("upperBound"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandReferenceDto", t);
        }
      }
      public String marshall(MeasurandReferenceDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandReferenceDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandReferenceDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"selectionInToleranceList\" : ").append(java_util_List.marshall(a0.getSelectionInToleranceList(), a1)).append(",").append("\"lowerBound\" : ").append(java_math_BigDecimal.marshall(a0.getLowerBound(), a1)).append(",").append("\"upperBound\" : ").append(java_math_BigDecimal.marshall(a0.getUpperBound(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandReferenceDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_MeasurandReferenceDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_ResultDto = new Marshaller<ResultDto>() {
      private ResultDto[] EMPTY_ARRAY = new ResultDto[0];
      public ResultDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ResultDto.class;
      }
      public ResultDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ResultDto.class, objId);
          }
          ResultDto entity = new ResultDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("measuring")) && (!obj.get("measuring").isNull())) {
            entity.setMeasuring((MeasuringDto) java_lang_Object.demarshall(MeasuringDto.class, obj.get("measuring"), a1));
          }
          if ((obj.containsKey("measurandLibrary")) && (!obj.get("measurandLibrary").isNull())) {
            entity.setMeasurandLibrary((MeasurandLibraryDto) java_lang_Object.demarshall(MeasurandLibraryDto.class, obj.get("measurandLibrary"), a1));
          }
          if ((obj.containsKey("measurandReference")) && (!obj.get("measurandReference").isNull())) {
            entity.setMeasurandReference((MeasurandReferenceDto) java_lang_Object.demarshall(MeasurandReferenceDto.class, obj.get("measurandReference"), a1));
          }
          if ((obj.containsKey("chargeResult")) && (!obj.get("chargeResult").isNull())) {
            entity.setChargeResult(java_lang_Boolean.demarshall(obj.get("chargeResult"), a1));
          }
          if ((obj.containsKey("visible")) && (!obj.get("visible").isNull())) {
            entity.setVisible(java_lang_Boolean.demarshall(obj.get("visible"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.ResultDto", t);
        }
      }
      public String marshall(ResultDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.ResultDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(896).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.ResultDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"measuring\" : ").append(java_lang_Object.marshall(a0.getMeasuring(), a1)).append(",").append("\"measurandLibrary\" : ").append(java_lang_Object.marshall(a0.getMeasurandLibrary(), a1)).append(",").append("\"measurandReference\" : ").append(java_lang_Object.marshall(a0.getMeasurandReference(), a1)).append(",").append("\"chargeResult\" : ").append(java_lang_Boolean.marshall(a0.getChargeResult(), a1)).append(",").append("\"visible\" : ").append(java_lang_Boolean.marshall(a0.getVisible(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.ResultDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_ResultDto);
    ch_apkern_achilles_dto_shared_module_laboratory_DetailResultDto = new Marshaller<DetailResultDto>() {
      private DetailResultDto[] EMPTY_ARRAY = new DetailResultDto[0];
      public DetailResultDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return DetailResultDto.class;
      }
      public DetailResultDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(DetailResultDto.class, objId);
          }
          DetailResultDto entity = new DetailResultDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("resultDto")) && (!obj.get("resultDto").isNull())) {
            entity.setResultDto((ResultDto) java_lang_Object.demarshall(ResultDto.class, obj.get("resultDto"), a1));
          }
          if ((obj.containsKey("referenceArrow")) && (!obj.get("referenceArrow").isNull())) {
            entity.setReferenceArrow(obj.get("referenceArrow").isObject() != null ? Enum.valueOf(ReferenceArrowEnum.class, obj.get("referenceArrow").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("referenceArrow").isString() != null ? Enum.valueOf(ReferenceArrowEnum.class, obj.get("referenceArrow").isString().stringValue()) : null);
          }
          if ((obj.containsKey("remarksAvailable")) && (!obj.get("remarksAvailable").isNull())) {
            entity.setRemarksAvailable(java_lang_Boolean.demarshall(obj.get("remarksAvailable"), a1));
          }
          if ((obj.containsKey("referenceCell")) && (!obj.get("referenceCell").isNull())) {
            entity.setReferenceCell(java_lang_String.demarshall(obj.get("referenceCell"), a1));
          }
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(java_lang_String.demarshall(obj.get("unit"), a1));
          }
          if ((obj.containsKey("lowerBound")) && (!obj.get("lowerBound").isNull())) {
            entity.setLowerBound(java_math_BigDecimal.demarshall(obj.get("lowerBound"), a1));
          }
          if ((obj.containsKey("upperBound")) && (!obj.get("upperBound").isNull())) {
            entity.setUpperBound(java_math_BigDecimal.demarshall(obj.get("upperBound"), a1));
          }
          if ((obj.containsKey("selectionInToleranceList")) && (!obj.get("selectionInToleranceList").isNull())) {
            a1.setAssumedMapKeyType("java.lang.String");
            a1.setAssumedMapValueType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto");
            entity.setSelectionInToleranceList((Map) java_util_Map.demarshall(obj.get("selectionInToleranceList"), a1));
            a1.setAssumedMapKeyType(null);
            a1.setAssumedMapValueType(null);
          }
          if ((obj.containsKey("selectionList")) && (!obj.get("selectionList").isNull())) {
            a1.setAssumedMapKeyType("java.lang.String");
            a1.setAssumedMapValueType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto");
            entity.setSelectionList((Map) java_util_Map.demarshall(obj.get("selectionList"), a1));
            a1.setAssumedMapKeyType(null);
            a1.setAssumedMapValueType(null);
          }
          if ((obj.containsKey("tariffCode")) && (!obj.get("tariffCode").isNull())) {
            entity.setTariffCode(java_lang_String.demarshall(obj.get("tariffCode"), a1));
          }
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("library")) && (!obj.get("library").isNull())) {
            entity.setLibrary(java_lang_String.demarshall(obj.get("library"), a1));
          }
          if ((obj.containsKey("remarksAvailableTooltip")) && (!obj.get("remarksAvailableTooltip").isNull())) {
            entity.setRemarksAvailableTooltip(java_lang_String.demarshall(obj.get("remarksAvailableTooltip"), a1));
          }
          if ((obj.containsKey("remark")) && (!obj.get("remark").isNull())) {
            entity.setRemark(java_lang_String.demarshall(obj.get("remark"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDto", t);
        }
      }
      public String marshall(DetailResultDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1920).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"resultDto\" : ").append(java_lang_Object.marshall(a0.getResultDto(), a1)).append(",").append("\"referenceArrow\" : ").append(a0.getReferenceArrow() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.ReferenceArrowEnum\",\"^EnumStringValue\":\"").append(a0.getReferenceArrow().name()).append("\"}") : "null").append(",").append("\"remarksAvailable\" : ").append(java_lang_Boolean.marshall(a0.getRemarksAvailable(), a1)).append(",").append("\"referenceCell\" : ").append(java_lang_String.marshall(a0.getReferenceCell(), a1)).append(",").append("\"unit\" : ").append(java_lang_String.marshall(a0.getUnit(), a1)).append(",").append("\"lowerBound\" : ").append(java_math_BigDecimal.marshall(a0.getLowerBound(), a1)).append(",").append("\"upperBound\" : ").append(java_math_BigDecimal.marshall(a0.getUpperBound(), a1)).append(",").append("\"selectionInToleranceList\" : ").append(java_util_Map.marshall(a0.getSelectionInToleranceList(), a1)).append(",").append("\"selectionList\" : ").append(java_util_Map.marshall(a0.getSelectionList(), a1)).append(",").append("\"tariffCode\" : ").append(java_lang_String.marshall(a0.getTariffCode(), a1)).append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"library\" : ").append(java_lang_String.marshall(a0.getLibrary(), a1)).append(",").append("\"remarksAvailableTooltip\" : ").append(java_lang_String.marshall(a0.getRemarksAvailableTooltip(), a1)).append(",").append("\"remark\" : ").append(java_lang_String.marshall(a0.getRemark(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDto", ch_apkern_achilles_dto_shared_module_laboratory_DetailResultDto);
    java_lang_NullPointerException = new Marshaller<NullPointerException>() {
      private NullPointerException[] EMPTY_ARRAY = new NullPointerException[0];
      public NullPointerException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return NullPointerException.class;
      }
      public NullPointerException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(NullPointerException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          NullPointerException entity = new NullPointerException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.NullPointerException", t);
        }
      }
      public String marshall(NullPointerException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.NullPointerException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.NullPointerException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.NullPointerException", java_lang_NullPointerException);
    ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceTypeDto = new Marshaller<DeviceTypeDto>() {
      private DeviceTypeDto[] EMPTY_ARRAY = new DeviceTypeDto[0];
      public DeviceTypeDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return DeviceTypeDto.class;
      }
      public DeviceTypeDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(DeviceTypeDto.class, objId);
          }
          DeviceTypeDto entity = new DeviceTypeDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("measurandLibraryList")) && (!obj.get("measurandLibraryList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto");
            entity.setMeasurandLibraryList(java_util_List.demarshall(obj.get("measurandLibraryList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceTypeDto", t);
        }
      }
      public String marshall(DeviceTypeDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceTypeDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(512).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceTypeDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"measurandLibraryList\" : ").append(java_util_List.marshall(a0.getMeasurandLibraryList(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceTypeDto", ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceTypeDto);
    ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryDeviceProviderDto = new Marshaller<LaboratoryDeviceProviderDto>() {
      private LaboratoryDeviceProviderDto[] EMPTY_ARRAY = new LaboratoryDeviceProviderDto[0];
      public LaboratoryDeviceProviderDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LaboratoryDeviceProviderDto.class;
      }
      public LaboratoryDeviceProviderDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LaboratoryDeviceProviderDto.class, objId);
          }
          LaboratoryDeviceProviderDto entity = new LaboratoryDeviceProviderDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("active")) && (!obj.get("active").isNull())) {
            entity.setActive(java_lang_Boolean.demarshall(obj.get("active"), a1));
          }
          if ((obj.containsKey("serialNumber")) && (!obj.get("serialNumber").isNull())) {
            entity.setSerialNumber(java_lang_String.demarshall(obj.get("serialNumber"), a1));
          }
          if ((obj.containsKey("deviceType")) && (!obj.get("deviceType").isNull())) {
            entity.setDeviceType(ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceTypeDto.demarshall(obj.get("deviceType"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDto", t);
        }
      }
      public String marshall(LaboratoryDeviceProviderDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1152).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"active\" : ").append(java_lang_Boolean.marshall(a0.getActive(), a1)).append(",").append("\"serialNumber\" : ").append(java_lang_String.marshall(a0.getSerialNumber(), a1)).append(",").append("\"deviceType\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceTypeDto.marshall(a0.getDeviceType(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDto", ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryDeviceProviderDto);
    ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto = new Marshaller<MeasuringStatisticalReferenceValuesDto>() {
      private MeasuringStatisticalReferenceValuesDto[] EMPTY_ARRAY = new MeasuringStatisticalReferenceValuesDto[0];
      public MeasuringStatisticalReferenceValuesDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasuringStatisticalReferenceValuesDto.class;
      }
      public MeasuringStatisticalReferenceValuesDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasuringStatisticalReferenceValuesDto.class, objId);
          }
          MeasuringStatisticalReferenceValuesDto entity = new MeasuringStatisticalReferenceValuesDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("tolerance")) && (!obj.get("tolerance").isNull())) {
            entity.setTolerance(java_math_BigDecimal.demarshall(obj.get("tolerance"), a1));
          }
          if ((obj.containsKey("nominalValue")) && (!obj.get("nominalValue").isNull())) {
            entity.setNominalValue(java_math_BigDecimal.demarshall(obj.get("nominalValue"), a1));
          }
          if ((obj.containsKey("variation")) && (!obj.get("variation").isNull())) {
            entity.setVariation(java_math_BigDecimal.demarshall(obj.get("variation"), a1));
          }
          if ((obj.containsKey("standardDeviation")) && (!obj.get("standardDeviation").isNull())) {
            entity.setStandardDeviation(java_math_BigDecimal.demarshall(obj.get("standardDeviation"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalReferenceValuesDto", t);
        }
      }
      public String marshall(MeasuringStatisticalReferenceValuesDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalReferenceValuesDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalReferenceValuesDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"tolerance\" : ").append(java_math_BigDecimal.marshall(a0.getTolerance(), a1)).append(",").append("\"nominalValue\" : ").append(java_math_BigDecimal.marshall(a0.getNominalValue(), a1)).append(",").append("\"variation\" : ").append(java_math_BigDecimal.marshall(a0.getVariation(), a1)).append(",").append("\"standardDeviation\" : ").append(java_math_BigDecimal.marshall(a0.getStandardDeviation(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalReferenceValuesDto", ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto);
    ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalValuesDto = new Marshaller<MeasuringStatisticalValuesDto>() {
      private MeasuringStatisticalValuesDto[] EMPTY_ARRAY = new MeasuringStatisticalValuesDto[0];
      public MeasuringStatisticalValuesDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasuringStatisticalValuesDto.class;
      }
      public MeasuringStatisticalValuesDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasuringStatisticalValuesDto.class, objId);
          }
          MeasuringStatisticalValuesDto entity = new MeasuringStatisticalValuesDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("valuesQualab")) && (!obj.get("valuesQualab").isNull())) {
            entity.setValuesQualab(ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto.demarshall(obj.get("valuesQualab"), a1));
          }
          if ((obj.containsKey("valuesManufacturer")) && (!obj.get("valuesManufacturer").isNull())) {
            entity.setValuesManufacturer(ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto.demarshall(obj.get("valuesManufacturer"), a1));
          }
          if ((obj.containsKey("values20Points")) && (!obj.get("values20Points").isNull())) {
            entity.setValues20Points(ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto.demarshall(obj.get("values20Points"), a1));
          }
          if ((obj.containsKey("valuesAllPoints")) && (!obj.get("valuesAllPoints").isNull())) {
            entity.setValuesAllPoints(ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto.demarshall(obj.get("valuesAllPoints"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalValuesDto", t);
        }
      }
      public String marshall(MeasuringStatisticalValuesDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalValuesDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1152).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalValuesDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"valuesQualab\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto.marshall(a0.getValuesQualab(), a1)).append(",").append("\"valuesManufacturer\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto.marshall(a0.getValuesManufacturer(), a1)).append(",").append("\"values20Points\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto.marshall(a0.getValues20Points(), a1)).append(",").append("\"valuesAllPoints\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalReferenceValuesDto.marshall(a0.getValuesAllPoints(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalValuesDto", ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringStatisticalValuesDto);
    org_jboss_errai_bus_client_api_base_TransportIOException = new Marshaller<TransportIOException>() {
      private TransportIOException[] EMPTY_ARRAY = new TransportIOException[0];
      public TransportIOException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return TransportIOException.class;
      }
      public TransportIOException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(TransportIOException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          final Integer c1 = java_lang_Integer.demarshall(obj.get("errorCode"), a1);
          final String c2 = java_lang_String.demarshall(obj.get("errorMessage"), a1);
          TransportIOException entity = new TransportIOException(c0, c1, c2);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: org.jboss.errai.bus.client.api.base.TransportIOException", t);
        }
      }
      public String marshall(TransportIOException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"org.jboss.errai.bus.client.api.base.TransportIOException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(4224).append("{\"^EncodedType\":\"org.jboss.errai.bus.client.api.base.TransportIOException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"errorCode\" : ").append(java_lang_Integer.marshall(a0.errorCode(), a1)).append(",").append("\"errorMessage\" : ").append(java_lang_String.marshall(a0.getErrorMessage(), a1)).append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("org.jboss.errai.bus.client.api.base.TransportIOException", org_jboss_errai_bus_client_api_base_TransportIOException);
    ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryDeviceQualityMeasuringDtoList = new Marshaller<LaboratoryDeviceQualityMeasuringDtoList>() {
      private LaboratoryDeviceQualityMeasuringDtoList[] EMPTY_ARRAY = new LaboratoryDeviceQualityMeasuringDtoList[0];
      public LaboratoryDeviceQualityMeasuringDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LaboratoryDeviceQualityMeasuringDtoList.class;
      }
      public LaboratoryDeviceQualityMeasuringDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LaboratoryDeviceQualityMeasuringDtoList.class, objId);
          }
          LaboratoryDeviceQualityMeasuringDtoList entity = new LaboratoryDeviceQualityMeasuringDtoList();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("measuringList")) && (!obj.get("measuringList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.DeviceQualityMeasuringDto");
            entity.setMeasuringList(java_util_List.demarshall(obj.get("measuringList"), a1));
            a1.setAssumedElementType(null);
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuringDtoList", t);
        }
      }
      public String marshall(LaboratoryDeviceQualityMeasuringDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuringDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuringDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"measuringList\" : ").append(java_util_List.marshall(a0.getMeasuringList(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuringDtoList", ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryDeviceQualityMeasuringDtoList);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_AgeDto = new Marshaller<AgeDto>() {
      private AgeDto[] EMPTY_ARRAY = new AgeDto[0];
      public AgeDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return AgeDto.class;
      }
      public AgeDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(AgeDto.class, objId);
          }
          AgeDto entity = new AgeDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(obj.get("unit").isObject() != null ? Enum.valueOf(AgeUnitEnum.class, obj.get("unit").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("unit").isString() != null ? Enum.valueOf(AgeUnitEnum.class, obj.get("unit").isString().stringValue()) : null);
          }
          if ((obj.containsKey("lower")) && (!obj.get("lower").isNull())) {
            entity.setLower(java_lang_Long.demarshall(obj.get("lower"), a1));
          }
          if ((obj.containsKey("upper")) && (!obj.get("upper").isNull())) {
            entity.setUpper(java_lang_Long.demarshall(obj.get("upper"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.AgeDto", t);
        }
      }
      public String marshall(AgeDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.AgeDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(512).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.AgeDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"unit\" : ").append(a0.getUnit() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.analysis.result.reference.AgeUnitEnum\",\"^EnumStringValue\":\"").append(a0.getUnit().name()).append("\"}") : "null").append(",").append("\"lower\" : ").append(java_lang_Long.marshall(a0.getLower(), a1)).append(",").append("\"upper\" : ").append(java_lang_Long.marshall(a0.getUpper(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.AgeDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_AgeDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_BaseReferenceDto = new Marshaller<BaseReferenceDto>() {
      private BaseReferenceDto[] EMPTY_ARRAY = new BaseReferenceDto[0];
      public BaseReferenceDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return BaseReferenceDto.class;
      }
      public BaseReferenceDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(BaseReferenceDto.class, objId);
          }
          BaseReferenceDto entity = new BaseReferenceDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("age")) && (!obj.get("age").isNull())) {
            entity.setAge(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_AgeDto.demarshall(obj.get("age"), a1));
          }
          if ((obj.containsKey("sex")) && (!obj.get("sex").isNull())) {
            entity.setSex(obj.get("sex").isObject() != null ? Enum.valueOf(SexEnum.class, obj.get("sex").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("sex").isString() != null ? Enum.valueOf(SexEnum.class, obj.get("sex").isString().stringValue()) : null);
          }
          if ((obj.containsKey("selectionInToleranceList")) && (!obj.get("selectionInToleranceList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto");
            entity.setSelectionInToleranceList(java_util_List.demarshall(obj.get("selectionInToleranceList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("lowerBound")) && (!obj.get("lowerBound").isNull())) {
            entity.setLowerBound(java_math_BigDecimal.demarshall(obj.get("lowerBound"), a1));
          }
          if ((obj.containsKey("upperBound")) && (!obj.get("upperBound").isNull())) {
            entity.setUpperBound(java_math_BigDecimal.demarshall(obj.get("upperBound"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.BaseReferenceDto", t);
        }
      }
      public String marshall(BaseReferenceDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.BaseReferenceDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1280).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.BaseReferenceDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"age\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_AgeDto.marshall(a0.getAge(), a1)).append(",").append("\"sex\" : ").append(a0.getSex() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.SexEnum\",\"^EnumStringValue\":\"").append(a0.getSex().name()).append("\"}") : "null").append(",").append("\"selectionInToleranceList\" : ").append(java_util_List.marshall(a0.getSelectionInToleranceList(), a1)).append(",").append("\"lowerBound\" : ").append(java_math_BigDecimal.marshall(a0.getLowerBound(), a1)).append(",").append("\"upperBound\" : ").append(java_math_BigDecimal.marshall(a0.getUpperBound(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.BaseReferenceDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_BaseReferenceDto);
    ch_apkern_achilles_api_shared_validation_ValidationResult = new Marshaller<ValidationResult>() {
      private ValidationResult[] EMPTY_ARRAY = new ValidationResult[0];
      public ValidationResult[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ValidationResult.class;
      }
      public ValidationResult demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ValidationResult.class, objId);
          }
          ValidationResult entity = new ValidationResult();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("fieldId")) && (!obj.get("fieldId").isNull())) {
            entity.setFieldId(java_lang_String.demarshall(obj.get("fieldId"), a1));
          }
          if ((obj.containsKey("fieldname")) && (!obj.get("fieldname").isNull())) {
            _1626942963_fieldname(entity, java_lang_String.demarshall(obj.get("fieldname"), a1));
          }
          if ((obj.containsKey("validationState")) && (!obj.get("validationState").isNull())) {
            entity.setValidationState(obj.get("validationState").isObject() != null ? Enum.valueOf(ValidationStateEnum.class, obj.get("validationState").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("validationState").isString() != null ? Enum.valueOf(ValidationStateEnum.class, obj.get("validationState").isString().stringValue()) : null);
          }
          if ((obj.containsKey("message")) && (!obj.get("message").isNull())) {
            entity.setMessage(java_lang_String.demarshall(obj.get("message"), a1));
          }
          if ((obj.containsKey("info")) && (!obj.get("info").isNull())) {
            entity.setInfo((TranslatableEnum) java_lang_Object.demarshall(TranslatableEnum.class, obj.get("info"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.api.shared.validation.ValidationResult", t);
        }
      }
      public String marshall(ValidationResult a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.api.shared.validation.ValidationResult\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(768).append("{\"^EncodedType\":\"ch.apkern.achilles.api.shared.validation.ValidationResult\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"fieldId\" : ").append(java_lang_String.marshall(a0.getFieldId(), a1)).append(",").append("\"fieldname\" : ").append(java_lang_String.marshall(a0.getFieldname(), a1)).append(",").append("\"validationState\" : ").append(a0.getValidationState() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.api.shared.validation.ValidationStateEnum\",\"^EnumStringValue\":\"").append(a0.getValidationState().name()).append("\"}") : "null").append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"info\" : ").append(java_lang_Object.marshall(a0.getInfo(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.api.shared.validation.ValidationResult", ch_apkern_achilles_api_shared_validation_ValidationResult);
    ch_apkern_achilles_dto_shared_module_laboratory_ReferenceArrowEnum = new Marshaller<ReferenceArrowEnum>() {
      private ReferenceArrowEnum[] EMPTY_ARRAY = new ReferenceArrowEnum[0];
      public ReferenceArrowEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ReferenceArrowEnum.class;
      }
      public ReferenceArrowEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          ReferenceArrowEnum entity = obj != null ? Enum.valueOf(ReferenceArrowEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(ReferenceArrowEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.ReferenceArrowEnum", t);
        }
      }
      public String marshall(ReferenceArrowEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.ReferenceArrowEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.ReferenceArrowEnum", ch_apkern_achilles_dto_shared_module_laboratory_ReferenceArrowEnum);
    ch_apkern_achilles_dto_shared_module_core_preferences_user_UserManagementDto = new Marshaller<UserManagementDto>() {
      private UserManagementDto[] EMPTY_ARRAY = new UserManagementDto[0];
      public UserManagementDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return UserManagementDto.class;
      }
      public UserManagementDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(UserManagementDto.class, objId);
          }
          UserManagementDto entity = new UserManagementDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("users")) && (!obj.get("users").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.core.UserDto");
            entity.setUsers(java_util_List.demarshall(obj.get("users"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("list")) && (!obj.get("list").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.core.GroupDto");
            _1034140142_list(entity, java_util_List.demarshall(obj.get("list"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("currentUser")) && (!obj.get("currentUser").isNull())) {
            entity.setCurrentUser(ch_apkern_achilles_dto_shared_entity_core_UserDto.demarshall(obj.get("currentUser"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.core.preferences.user.UserManagementDto", t);
        }
      }
      public String marshall(UserManagementDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.user.UserManagementDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1536).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.user.UserManagementDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"users\" : ").append(java_util_List.marshall(a0.getUsers(), a1)).append(",").append("\"list\" : ").append(java_util_List.marshall(_1034140142_list(a0), a1)).append(",").append("\"currentUser\" : ").append(ch_apkern_achilles_dto_shared_entity_core_UserDto.marshall(a0.getCurrentUser(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.core.preferences.user.UserManagementDto", ch_apkern_achilles_dto_shared_module_core_preferences_user_UserManagementDto);
    ch_apkern_achilles_dto_shared_module_search_SearchCriteriaDto = new Marshaller<SearchCriteriaDto>() {
      private SearchCriteriaDto[] EMPTY_ARRAY = new SearchCriteriaDto[0];
      public SearchCriteriaDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SearchCriteriaDto.class;
      }
      public SearchCriteriaDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(SearchCriteriaDto.class, objId);
          }
          SearchCriteriaDto entity = new SearchCriteriaDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("sortProperty")) && (!obj.get("sortProperty").isNull())) {
            entity.setSortProperty((SearchCriterionEnum) java_lang_Object.demarshall(SearchCriterionEnum.class, obj.get("sortProperty"), a1));
          }
          if ((obj.containsKey("sortOrderAsc")) && (!obj.get("sortOrderAsc").isNull())) {
            entity.setSortOrderAsc(java_lang_Boolean.demarshall(obj.get("sortOrderAsc"), a1));
          }
          if ((obj.containsKey("searchCriteria")) && (!obj.get("searchCriteria").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.module.search.SearchParameter");
            entity.setSearchCriteria(java_util_List.demarshall(obj.get("searchCriteria"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("resultLimit")) && (!obj.get("resultLimit").isNull())) {
            entity.setResultLimit(java_lang_Integer.demarshall(obj.get("resultLimit"), a1));
          }
          if ((obj.containsKey("currentPage")) && (!obj.get("currentPage").isNull())) {
            entity.setCurrentPage(java_lang_Integer.demarshall(obj.get("currentPage"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.search.SearchCriteriaDto", t);
        }
      }
      public String marshall(SearchCriteriaDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.search.SearchCriteriaDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(768).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.search.SearchCriteriaDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"sortProperty\" : ").append(java_lang_Object.marshall(a0.getSortProperty(), a1)).append(",").append("\"sortOrderAsc\" : ").append(java_lang_Boolean.marshall(a0.getSortOrderAsc(), a1)).append(",").append("\"searchCriteria\" : ").append(java_util_List.marshall(a0.getSearchCriteria(), a1)).append(",").append("\"resultLimit\" : ").append(java_lang_Integer.marshall(a0.getResultLimit(), a1)).append(",").append("\"currentPage\" : ").append(java_lang_Integer.marshall(a0.getCurrentPage(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.search.SearchCriteriaDto", ch_apkern_achilles_dto_shared_module_search_SearchCriteriaDto);
    ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_LibraryTypeEnum = new Marshaller<LibraryTypeEnum>() {
      private LibraryTypeEnum[] EMPTY_ARRAY = new LibraryTypeEnum[0];
      public LibraryTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LibraryTypeEnum.class;
      }
      public LibraryTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          LibraryTypeEnum entity = obj != null ? Enum.valueOf(LibraryTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(LibraryTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.LibraryTypeEnum", t);
        }
      }
      public String marshall(LibraryTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.LibraryTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.LibraryTypeEnum", ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_LibraryTypeEnum);
    org_jboss_errai_bus_client_api_base_MessageDeliveryFailure = new Marshaller<MessageDeliveryFailure>() {
      private MessageDeliveryFailure[] EMPTY_ARRAY = new MessageDeliveryFailure[0];
      public MessageDeliveryFailure[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MessageDeliveryFailure.class;
      }
      public MessageDeliveryFailure demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MessageDeliveryFailure.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          MessageDeliveryFailure entity = new MessageDeliveryFailure(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: org.jboss.errai.bus.client.api.base.MessageDeliveryFailure", t);
        }
      }
      public String marshall(MessageDeliveryFailure a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"org.jboss.errai.bus.client.api.base.MessageDeliveryFailure\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"org.jboss.errai.bus.client.api.base.MessageDeliveryFailure\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("org.jboss.errai.bus.client.api.base.MessageDeliveryFailure", org_jboss_errai_bus_client_api_base_MessageDeliveryFailure);
    ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_detail_reference_list_MeasurandReferenceCommunicationDto = new Marshaller<MeasurandReferenceCommunicationDto>() {
      private MeasurandReferenceCommunicationDto[] EMPTY_ARRAY = new MeasurandReferenceCommunicationDto[0];
      public MeasurandReferenceCommunicationDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasurandReferenceCommunicationDto.class;
      }
      public MeasurandReferenceCommunicationDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasurandReferenceCommunicationDto.class, objId);
          }
          MeasurandReferenceCommunicationDto entity = new MeasurandReferenceCommunicationDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("measurandLibraryUuid")) && (!obj.get("measurandLibraryUuid").isNull())) {
            entity.setMeasurandLibraryUuid(java_lang_String.demarshall(obj.get("measurandLibraryUuid"), a1));
          }
          if ((obj.containsKey("measurandGroupUuid")) && (!obj.get("measurandGroupUuid").isNull())) {
            entity.setMeasurandGroupUuid(java_lang_String.demarshall(obj.get("measurandGroupUuid"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.detail.reference.list.MeasurandReferenceCommunicationDto", t);
        }
      }
      public String marshall(MeasurandReferenceCommunicationDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.detail.reference.list.MeasurandReferenceCommunicationDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.detail.reference.list.MeasurandReferenceCommunicationDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"measurandLibraryUuid\" : ").append(java_lang_String.marshall(a0.getMeasurandLibraryUuid(), a1)).append(",").append("\"measurandGroupUuid\" : ").append(java_lang_String.marshall(a0.getMeasurandGroupUuid(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.detail.reference.list.MeasurandReferenceCommunicationDto", ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_detail_reference_list_MeasurandReferenceCommunicationDto);
    ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId = new Marshaller<ClientInstanceId>() {
      private ClientInstanceId[] EMPTY_ARRAY = new ClientInstanceId[0];
      public ClientInstanceId[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ClientInstanceId.class;
      }
      public ClientInstanceId demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ClientInstanceId.class, objId);
          }
          final Long c0 = java_lang_Long.demarshall(obj.get("value"), a1);
          ClientInstanceId entity = new ClientInstanceId(c0);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.concurrency.client.internal.model.ClientInstanceId", t);
        }
      }
      public String marshall(ClientInstanceId a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.model.ClientInstanceId\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.model.ClientInstanceId\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"value\" : ").append(java_lang_Long.marshall(a0.getValue(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.model.ClientInstanceId", ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId);
    ch_apkern_achilles_concurrency_client_internal_transfer_LockEventTransfer = new Marshaller<LockEventTransfer>() {
      private LockEventTransfer[] EMPTY_ARRAY = new LockEventTransfer[0];
      public LockEventTransfer[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LockEventTransfer.class;
      }
      public LockEventTransfer demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LockEventTransfer.class, objId);
          }
          final ClientInstanceId c0 = ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.demarshall(obj.get("clientInstanceId"), a1);
          final String c1 = java_lang_String.demarshall(obj.get("fieldId"), a1);
          final String c2 = java_lang_String.demarshall(obj.get("entityId"), a1);
          final EventCase c3 = obj.get("eventCase").isObject() != null ? Enum.valueOf(EventCase.class, obj.get("eventCase").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("eventCase").isString() != null ? Enum.valueOf(EventCase.class, obj.get("eventCase").isString().stringValue()) : null;
          final String c4 = java_lang_String.demarshall(obj.get("editor"), a1);
          LockEventTransfer entity = new LockEventTransfer(c0, c1, c2, c3, c4);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("clientInstanceId")) && (!obj.get("clientInstanceId").isNull())) {
            _$411629081_clientInstanceId(entity, ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.demarshall(obj.get("clientInstanceId"), a1));
          }
          if ((obj.containsKey("fieldId")) && (!obj.get("fieldId").isNull())) {
            _$411629081_fieldId(entity, java_lang_String.demarshall(obj.get("fieldId"), a1));
          }
          if ((obj.containsKey("entityId")) && (!obj.get("entityId").isNull())) {
            _$411629081_entityId(entity, java_lang_String.demarshall(obj.get("entityId"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer", t);
        }
      }
      public String marshall(LockEventTransfer a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(896).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"editor\" : ").append(java_lang_String.marshall(a0.getEditor(), a1)).append(",").append("\"eventCase\" : ").append(a0.getEventCase() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer$EventCase\",\"^EnumStringValue\":\"").append(a0.getEventCase().name()).append("\"}") : "null").append(",").append("\"clientInstanceId\" : ").append(ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.marshall(a0.getClientInstanceId(), a1)).append(",").append("\"fieldId\" : ").append(java_lang_String.marshall(a0.getFieldId(), a1)).append(",").append("\"entityId\" : ").append(java_lang_String.marshall(a0.getEntityId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer", ch_apkern_achilles_concurrency_client_internal_transfer_LockEventTransfer);
    ch_apkern_achilles_dto_shared_entity_address_PersonDto = new Marshaller<PersonDto>() {
      private PersonDto[] EMPTY_ARRAY = new PersonDto[0];
      public PersonDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PersonDto.class;
      }
      public PersonDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(PersonDto.class, objId);
          }
          PersonDto entity = new PersonDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("address")) && (!obj.get("address").isNull())) {
            entity.setAddress(ch_apkern_achilles_dto_shared_entity_address_AddressDto.demarshall(obj.get("address"), a1));
          }
          if ((obj.containsKey("metaFieldValueList")) && (!obj.get("metaFieldValueList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.core.MetaFieldValueDto");
            entity.setMetaFieldValueList(java_util_List.demarshall(obj.get("metaFieldValueList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.address.PersonDto", t);
        }
      }
      public String marshall(PersonDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.PersonDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(2304).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.PersonDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"address\" : ").append(ch_apkern_achilles_dto_shared_entity_address_AddressDto.marshall(a0.getAddress(), a1)).append(",").append("\"metaFieldValueList\" : ").append(java_util_List.marshall(a0.getMetaFieldValueList(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.address.PersonDto", ch_apkern_achilles_dto_shared_entity_address_PersonDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_BiometricDataMeasuringDto = new Marshaller<BiometricDataMeasuringDto>() {
      private BiometricDataMeasuringDto[] EMPTY_ARRAY = new BiometricDataMeasuringDto[0];
      public BiometricDataMeasuringDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return BiometricDataMeasuringDto.class;
      }
      public BiometricDataMeasuringDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(BiometricDataMeasuringDto.class, objId);
          }
          BiometricDataMeasuringDto entity = new BiometricDataMeasuringDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("measuringDate")) && (!obj.get("measuringDate").isNull())) {
            entity.setMeasuringDate(java_util_Date.demarshall(obj.get("measuringDate"), a1));
          }
          if ((obj.containsKey("treatment")) && (!obj.get("treatment").isNull())) {
            entity.setTreatment(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.demarshall(obj.get("treatment"), a1));
          }
          if ((obj.containsKey("manual")) && (!obj.get("manual").isNull())) {
            entity.setManual(java_lang_Boolean.demarshall(obj.get("manual"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.BiometricDataMeasuringDto", t);
        }
      }
      public String marshall(BiometricDataMeasuringDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.BiometricDataMeasuringDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(6784).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.BiometricDataMeasuringDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"measuringDate\" : ").append(java_util_Date.marshall(a0.getMeasuringDate(), a1)).append(",").append("\"treatment\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.marshall(a0.getTreatment(), a1)).append(",").append("\"manual\" : ").append(java_lang_Boolean.marshall(a0.getManual(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.BiometricDataMeasuringDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_BiometricDataMeasuringDto);
    ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryDeviceProviderDtoList = new Marshaller<LaboratoryDeviceProviderDtoList>() {
      private LaboratoryDeviceProviderDtoList[] EMPTY_ARRAY = new LaboratoryDeviceProviderDtoList[0];
      public LaboratoryDeviceProviderDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LaboratoryDeviceProviderDtoList.class;
      }
      public LaboratoryDeviceProviderDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LaboratoryDeviceProviderDtoList.class, objId);
          }
          a1.setAssumedElementType("ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDto");
          final List<LaboratoryDeviceProviderDto> c0 = java_util_List.demarshall(obj.get("deviceList"), a1);
          a1.setAssumedElementType(null);
          LaboratoryDeviceProviderDtoList entity = new LaboratoryDeviceProviderDtoList(c0);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDtoList", t);
        }
      }
      public String marshall(LaboratoryDeviceProviderDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"deviceList\" : ").append(java_util_List.marshall(a0.getDeviceList(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryDeviceProviderDtoList", ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryDeviceProviderDtoList);
    ch_apkern_achilles_model_shared_entity_core_SexEnum = new Marshaller<SexEnum>() {
      private SexEnum[] EMPTY_ARRAY = new SexEnum[0];
      public SexEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SexEnum.class;
      }
      public SexEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          SexEnum entity = obj != null ? Enum.valueOf(SexEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(SexEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.model.shared.entity.core.SexEnum", t);
        }
      }
      public String marshall(SexEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.SexEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.model.shared.entity.core.SexEnum", ch_apkern_achilles_model_shared_entity_core_SexEnum);
    ch_apkern_achilles_apisecurity_client_session_ClientSessionUser = new Marshaller<ClientSessionUser>() {
      private ClientSessionUser[] EMPTY_ARRAY = new ClientSessionUser[0];
      public ClientSessionUser[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ClientSessionUser.class;
      }
      public ClientSessionUser demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ClientSessionUser.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("userName"), a1);
          final String c1 = java_lang_String.demarshall(obj.get("userSignature"), a1);
          final SessionStateEnum c2 = obj.get("sessionState").isObject() != null ? Enum.valueOf(SessionStateEnum.class, obj.get("sessionState").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("sessionState").isString() != null ? Enum.valueOf(SessionStateEnum.class, obj.get("sessionState").isString().stringValue()) : null;
          final String c3 = java_lang_String.demarshall(obj.get("sessionId"), a1);
          ClientSessionUser entity = new ClientSessionUser(c0, c1, c2, c3);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.apisecurity.client.session.ClientSessionUser", t);
        }
      }
      public String marshall(ClientSessionUser a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.apisecurity.client.session.ClientSessionUser\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"ch.apkern.achilles.apisecurity.client.session.ClientSessionUser\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"userName\" : ").append(java_lang_String.marshall(a0.getUserName(), a1)).append(",").append("\"userSignature\" : ").append(java_lang_String.marshall(a0.getUserSignature(), a1)).append(",").append("\"sessionState\" : ").append(a0.getSessionState() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.apisecurity.client.session.enumeration.SessionStateEnum\",\"^EnumStringValue\":\"").append(a0.getSessionState().name()).append("\"}") : "null").append(",").append("\"sessionId\" : ").append(java_lang_String.marshall(a0.getSessionId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.apisecurity.client.session.ClientSessionUser", ch_apkern_achilles_apisecurity_client_session_ClientSessionUser);
    ch_apkern_achilles_apisecurity_client_session_ClientSessionDto = new Marshaller<ClientSessionDto>() {
      private ClientSessionDto[] EMPTY_ARRAY = new ClientSessionDto[0];
      public ClientSessionDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ClientSessionDto.class;
      }
      public ClientSessionDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ClientSessionDto.class, objId);
          }
          ClientSessionDto entity = new ClientSessionDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("sessionUser")) && (!obj.get("sessionUser").isNull())) {
            entity.setSessionUser(ch_apkern_achilles_apisecurity_client_session_ClientSessionUser.demarshall(obj.get("sessionUser"), a1));
          }
          if ((obj.containsKey("searchCriteria")) && (!obj.get("searchCriteria").isNull())) {
            a1.setAssumedMapKeyType("java.lang.String");
            a1.setAssumedMapValueType("ch.apkern.achilles.dto.shared.module.search.SearchCriteriaDto");
            entity.setSearchCriteria((Map) java_util_Map.demarshall(obj.get("searchCriteria"), a1));
            a1.setAssumedMapKeyType(null);
            a1.setAssumedMapValueType(null);
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.apisecurity.client.session.ClientSessionDto", t);
        }
      }
      public String marshall(ClientSessionDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.apisecurity.client.session.ClientSessionDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(896).append("{\"^EncodedType\":\"ch.apkern.achilles.apisecurity.client.session.ClientSessionDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"sessionUser\" : ").append(ch_apkern_achilles_apisecurity_client_session_ClientSessionUser.marshall(a0.getSessionUser(), a1)).append(",").append("\"searchCriteria\" : ").append(java_util_Map.marshall(a0.getSearchCriteria(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.apisecurity.client.session.ClientSessionDto", ch_apkern_achilles_apisecurity_client_session_ClientSessionDto);
    ch_apkern_achilles_dto_shared_entity_base_ValidityDto = new Marshaller<ValidityDto>() {
      private ValidityDto[] EMPTY_ARRAY = new ValidityDto[0];
      public ValidityDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ValidityDto.class;
      }
      public ValidityDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ValidityDto.class, objId);
          }
          ValidityDto entity = new ValidityDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("validFrom")) && (!obj.get("validFrom").isNull())) {
            entity.setValidFrom(java_util_Date.demarshall(obj.get("validFrom"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.base.ValidityDto", t);
        }
      }
      public String marshall(ValidityDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.base.ValidityDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.base.ValidityDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"validFrom\" : ").append(java_util_Date.marshall(a0.getValidFrom(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.base.ValidityDto", ch_apkern_achilles_dto_shared_entity_base_ValidityDto);
    ch_apkern_achilles_api_client_exception_ExceptionElement = new Marshaller<ExceptionElement>() {
      private ExceptionElement[] EMPTY_ARRAY = new ExceptionElement[0];
      public ExceptionElement[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ExceptionElement.class;
      }
      public ExceptionElement demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ExceptionElement.class, objId);
          }
          ExceptionElement entity = new ExceptionElement();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("incorrectField")) && (!obj.get("incorrectField").isNull())) {
            entity.setIncorrectField(java_lang_String.demarshall(obj.get("incorrectField"), a1));
          }
          if ((obj.containsKey("incorrectObjectUUID")) && (!obj.get("incorrectObjectUUID").isNull())) {
            entity.setIncorrectObjectUUID(java_lang_String.demarshall(obj.get("incorrectObjectUUID"), a1));
          }
          if ((obj.containsKey("validationMessage")) && (!obj.get("validationMessage").isNull())) {
            entity.setValidationMessage(java_lang_String.demarshall(obj.get("validationMessage"), a1));
          }
          if ((obj.containsKey("incorrectDtoClass")) && (!obj.get("incorrectDtoClass").isNull())) {
            entity.setIncorrectDtoClass(java_lang_String.demarshall(obj.get("incorrectDtoClass"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.api.client.exception.ExceptionElement", t);
        }
      }
      public String marshall(ExceptionElement a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.api.client.exception.ExceptionElement\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"ch.apkern.achilles.api.client.exception.ExceptionElement\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"incorrectField\" : ").append(java_lang_String.marshall(a0.getIncorrectField(), a1)).append(",").append("\"incorrectObjectUUID\" : ").append(java_lang_String.marshall(a0.getIncorrectObjectUUID(), a1)).append(",").append("\"validationMessage\" : ").append(java_lang_String.marshall(a0.getValidationMessage(), a1)).append(",").append("\"incorrectDtoClass\" : ").append(java_lang_String.marshall(a0.getIncorrectDtoClass(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.api.client.exception.ExceptionElement", ch_apkern_achilles_api_client_exception_ExceptionElement);
    ch_apkern_achilles_dto_shared_entity_core_CommentDto = new Marshaller<CommentDto>() {
      private CommentDto[] EMPTY_ARRAY = new CommentDto[0];
      public CommentDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return CommentDto.class;
      }
      public CommentDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(CommentDto.class, objId);
          }
          CommentDto entity = new CommentDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("text")) && (!obj.get("text").isNull())) {
            entity.setText(java_lang_String.demarshall(obj.get("text"), a1));
          }
          if ((obj.containsKey("user")) && (!obj.get("user").isNull())) {
            entity.setUser(ch_apkern_achilles_dto_shared_entity_core_UserDto.demarshall(obj.get("user"), a1));
          }
          if ((obj.containsKey("entityId")) && (!obj.get("entityId").isNull())) {
            entity.setEntityId(java_lang_String.demarshall(obj.get("entityId"), a1));
          }
          if ((obj.containsKey("date")) && (!obj.get("date").isNull())) {
            entity.setDate(java_util_Date.demarshall(obj.get("date"), a1));
          }
          if ((obj.containsKey("newComment")) && (!obj.get("newComment").isNull())) {
            entity.setNewComment(java_lang_Boolean.demarshall(obj.get("newComment"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.CommentDto", t);
        }
      }
      public String marshall(CommentDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.CommentDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1920).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.CommentDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"text\" : ").append(java_lang_String.marshall(a0.getText(), a1)).append(",").append("\"user\" : ").append(ch_apkern_achilles_dto_shared_entity_core_UserDto.marshall(a0.getUser(), a1)).append(",").append("\"entityId\" : ").append(java_lang_String.marshall(a0.getEntityId(), a1)).append(",").append("\"date\" : ").append(java_util_Date.marshall(a0.getDate(), a1)).append(",").append("\"newComment\" : ").append(java_lang_Boolean.marshall(a0.getNewComment(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.CommentDto", ch_apkern_achilles_dto_shared_entity_core_CommentDto);
    ch_apkern_achilles_apisecurity_client_session_enumeration_SessionStateEnum = new Marshaller<SessionStateEnum>() {
      private SessionStateEnum[] EMPTY_ARRAY = new SessionStateEnum[0];
      public SessionStateEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SessionStateEnum.class;
      }
      public SessionStateEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          SessionStateEnum entity = obj != null ? Enum.valueOf(SessionStateEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(SessionStateEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.apisecurity.client.session.enumeration.SessionStateEnum", t);
        }
      }
      public String marshall(SessionStateEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.apisecurity.client.session.enumeration.SessionStateEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.apisecurity.client.session.enumeration.SessionStateEnum", ch_apkern_achilles_apisecurity_client_session_enumeration_SessionStateEnum);
    ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxListDetailDto = new Marshaller<InboxListDetailDto>() {
      private InboxListDetailDto[] EMPTY_ARRAY = new InboxListDetailDto[0];
      public InboxListDetailDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return InboxListDetailDto.class;
      }
      public InboxListDetailDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(InboxListDetailDto.class, objId);
          }
          InboxListDetailDto entity = new InboxListDetailDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          if ((obj.containsKey("fullPatientName")) && (!obj.get("fullPatientName").isNull())) {
            entity.setFullPatientName(java_lang_String.demarshall(obj.get("fullPatientName"), a1));
          }
          if ((obj.containsKey("mandatorName")) && (!obj.get("mandatorName").isNull())) {
            entity.setMandatorName(java_lang_String.demarshall(obj.get("mandatorName"), a1));
          }
          if ((obj.containsKey("controllerName")) && (!obj.get("controllerName").isNull())) {
            entity.setControllerName(java_lang_String.demarshall(obj.get("controllerName"), a1));
          }
          if ((obj.containsKey("measuringDate")) && (!obj.get("measuringDate").isNull())) {
            entity.setMeasuringDate(java_util_Date.demarshall(obj.get("measuringDate"), a1));
          }
          if ((obj.containsKey("provider")) && (!obj.get("provider").isNull())) {
            entity.setProvider(java_lang_String.demarshall(obj.get("provider"), a1));
          }
          if ((obj.containsKey("patientIdentification")) && (!obj.get("patientIdentification").isNull())) {
            entity.setPatientIdentification(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.demarshall(obj.get("patientIdentification"), a1));
          }
          if ((obj.containsKey("patient")) && (!obj.get("patient").isNull())) {
            entity.setPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("patient"), a1));
          }
          if ((obj.containsKey("naturalPerson")) && (!obj.get("naturalPerson").isNull())) {
            entity.setNaturalPerson(ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto.demarshall(obj.get("naturalPerson"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDetailDto", t);
        }
      }
      public String marshall(InboxListDetailDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDetailDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(5888).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDetailDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append(",").append("\"fullPatientName\" : ").append(java_lang_String.marshall(a0.getFullPatientName(), a1)).append(",").append("\"mandatorName\" : ").append(java_lang_String.marshall(a0.getMandatorName(), a1)).append(",").append("\"controllerName\" : ").append(java_lang_String.marshall(a0.getControllerName(), a1)).append(",").append("\"measuringDate\" : ").append(java_util_Date.marshall(a0.getMeasuringDate(), a1)).append(",").append("\"provider\" : ").append(java_lang_String.marshall(a0.getProvider(), a1)).append(",").append("\"patientIdentification\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.marshall(a0.getPatientIdentification(), a1)).append(",").append("\"patient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getPatient(), a1)).append(",").append("\"naturalPerson\" : ").append(ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto.marshall(a0.getNaturalPerson(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDetailDto", ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxListDetailDto);
    ch_apkern_achilles_model_shared_entity_patient_PersonReferenceTypeEnum = new Marshaller<PersonReferenceTypeEnum>() {
      private PersonReferenceTypeEnum[] EMPTY_ARRAY = new PersonReferenceTypeEnum[0];
      public PersonReferenceTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PersonReferenceTypeEnum.class;
      }
      public PersonReferenceTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          PersonReferenceTypeEnum entity = obj != null ? Enum.valueOf(PersonReferenceTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(PersonReferenceTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.model.shared.entity.patient.PersonReferenceTypeEnum", t);
        }
      }
      public String marshall(PersonReferenceTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.patient.PersonReferenceTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.model.shared.entity.patient.PersonReferenceTypeEnum", ch_apkern_achilles_model_shared_entity_patient_PersonReferenceTypeEnum);
    ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxListDto = new Marshaller<InboxListDto>() {
      private InboxListDto[] EMPTY_ARRAY = new InboxListDto[0];
      public InboxListDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return InboxListDto.class;
      }
      public InboxListDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(InboxListDto.class, objId);
          }
          InboxListDto entity = new InboxListDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("inboxList")) && (!obj.get("inboxList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDetailDto");
            entity.setInboxList(java_util_List.demarshall(obj.get("inboxList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("currentDto")) && (!obj.get("currentDto").isNull())) {
            entity.setCurrentDto(ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxListDetailDto.demarshall(obj.get("currentDto"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDto", t);
        }
      }
      public String marshall(InboxListDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(6144).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"inboxList\" : ").append(java_util_List.marshall(a0.getInboxList(), a1)).append(",").append("\"currentDto\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxListDetailDto.marshall(a0.getCurrentDto(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.inbox.InboxListDto", ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxListDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_provider_AutomaticDeviceProviderDto = new Marshaller<AutomaticDeviceProviderDto>() {
      private AutomaticDeviceProviderDto[] EMPTY_ARRAY = new AutomaticDeviceProviderDto[0];
      public AutomaticDeviceProviderDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return AutomaticDeviceProviderDto.class;
      }
      public AutomaticDeviceProviderDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(AutomaticDeviceProviderDto.class, objId);
          }
          AutomaticDeviceProviderDto entity = new AutomaticDeviceProviderDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("deviceTypeId")) && (!obj.get("deviceTypeId").isNull())) {
            entity.setDeviceTypeId(java_lang_String.demarshall(obj.get("deviceTypeId"), a1));
          }
          if ((obj.containsKey("serialNumber")) && (!obj.get("serialNumber").isNull())) {
            entity.setSerialNumber(java_lang_String.demarshall(obj.get("serialNumber"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("active")) && (!obj.get("active").isNull())) {
            entity.setActive(java_lang_Boolean.demarshall(obj.get("active"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.provider.AutomaticDeviceProviderDto", t);
        }
      }
      public String marshall(AutomaticDeviceProviderDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.AutomaticDeviceProviderDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(768).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.AutomaticDeviceProviderDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"deviceTypeId\" : ").append(java_lang_String.marshall(a0.getDeviceTypeId(), a1)).append(",").append("\"serialNumber\" : ").append(java_lang_String.marshall(a0.getSerialNumber(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"active\" : ").append(java_lang_Boolean.marshall(a0.getActive(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.provider.AutomaticDeviceProviderDto", ch_apkern_achilles_dto_shared_entity_laboratory_provider_AutomaticDeviceProviderDto);
    ch_apkern_achilles_dto_shared_module_laboratory_inbox_detail_InboxDetailDto = new Marshaller<InboxDetailDto>() {
      private InboxDetailDto[] EMPTY_ARRAY = new InboxDetailDto[0];
      public InboxDetailDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return InboxDetailDto.class;
      }
      public InboxDetailDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(InboxDetailDto.class, objId);
          }
          InboxDetailDto entity = new InboxDetailDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("inboxDto")) && (!obj.get("inboxDto").isNull())) {
            entity.setInboxDto(ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxDto.demarshall(obj.get("inboxDto"), a1));
          }
          if ((obj.containsKey("naturalPerson")) && (!obj.get("naturalPerson").isNull())) {
            entity.setNaturalPerson(ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto.demarshall(obj.get("naturalPerson"), a1));
          }
          if ((obj.containsKey("currentResult")) && (!obj.get("currentResult").isNull())) {
            entity.setCurrentResult(ch_apkern_achilles_dto_shared_module_laboratory_DetailResultDto.demarshall(obj.get("currentResult"), a1));
          }
          if ((obj.containsKey("fullPatientName")) && (!obj.get("fullPatientName").isNull())) {
            entity.setFullPatientName(java_lang_String.demarshall(obj.get("fullPatientName"), a1));
          }
          if ((obj.containsKey("mandatorName")) && (!obj.get("mandatorName").isNull())) {
            entity.setMandatorName(java_lang_String.demarshall(obj.get("mandatorName"), a1));
          }
          if ((obj.containsKey("controllerName")) && (!obj.get("controllerName").isNull())) {
            entity.setControllerName(java_lang_String.demarshall(obj.get("controllerName"), a1));
          }
          if ((obj.containsKey("manual")) && (!obj.get("manual").isNull())) {
            entity.setManual(java_lang_Boolean.demarshall(obj.get("manual"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.inbox.detail.InboxDetailDto", t);
        }
      }
      public String marshall(InboxDetailDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.inbox.detail.InboxDetailDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(10752).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.inbox.detail.InboxDetailDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"inboxDto\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_inbox_InboxDto.marshall(a0.getInboxDto(), a1)).append(",").append("\"naturalPerson\" : ").append(ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto.marshall(a0.getNaturalPerson(), a1)).append(",").append("\"currentResult\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_DetailResultDto.marshall(a0.getCurrentResult(), a1)).append(",").append("\"fullPatientName\" : ").append(java_lang_String.marshall(a0.getFullPatientName(), a1)).append(",").append("\"mandatorName\" : ").append(java_lang_String.marshall(a0.getMandatorName(), a1)).append(",").append("\"controllerName\" : ").append(java_lang_String.marshall(a0.getControllerName(), a1)).append(",").append("\"manual\" : ").append(java_lang_Boolean.marshall(a0.getManual(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.inbox.detail.InboxDetailDto", ch_apkern_achilles_dto_shared_module_laboratory_inbox_detail_InboxDetailDto);
    ch_apkern_achilles_concurrency_client_internal_transfer_ValueBroadcastEventTransfer$ValueBroadcastEventEntry = new Marshaller<ValueBroadcastEventEntry>() {
      private ValueBroadcastEventEntry[] EMPTY_ARRAY = new ValueBroadcastEventEntry[0];
      public ValueBroadcastEventEntry[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ValueBroadcastEventEntry.class;
      }
      public ValueBroadcastEventEntry demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ValueBroadcastEventEntry.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("entityId"), a1);
          final String c1 = java_lang_String.demarshall(obj.get("fieldId"), a1);
          ValueBroadcastEventEntry entity = new ValueBroadcastEventEntry(c0, c1);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer$ValueBroadcastEventEntry", t);
        }
      }
      public String marshall(ValueBroadcastEventEntry a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer$ValueBroadcastEventEntry\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer$ValueBroadcastEventEntry\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"entityId\" : ").append(java_lang_String.marshall(a0.getEntityId(), a1)).append(",").append("\"fieldId\" : ").append(java_lang_String.marshall(a0.getFieldId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer$ValueBroadcastEventEntry", ch_apkern_achilles_concurrency_client_internal_transfer_ValueBroadcastEventTransfer$ValueBroadcastEventEntry);
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer.ValueBroadcastEventEntry", ch_apkern_achilles_concurrency_client_internal_transfer_ValueBroadcastEventTransfer$ValueBroadcastEventEntry);
    ch_apkern_achilles_dto_shared_module_laboratory_quality_ManufacturerResultReferenceViewDto = new Marshaller<ManufacturerResultReferenceViewDto>() {
      private ManufacturerResultReferenceViewDto[] EMPTY_ARRAY = new ManufacturerResultReferenceViewDto[0];
      public ManufacturerResultReferenceViewDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ManufacturerResultReferenceViewDto.class;
      }
      public ManufacturerResultReferenceViewDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ManufacturerResultReferenceViewDto.class, objId);
          }
          ManufacturerResultReferenceViewDto entity = new ManufacturerResultReferenceViewDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("libraryCode")) && (!obj.get("libraryCode").isNull())) {
            entity.setLibraryCode(java_lang_String.demarshall(obj.get("libraryCode"), a1));
          }
          if ((obj.containsKey("unitId")) && (!obj.get("unitId").isNull())) {
            entity.setUnitId(java_lang_String.demarshall(obj.get("unitId"), a1));
          }
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(java_lang_String.demarshall(obj.get("unit"), a1));
          }
          if ((obj.containsKey("nominalValue")) && (!obj.get("nominalValue").isNull())) {
            entity.setNominalValue(java_math_BigDecimal.demarshall(obj.get("nominalValue"), a1));
          }
          if ((obj.containsKey("tolerance")) && (!obj.get("tolerance").isNull())) {
            entity.setTolerance(java_math_BigDecimal.demarshall(obj.get("tolerance"), a1));
          }
          if ((obj.containsKey("range")) && (!obj.get("range").isNull())) {
            entity.setRange(java_lang_String.demarshall(obj.get("range"), a1));
          }
          if ((obj.containsKey("qualabTolerance")) && (!obj.get("qualabTolerance").isNull())) {
            entity.setQualabTolerance(java_math_BigDecimal.demarshall(obj.get("qualabTolerance"), a1));
          }
          if ((obj.containsKey("qualabRange")) && (!obj.get("qualabRange").isNull())) {
            entity.setQualabRange(java_lang_String.demarshall(obj.get("qualabRange"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.quality.ManufacturerResultReferenceViewDto", t);
        }
      }
      public String marshall(ManufacturerResultReferenceViewDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.ManufacturerResultReferenceViewDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1280).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.ManufacturerResultReferenceViewDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"libraryCode\" : ").append(java_lang_String.marshall(a0.getLibraryCode(), a1)).append(",").append("\"unitId\" : ").append(java_lang_String.marshall(a0.getUnitId(), a1)).append(",").append("\"unit\" : ").append(java_lang_String.marshall(a0.getUnit(), a1)).append(",").append("\"nominalValue\" : ").append(java_math_BigDecimal.marshall(a0.getNominalValue(), a1)).append(",").append("\"tolerance\" : ").append(java_math_BigDecimal.marshall(a0.getTolerance(), a1)).append(",").append("\"range\" : ").append(java_lang_String.marshall(a0.getRange(), a1)).append(",").append("\"qualabTolerance\" : ").append(java_math_BigDecimal.marshall(a0.getQualabTolerance(), a1)).append(",").append("\"qualabRange\" : ").append(java_lang_String.marshall(a0.getQualabRange(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.quality.ManufacturerResultReferenceViewDto", ch_apkern_achilles_dto_shared_module_laboratory_quality_ManufacturerResultReferenceViewDto);
    org_jboss_errai_enterprise_client_cdi_events_BusReadyEvent = new Marshaller<BusReadyEvent>() {
      private BusReadyEvent[] EMPTY_ARRAY = new BusReadyEvent[0];
      public BusReadyEvent[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return BusReadyEvent.class;
      }
      public BusReadyEvent demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(BusReadyEvent.class, objId);
          }
          BusReadyEvent entity = new BusReadyEvent();
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: org.jboss.errai.enterprise.client.cdi.events.BusReadyEvent", t);
        }
      }
      public String marshall(BusReadyEvent a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"org.jboss.errai.enterprise.client.cdi.events.BusReadyEvent\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(128).append("{\"^EncodedType\":\"org.jboss.errai.enterprise.client.cdi.events.BusReadyEvent\",\"^ObjectID\":\"").append(objId).append("\"").append(",\"^InstantiateOnly\":true").append("}").toString();
      }
    };
    marshallers.put("org.jboss.errai.enterprise.client.cdi.events.BusReadyEvent", org_jboss_errai_enterprise_client_cdi_events_BusReadyEvent);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_BiometricDataLibraryDto = new Marshaller<BiometricDataLibraryDto>() {
      private BiometricDataLibraryDto[] EMPTY_ARRAY = new BiometricDataLibraryDto[0];
      public BiometricDataLibraryDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return BiometricDataLibraryDto.class;
      }
      public BiometricDataLibraryDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(BiometricDataLibraryDto.class, objId);
          }
          BiometricDataLibraryDto entity = new BiometricDataLibraryDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("diagram")) && (!obj.get("diagram").isNull())) {
            entity.setDiagram(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.demarshall(obj.get("diagram"), a1));
          }
          if ((obj.containsKey("division")) && (!obj.get("division").isNull())) {
            entity.setDivision(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.demarshall(obj.get("division"), a1));
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("modificated")) && (!obj.get("modificated").isNull())) {
            entity.setModificated(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("modificated"), a1));
          }
          if ((obj.containsKey("resultType")) && (!obj.get("resultType").isNull())) {
            entity.setResultType((ResultTypeDto) java_lang_Object.demarshall(ResultTypeDto.class, obj.get("resultType"), a1));
          }
          if ((obj.containsKey("sortCode")) && (!obj.get("sortCode").isNull())) {
            entity.setSortCode(java_lang_Integer.demarshall(obj.get("sortCode"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.BiometricDataLibraryDto", t);
        }
      }
      public String marshall(BiometricDataLibraryDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.BiometricDataLibraryDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3328).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.BiometricDataLibraryDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"diagram\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.marshall(a0.getDiagram(), a1)).append(",").append("\"division\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.marshall(a0.getDivision(), a1)).append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"modificated\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getModificated(), a1)).append(",").append("\"resultType\" : ").append(java_lang_Object.marshall(a0.getResultType(), a1)).append(",").append("\"sortCode\" : ").append(java_lang_Integer.marshall(a0.getSortCode(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.BiometricDataLibraryDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_BiometricDataLibraryDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_TextResultTypeDto = new Marshaller<TextResultTypeDto>() {
      private TextResultTypeDto[] EMPTY_ARRAY = new TextResultTypeDto[0];
      public TextResultTypeDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return TextResultTypeDto.class;
      }
      public TextResultTypeDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(TextResultTypeDto.class, objId);
          }
          TextResultTypeDto entity = new TextResultTypeDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TextResultTypeDto", t);
        }
      }
      public String marshall(TextResultTypeDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TextResultTypeDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TextResultTypeDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TextResultTypeDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_TextResultTypeDto);
    ch_apkern_achilles_dto_shared_module_laboratory_MeasuringDtoList = new Marshaller<MeasuringDtoList>() {
      private MeasuringDtoList[] EMPTY_ARRAY = new MeasuringDtoList[0];
      public MeasuringDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasuringDtoList.class;
      }
      public MeasuringDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasuringDtoList.class, objId);
          }
          a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.MeasuringDto");
          final List<MeasuringDto> c0 = java_util_List.demarshall(obj.get("measuringDtoList"), a1);
          a1.setAssumedElementType(null);
          MeasuringDtoList entity = new MeasuringDtoList(c0);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDtoList", t);
        }
      }
      public String marshall(MeasuringDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"measuringDtoList\" : ").append(java_util_List.marshall(a0.getMeasuringDtoList(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDtoList", ch_apkern_achilles_dto_shared_module_laboratory_MeasuringDtoList);
    ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringDateFilterTypeEnum = new Marshaller<MeasuringDateFilterTypeEnum>() {
      private MeasuringDateFilterTypeEnum[] EMPTY_ARRAY = new MeasuringDateFilterTypeEnum[0];
      public MeasuringDateFilterTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasuringDateFilterTypeEnum.class;
      }
      public MeasuringDateFilterTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          MeasuringDateFilterTypeEnum entity = obj != null ? Enum.valueOf(MeasuringDateFilterTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(MeasuringDateFilterTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringDateFilterTypeEnum", t);
        }
      }
      public String marshall(MeasuringDateFilterTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringDateFilterTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringDateFilterTypeEnum", ch_apkern_achilles_dto_shared_module_laboratory_quality_MeasuringDateFilterTypeEnum);
    ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto = new Marshaller<ValueFormatDto>() {
      private ValueFormatDto[] EMPTY_ARRAY = new ValueFormatDto[0];
      public ValueFormatDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ValueFormatDto.class;
      }
      public ValueFormatDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ValueFormatDto.class, objId);
          }
          ValueFormatDto entity = new ValueFormatDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("format")) && (!obj.get("format").isNull())) {
            entity.setFormat(java_lang_String.demarshall(obj.get("format"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.core.ValueFormatDto", t);
        }
      }
      public String marshall(ValueFormatDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.ValueFormatDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.core.ValueFormatDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"format\" : ").append(java_lang_String.marshall(a0.getFormat(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.core.ValueFormatDto", ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_NumericResultTypeDto = new Marshaller<NumericResultTypeDto>() {
      private NumericResultTypeDto[] EMPTY_ARRAY = new NumericResultTypeDto[0];
      public NumericResultTypeDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return NumericResultTypeDto.class;
      }
      public NumericResultTypeDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(NumericResultTypeDto.class, objId);
          }
          NumericResultTypeDto entity = new NumericResultTypeDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.demarshall(obj.get("unit"), a1));
          }
          if ((obj.containsKey("valueFormat")) && (!obj.get("valueFormat").isNull())) {
            entity.setValueFormat(ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto.demarshall(obj.get("valueFormat"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.NumericResultTypeDto", t);
        }
      }
      public String marshall(NumericResultTypeDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.NumericResultTypeDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1664).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.NumericResultTypeDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"unit\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.marshall(a0.getUnit(), a1)).append(",").append("\"valueFormat\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto.marshall(a0.getValueFormat(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.NumericResultTypeDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_NumericResultTypeDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitOverrideDto = new Marshaller<UnitOverrideDto>() {
      private UnitOverrideDto[] EMPTY_ARRAY = new UnitOverrideDto[0];
      public UnitOverrideDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return UnitOverrideDto.class;
      }
      public UnitOverrideDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(UnitOverrideDto.class, objId);
          }
          UnitOverrideDto entity = new UnitOverrideDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.demarshall(obj.get("unit"), a1));
          }
          if ((obj.containsKey("numericResultType")) && (!obj.get("numericResultType").isNull())) {
            entity.setNumericResultType((NumericResultTypeDto) java_lang_Object.demarshall(NumericResultTypeDto.class, obj.get("numericResultType"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitOverrideDto", t);
        }
      }
      public String marshall(UnitOverrideDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitOverrideDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1408).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitOverrideDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"unit\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.marshall(a0.getUnit(), a1)).append(",").append("\"numericResultType\" : ").append(java_lang_Object.marshall(a0.getNumericResultType(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.UnitOverrideDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitOverrideDto);
    ch_apkern_achilles_dto_shared_module_laboratory_library_ValueLibraryDto = new Marshaller<ValueLibraryDto>() {
      private ValueLibraryDto[] EMPTY_ARRAY = new ValueLibraryDto[0];
      public ValueLibraryDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ValueLibraryDto.class;
      }
      public ValueLibraryDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ValueLibraryDto.class, objId);
          }
          ValueLibraryDto entity = new ValueLibraryDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("unitOverride")) && (!obj.get("unitOverride").isNull())) {
            entity.setUnitOverride(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitOverrideDto.demarshall(obj.get("unitOverride"), a1));
          }
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("division")) && (!obj.get("division").isNull())) {
            entity.setDivision(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.demarshall(obj.get("division"), a1));
          }
          if ((obj.containsKey("measuringMethod")) && (!obj.get("measuringMethod").isNull())) {
            entity.setMeasuringMethod(ch_apkern_achilles_dto_shared_entity_core_GroupItemDto.demarshall(obj.get("measuringMethod"), a1));
          }
          if ((obj.containsKey("substance")) && (!obj.get("substance").isNull())) {
            entity.setSubstance(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SubstanceDto.demarshall(obj.get("substance"), a1));
          }
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.demarshall(obj.get("unit"), a1));
          }
          if ((obj.containsKey("formula")) && (!obj.get("formula").isNull())) {
            entity.setFormula(java_lang_String.demarshall(obj.get("formula"), a1));
          }
          if ((obj.containsKey("diagram")) && (!obj.get("diagram").isNull())) {
            entity.setDiagram(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.demarshall(obj.get("diagram"), a1));
          }
          if ((obj.containsKey("type")) && (!obj.get("type").isNull())) {
            entity.setType(obj.get("type").isObject() != null ? Enum.valueOf(LibraryTypeEnum.class, obj.get("type").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("type").isString() != null ? Enum.valueOf(LibraryTypeEnum.class, obj.get("type").isString().stringValue()) : null);
          }
          if ((obj.containsKey("libraryClass")) && (!obj.get("libraryClass").isNull())) {
            entity.setLibraryClass(obj.get("libraryClass").isObject() != null ? Enum.valueOf(ResultTypeEnum.class, obj.get("libraryClass").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("libraryClass").isString() != null ? Enum.valueOf(ResultTypeEnum.class, obj.get("libraryClass").isString().stringValue()) : null);
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("modificated")) && (!obj.get("modificated").isNull())) {
            entity.setModificated(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("modificated"), a1));
          }
          if ((obj.containsKey("selection")) && (!obj.get("selection").isNull())) {
            entity.setSelection(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto.demarshall(obj.get("selection"), a1));
          }
          if ((obj.containsKey("valueFormat")) && (!obj.get("valueFormat").isNull())) {
            entity.setValueFormat(ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto.demarshall(obj.get("valueFormat"), a1));
          }
          if ((obj.containsKey("remark")) && (!obj.get("remark").isNull())) {
            entity.setRemark(java_lang_String.demarshall(obj.get("remark"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDto", t);
        }
      }
      public String marshall(ValueLibraryDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(7040).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"unitOverride\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitOverrideDto.marshall(a0.getUnitOverride(), a1)).append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"division\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.marshall(a0.getDivision(), a1)).append(",").append("\"measuringMethod\" : ").append(ch_apkern_achilles_dto_shared_entity_core_GroupItemDto.marshall(a0.getMeasuringMethod(), a1)).append(",").append("\"substance\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SubstanceDto.marshall(a0.getSubstance(), a1)).append(",").append("\"unit\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.marshall(a0.getUnit(), a1)).append(",").append("\"formula\" : ").append(java_lang_String.marshall(a0.getFormula(), a1)).append(",").append("\"diagram\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.marshall(a0.getDiagram(), a1)).append(",").append("\"type\" : ").append(a0.getType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.LibraryTypeEnum\",\"^EnumStringValue\":\"").append(a0.getType().name()).append("\"}") : "null").append(",").append("\"libraryClass\" : ").append(a0.getLibraryClass() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.ResultTypeEnum\",\"^EnumStringValue\":\"").append(a0.getLibraryClass().name()).append("\"}") : "null").append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"modificated\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getModificated(), a1)).append(",").append("\"selection\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto.marshall(a0.getSelection(), a1)).append(",").append("\"valueFormat\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto.marshall(a0.getValueFormat(), a1)).append(",").append("\"remark\" : ").append(java_lang_String.marshall(a0.getRemark(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDto", ch_apkern_achilles_dto_shared_module_laboratory_library_ValueLibraryDto);
    ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryMeasuringDtoList = new Marshaller<LaboratoryMeasuringDtoList>() {
      private LaboratoryMeasuringDtoList[] EMPTY_ARRAY = new LaboratoryMeasuringDtoList[0];
      public LaboratoryMeasuringDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LaboratoryMeasuringDtoList.class;
      }
      public LaboratoryMeasuringDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LaboratoryMeasuringDtoList.class, objId);
          }
          LaboratoryMeasuringDtoList entity = new LaboratoryMeasuringDtoList();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("laboratoryMeasuringDtoList")) && (!obj.get("laboratoryMeasuringDtoList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDto");
            entity.setLaboratoryMeasuringDtoList(java_util_List.demarshall(obj.get("laboratoryMeasuringDtoList"), a1));
            a1.setAssumedElementType(null);
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDtoList", t);
        }
      }
      public String marshall(LaboratoryMeasuringDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"laboratoryMeasuringDtoList\" : ").append(java_util_List.marshall(a0.getLaboratoryMeasuringDtoList(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDtoList", ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryMeasuringDtoList);
    ch_apkern_achilles_concurrency_client_internal_transfer_PersistEventTransfer = new Marshaller<PersistEventTransfer>() {
      private PersistEventTransfer[] EMPTY_ARRAY = new PersistEventTransfer[0];
      public PersistEventTransfer[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PersistEventTransfer.class;
      }
      public PersistEventTransfer demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(PersistEventTransfer.class, objId);
          }
          final Object c0 = java_lang_Object.demarshall(Object.class, obj.get("value"), a1);
          final ClientInstanceId c1 = ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.demarshall(obj.get("clientInstanceId"), a1);
          final String c2 = java_lang_String.demarshall(obj.get("fieldId"), a1);
          final String c3 = java_lang_String.demarshall(obj.get("entityId"), a1);
          final Boolean c4 = java_lang_Boolean.demarshall(obj.get("finalPersist"), a1);
          PersistEventTransfer entity = new PersistEventTransfer(c0, c1, c2, c3, c4);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("clientInstanceId")) && (!obj.get("clientInstanceId").isNull())) {
            _$411629081_clientInstanceId(entity, ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.demarshall(obj.get("clientInstanceId"), a1));
          }
          if ((obj.containsKey("fieldId")) && (!obj.get("fieldId").isNull())) {
            _$411629081_fieldId(entity, java_lang_String.demarshall(obj.get("fieldId"), a1));
          }
          if ((obj.containsKey("entityId")) && (!obj.get("entityId").isNull())) {
            _$411629081_entityId(entity, java_lang_String.demarshall(obj.get("entityId"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.concurrency.client.internal.transfer.PersistEventTransfer", t);
        }
      }
      public String marshall(PersistEventTransfer a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.PersistEventTransfer\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(896).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.PersistEventTransfer\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"value\" : ").append(java_lang_Object.marshall(a0.getValue(), a1)).append(",").append("\"finalPersist\" : ").append(java_lang_Boolean.marshall(a0.getFinalPersist(), a1)).append(",").append("\"clientInstanceId\" : ").append(ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.marshall(a0.getClientInstanceId(), a1)).append(",").append("\"fieldId\" : ").append(java_lang_String.marshall(a0.getFieldId(), a1)).append(",").append("\"entityId\" : ").append(java_lang_String.marshall(a0.getEntityId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.PersistEventTransfer", ch_apkern_achilles_concurrency_client_internal_transfer_PersistEventTransfer);
    ch_apkern_achilles_dto_shared_entity_laboratory_provider_masterdata_ExternalProviderDto = new Marshaller<ExternalProviderDto>() {
      private ExternalProviderDto[] EMPTY_ARRAY = new ExternalProviderDto[0];
      public ExternalProviderDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ExternalProviderDto.class;
      }
      public ExternalProviderDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ExternalProviderDto.class, objId);
          }
          ExternalProviderDto entity = new ExternalProviderDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("measurandLibraryList")) && (!obj.get("measurandLibraryList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto");
            entity.setMeasurandLibraryList(java_util_List.demarshall(obj.get("measurandLibraryList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("address")) && (!obj.get("address").isNull())) {
            entity.setAddress(ch_apkern_achilles_dto_shared_entity_address_AddressDto.demarshall(obj.get("address"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("active")) && (!obj.get("active").isNull())) {
            entity.setActive(java_lang_Boolean.demarshall(obj.get("active"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.provider.masterdata.ExternalProviderDto", t);
        }
      }
      public String marshall(ExternalProviderDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.masterdata.ExternalProviderDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(2688).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.masterdata.ExternalProviderDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"measurandLibraryList\" : ").append(java_util_List.marshall(a0.getMeasurandLibraryList(), a1)).append(",").append("\"address\" : ").append(ch_apkern_achilles_dto_shared_entity_address_AddressDto.marshall(a0.getAddress(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"active\" : ").append(java_lang_Boolean.marshall(a0.getActive(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.provider.masterdata.ExternalProviderDto", ch_apkern_achilles_dto_shared_entity_laboratory_provider_masterdata_ExternalProviderDto);
    ch_apkern_achilles_dto_shared_module_search_SearchParameter = new Marshaller<SearchParameter>() {
      private SearchParameter[] EMPTY_ARRAY = new SearchParameter[0];
      public SearchParameter[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SearchParameter.class;
      }
      public SearchParameter demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(SearchParameter.class, objId);
          }
          SearchParameter entity = new SearchParameter();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("parameterValue")) && (!obj.get("parameterValue").isNull())) {
            entity.setParameterValue(java_lang_String.demarshall(obj.get("parameterValue"), a1));
          }
          if ((obj.containsKey("parameterEnumName")) && (!obj.get("parameterEnumName").isNull())) {
            entity.setParameterEnumName((SearchCriterionEnum) java_lang_Object.demarshall(SearchCriterionEnum.class, obj.get("parameterEnumName"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.search.SearchParameter", t);
        }
      }
      public String marshall(SearchParameter a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.search.SearchParameter\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.search.SearchParameter\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"parameterValue\" : ").append(java_lang_String.marshall(a0.getParameterValue(), a1)).append(",").append("\"parameterEnumName\" : ").append(java_lang_Object.marshall(a0.getParameterEnumName(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.search.SearchParameter", ch_apkern_achilles_dto_shared_module_search_SearchParameter);
    ch_apkern_achilles_dto_shared_module_laboratory_SimpleDateFilterCriteriaDto = new Marshaller<SimpleDateFilterCriteriaDto>() {
      private SimpleDateFilterCriteriaDto[] EMPTY_ARRAY = new SimpleDateFilterCriteriaDto[0];
      public SimpleDateFilterCriteriaDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SimpleDateFilterCriteriaDto.class;
      }
      public SimpleDateFilterCriteriaDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(SimpleDateFilterCriteriaDto.class, objId);
          }
          SimpleDateFilterCriteriaDto entity = new SimpleDateFilterCriteriaDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("dateFrom")) && (!obj.get("dateFrom").isNull())) {
            entity.setDateFrom(java_util_Date.demarshall(obj.get("dateFrom"), a1));
          }
          if ((obj.containsKey("dateUntil")) && (!obj.get("dateUntil").isNull())) {
            entity.setDateUntil(java_util_Date.demarshall(obj.get("dateUntil"), a1));
          }
          if ((obj.containsKey("dateFilterType")) && (!obj.get("dateFilterType").isNull())) {
            entity.setDateFilterType(obj.get("dateFilterType").isObject() != null ? Enum.valueOf(MeasuringDateFilterTypeEnum.class, obj.get("dateFilterType").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("dateFilterType").isString() != null ? Enum.valueOf(MeasuringDateFilterTypeEnum.class, obj.get("dateFilterType").isString().stringValue()) : null);
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.SimpleDateFilterCriteriaDto", t);
        }
      }
      public String marshall(SimpleDateFilterCriteriaDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.SimpleDateFilterCriteriaDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(512).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.SimpleDateFilterCriteriaDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"dateFrom\" : ").append(java_util_Date.marshall(a0.getDateFrom(), a1)).append(",").append("\"dateUntil\" : ").append(java_util_Date.marshall(a0.getDateUntil(), a1)).append(",").append("\"dateFilterType\" : ").append(a0.getDateFilterType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringDateFilterTypeEnum\",\"^EnumStringValue\":\"").append(a0.getDateFilterType().name()).append("\"}") : "null").append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.SimpleDateFilterCriteriaDto", ch_apkern_achilles_dto_shared_module_laboratory_SimpleDateFilterCriteriaDto);
    ch_apkern_achilles_dto_shared_entity_patient_PersonReferenceGroupItemDto = new Marshaller<PersonReferenceGroupItemDto>() {
      private PersonReferenceGroupItemDto[] EMPTY_ARRAY = new PersonReferenceGroupItemDto[0];
      public PersonReferenceGroupItemDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PersonReferenceGroupItemDto.class;
      }
      public PersonReferenceGroupItemDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(PersonReferenceGroupItemDto.class, objId);
          }
          PersonReferenceGroupItemDto entity = new PersonReferenceGroupItemDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("type")) && (!obj.get("type").isNull())) {
            entity.setType(obj.get("type").isObject() != null ? Enum.valueOf(PersonReferenceTypeEnum.class, obj.get("type").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("type").isString() != null ? Enum.valueOf(PersonReferenceTypeEnum.class, obj.get("type").isString().stringValue()) : null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceGroupItemDto", t);
        }
      }
      public String marshall(PersonReferenceGroupItemDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceGroupItemDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceGroupItemDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"type\" : ").append(a0.getType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.patient.PersonReferenceTypeEnum\",\"^EnumStringValue\":\"").append(a0.getType().name()).append("\"}") : "null").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceGroupItemDto", ch_apkern_achilles_dto_shared_entity_patient_PersonReferenceGroupItemDto);
    ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryMeasuringDto = new Marshaller<LaboratoryMeasuringDto>() {
      private LaboratoryMeasuringDto[] EMPTY_ARRAY = new LaboratoryMeasuringDto[0];
      public LaboratoryMeasuringDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LaboratoryMeasuringDto.class;
      }
      public LaboratoryMeasuringDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LaboratoryMeasuringDto.class, objId);
          }
          LaboratoryMeasuringDto entity = new LaboratoryMeasuringDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("analysisDate")) && (!obj.get("analysisDate").isNull())) {
            entity.setAnalysisDate(java_util_Date.demarshall(obj.get("analysisDate"), a1));
          }
          if ((obj.containsKey("newEntry")) && (!obj.get("newEntry").isNull())) {
            entity.setNewEntry(java_lang_Boolean.demarshall(obj.get("newEntry"), a1));
          }
          if ((obj.containsKey("receiveDate")) && (!obj.get("receiveDate").isNull())) {
            entity.setReceiveDate(java_util_Date.demarshall(obj.get("receiveDate"), a1));
          }
          if ((obj.containsKey("assignedPatient")) && (!obj.get("assignedPatient").isNull())) {
            entity.setAssignedPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("assignedPatient"), a1));
          }
          if ((obj.containsKey("controller")) && (!obj.get("controller").isNull())) {
            entity.setController(ch_apkern_achilles_dto_shared_entity_core_UserDto.demarshall(obj.get("controller"), a1));
          }
          if ((obj.containsKey("patientIdentification")) && (!obj.get("patientIdentification").isNull())) {
            entity.setPatientIdentification(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.demarshall(obj.get("patientIdentification"), a1));
          }
          if ((obj.containsKey("provider")) && (!obj.get("provider").isNull())) {
            entity.setProvider((ProviderDto) java_lang_Object.demarshall(ProviderDto.class, obj.get("provider"), a1));
          }
          if ((obj.containsKey("measuringDate")) && (!obj.get("measuringDate").isNull())) {
            entity.setMeasuringDate(java_util_Date.demarshall(obj.get("measuringDate"), a1));
          }
          if ((obj.containsKey("treatment")) && (!obj.get("treatment").isNull())) {
            entity.setTreatment(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.demarshall(obj.get("treatment"), a1));
          }
          if ((obj.containsKey("manual")) && (!obj.get("manual").isNull())) {
            entity.setManual(java_lang_Boolean.demarshall(obj.get("manual"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDto", t);
        }
      }
      public String marshall(LaboratoryMeasuringDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(8192).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"analysisDate\" : ").append(java_util_Date.marshall(a0.getAnalysisDate(), a1)).append(",").append("\"newEntry\" : ").append(java_lang_Boolean.marshall(a0.getNewEntry(), a1)).append(",").append("\"receiveDate\" : ").append(java_util_Date.marshall(a0.getReceiveDate(), a1)).append(",").append("\"assignedPatient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getAssignedPatient(), a1)).append(",").append("\"controller\" : ").append(ch_apkern_achilles_dto_shared_entity_core_UserDto.marshall(a0.getController(), a1)).append(",").append("\"patientIdentification\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.marshall(a0.getPatientIdentification(), a1)).append(",").append("\"provider\" : ").append(java_lang_Object.marshall(a0.getProvider(), a1)).append(",").append("\"measuringDate\" : ").append(java_util_Date.marshall(a0.getMeasuringDate(), a1)).append(",").append("\"treatment\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.marshall(a0.getTreatment(), a1)).append(",").append("\"manual\" : ").append(java_lang_Boolean.marshall(a0.getManual(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.LaboratoryMeasuringDto", ch_apkern_achilles_dto_shared_module_laboratory_LaboratoryMeasuringDto);
    ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_list_LibraryListDto = new Marshaller<LibraryListDto>() {
      private LibraryListDto[] EMPTY_ARRAY = new LibraryListDto[0];
      public LibraryListDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LibraryListDto.class;
      }
      public LibraryListDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LibraryListDto.class, objId);
          }
          LibraryListDto entity = new LibraryListDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("tariff")) && (!obj.get("tariff").isNull())) {
            entity.setTariff(java_lang_String.demarshall(obj.get("tariff"), a1));
          }
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(java_lang_String.demarshall(obj.get("unit"), a1));
          }
          if ((obj.containsKey("division")) && (!obj.get("division").isNull())) {
            entity.setDivision(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.demarshall(obj.get("division"), a1));
          }
          if ((obj.containsKey("resultType")) && (!obj.get("resultType").isNull())) {
            entity.setResultType(obj.get("resultType").isObject() != null ? Enum.valueOf(ResultTypeEnum.class, obj.get("resultType").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("resultType").isString() != null ? Enum.valueOf(ResultTypeEnum.class, obj.get("resultType").isString().stringValue()) : null);
          }
          if ((obj.containsKey("libraryType")) && (!obj.get("libraryType").isNull())) {
            entity.setLibraryType(obj.get("libraryType").isObject() != null ? Enum.valueOf(LibraryTypeEnum.class, obj.get("libraryType").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("libraryType").isString() != null ? Enum.valueOf(LibraryTypeEnum.class, obj.get("libraryType").isString().stringValue()) : null);
          }
          if ((obj.containsKey("substance")) && (!obj.get("substance").isNull())) {
            entity.setSubstance(java_lang_String.demarshall(obj.get("substance"), a1));
          }
          if ((obj.containsKey("qualabTolerance")) && (!obj.get("qualabTolerance").isNull())) {
            entity.setQualabTolerance(java_lang_String.demarshall(obj.get("qualabTolerance"), a1));
          }
          if ((obj.containsKey("min")) && (!obj.get("min").isNull())) {
            entity.setMin(java_lang_String.demarshall(obj.get("min"), a1));
          }
          if ((obj.containsKey("max")) && (!obj.get("max").isNull())) {
            entity.setMax(java_lang_String.demarshall(obj.get("max"), a1));
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.list.LibraryListDto", t);
        }
      }
      public String marshall(LibraryListDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.list.LibraryListDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3584).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.list.LibraryListDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"tariff\" : ").append(java_lang_String.marshall(a0.getTariff(), a1)).append(",").append("\"unit\" : ").append(java_lang_String.marshall(a0.getUnit(), a1)).append(",").append("\"division\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.marshall(a0.getDivision(), a1)).append(",").append("\"resultType\" : ").append(a0.getResultType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.ResultTypeEnum\",\"^EnumStringValue\":\"").append(a0.getResultType().name()).append("\"}") : "null").append(",").append("\"libraryType\" : ").append(a0.getLibraryType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.LibraryTypeEnum\",\"^EnumStringValue\":\"").append(a0.getLibraryType().name()).append("\"}") : "null").append(",").append("\"substance\" : ").append(java_lang_String.marshall(a0.getSubstance(), a1)).append(",").append("\"qualabTolerance\" : ").append(java_lang_String.marshall(a0.getQualabTolerance(), a1)).append(",").append("\"min\" : ").append(java_lang_String.marshall(a0.getMin(), a1)).append(",").append("\"max\" : ").append(java_lang_String.marshall(a0.getMax(), a1)).append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.list.LibraryListDto", ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_list_LibraryListDto);
    ch_apkern_achilles_dto_shared_module_laboratory_DetailResultDtoList = new Marshaller<DetailResultDtoList>() {
      private DetailResultDtoList[] EMPTY_ARRAY = new DetailResultDtoList[0];
      public DetailResultDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return DetailResultDtoList.class;
      }
      public DetailResultDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(DetailResultDtoList.class, objId);
          }
          DetailResultDtoList entity = new DetailResultDtoList();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("results")) && (!obj.get("results").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDto");
            entity.setResults(java_util_List.demarshall(obj.get("results"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("manual")) && (!obj.get("manual").isNull())) {
            entity.setManual(java_lang_Boolean.demarshall(obj.get("manual"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDtoList", t);
        }
      }
      public String marshall(DetailResultDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"results\" : ").append(java_util_List.marshall(a0.getResults(), a1)).append(",").append("\"manual\" : ").append(java_lang_Boolean.marshall(a0.getManual(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.DetailResultDtoList", ch_apkern_achilles_dto_shared_module_laboratory_DetailResultDtoList);
    ch_apkern_achilles_dto_shared_entity_address_LegalPersonDto = new Marshaller<LegalPersonDto>() {
      private LegalPersonDto[] EMPTY_ARRAY = new LegalPersonDto[0];
      public LegalPersonDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LegalPersonDto.class;
      }
      public LegalPersonDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LegalPersonDto.class, objId);
          }
          LegalPersonDto entity = new LegalPersonDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("eanNumber")) && (!obj.get("eanNumber").isNull())) {
            entity.setEanNumber(java_lang_String.demarshall(obj.get("eanNumber"), a1));
          }
          if ((obj.containsKey("address")) && (!obj.get("address").isNull())) {
            entity.setAddress(ch_apkern_achilles_dto_shared_entity_address_AddressDto.demarshall(obj.get("address"), a1));
          }
          if ((obj.containsKey("metaFieldValueList")) && (!obj.get("metaFieldValueList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.core.MetaFieldValueDto");
            entity.setMetaFieldValueList(java_util_List.demarshall(obj.get("metaFieldValueList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.address.LegalPersonDto", t);
        }
      }
      public String marshall(LegalPersonDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.LegalPersonDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(2560).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.address.LegalPersonDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"eanNumber\" : ").append(java_lang_String.marshall(a0.getEanNumber(), a1)).append(",").append("\"address\" : ").append(ch_apkern_achilles_dto_shared_entity_address_AddressDto.marshall(a0.getAddress(), a1)).append(",").append("\"metaFieldValueList\" : ").append(java_util_List.marshall(a0.getMetaFieldValueList(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.address.LegalPersonDto", ch_apkern_achilles_dto_shared_entity_address_LegalPersonDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_NumericResultDto = new Marshaller<NumericResultDto>() {
      private NumericResultDto[] EMPTY_ARRAY = new NumericResultDto[0];
      public NumericResultDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return NumericResultDto.class;
      }
      public NumericResultDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(NumericResultDto.class, objId);
          }
          NumericResultDto entity = new NumericResultDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("value")) && (!obj.get("value").isNull())) {
            entity.setValue(java_math_BigDecimal.demarshall(obj.get("value"), a1));
          }
          if ((obj.containsKey("prefix")) && (!obj.get("prefix").isNull())) {
            entity.setPrefix(java_lang_String.demarshall(obj.get("prefix"), a1));
          }
          if ((obj.containsKey("measuring")) && (!obj.get("measuring").isNull())) {
            entity.setMeasuring((MeasuringDto) java_lang_Object.demarshall(MeasuringDto.class, obj.get("measuring"), a1));
          }
          if ((obj.containsKey("measurandLibrary")) && (!obj.get("measurandLibrary").isNull())) {
            entity.setMeasurandLibrary((MeasurandLibraryDto) java_lang_Object.demarshall(MeasurandLibraryDto.class, obj.get("measurandLibrary"), a1));
          }
          if ((obj.containsKey("measurandReference")) && (!obj.get("measurandReference").isNull())) {
            entity.setMeasurandReference((MeasurandReferenceDto) java_lang_Object.demarshall(MeasurandReferenceDto.class, obj.get("measurandReference"), a1));
          }
          if ((obj.containsKey("chargeResult")) && (!obj.get("chargeResult").isNull())) {
            entity.setChargeResult(java_lang_Boolean.demarshall(obj.get("chargeResult"), a1));
          }
          if ((obj.containsKey("visible")) && (!obj.get("visible").isNull())) {
            entity.setVisible(java_lang_Boolean.demarshall(obj.get("visible"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.NumericResultDto", t);
        }
      }
      public String marshall(NumericResultDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.NumericResultDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1152).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.NumericResultDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"value\" : ").append(java_math_BigDecimal.marshall(a0.getValue(), a1)).append(",").append("\"prefix\" : ").append(java_lang_String.marshall(a0.getPrefix(), a1)).append(",").append("\"measuring\" : ").append(java_lang_Object.marshall(a0.getMeasuring(), a1)).append(",").append("\"measurandLibrary\" : ").append(java_lang_Object.marshall(a0.getMeasurandLibrary(), a1)).append(",").append("\"measurandReference\" : ").append(java_lang_Object.marshall(a0.getMeasurandReference(), a1)).append(",").append("\"chargeResult\" : ").append(java_lang_Boolean.marshall(a0.getChargeResult(), a1)).append(",").append("\"visible\" : ").append(java_lang_Boolean.marshall(a0.getVisible(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.NumericResultDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_NumericResultDto);
    java_lang_AssertionError = new Marshaller<AssertionError>() {
      private AssertionError[] EMPTY_ARRAY = new AssertionError[0];
      public AssertionError[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return AssertionError.class;
      }
      public AssertionError demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(AssertionError.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          AssertionError entity = new AssertionError(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.AssertionError", t);
        }
      }
      public String marshall(AssertionError a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.AssertionError\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.AssertionError\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.AssertionError", java_lang_AssertionError);
    java_lang_ArrayStoreException = new Marshaller<ArrayStoreException>() {
      private ArrayStoreException[] EMPTY_ARRAY = new ArrayStoreException[0];
      public ArrayStoreException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ArrayStoreException.class;
      }
      public ArrayStoreException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ArrayStoreException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          ArrayStoreException entity = new ArrayStoreException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.ArrayStoreException", t);
        }
      }
      public String marshall(ArrayStoreException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.ArrayStoreException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.ArrayStoreException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.ArrayStoreException", java_lang_ArrayStoreException);
    ch_apkern_achilles_concurrency_client_internal_transfer_ValueBroadcastEventTransfer = new Marshaller<ValueBroadcastEventTransfer>() {
      private ValueBroadcastEventTransfer[] EMPTY_ARRAY = new ValueBroadcastEventTransfer[0];
      public ValueBroadcastEventTransfer[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ValueBroadcastEventTransfer.class;
      }
      public ValueBroadcastEventTransfer demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ValueBroadcastEventTransfer.class, objId);
          }
          final ClientInstanceId c0 = ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.demarshall(obj.get("clientInstanceId"), a1);
          final String c1 = java_lang_String.demarshall(obj.get("editor"), a1);
          final Object c2 = java_lang_Object.demarshall(Object.class, obj.get("value"), a1);
          a1.setAssumedElementType("ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer$ValueBroadcastEventEntry");
          final Set<ValueBroadcastEventEntry> c3 = java_util_Set.demarshall(obj.get("broadcastEventEntries"), a1);
          a1.setAssumedElementType(null);
          final Boolean c4 = java_lang_Boolean.demarshall(obj.get("finalUpdate"), a1);
          ValueBroadcastEventTransfer entity = new ValueBroadcastEventTransfer(c0, c1, c2, c3, c4);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer", t);
        }
      }
      public String marshall(ValueBroadcastEventTransfer a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(896).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"clientInstanceId\" : ").append(ch_apkern_achilles_concurrency_client_internal_model_ClientInstanceId.marshall(a0.getClientInstanceId(), a1)).append(",").append("\"editor\" : ").append(java_lang_String.marshall(a0.getEditor(), a1)).append(",").append("\"broadcastEventEntries\" : ").append(java_util_Set.marshall(a0.getBroadcastEventEntries(), a1)).append(",").append("\"value\" : ").append(java_lang_Object.marshall(a0.getValue(), a1)).append(",").append("\"finalUpdate\" : ").append(java_lang_Boolean.marshall(a0.isFinalUpdate(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.ValueBroadcastEventTransfer", ch_apkern_achilles_concurrency_client_internal_transfer_ValueBroadcastEventTransfer);
    ch_apkern_achilles_api_shared_validation_ValidationStateEnum = new Marshaller<ValidationStateEnum>() {
      private ValidationStateEnum[] EMPTY_ARRAY = new ValidationStateEnum[0];
      public ValidationStateEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ValidationStateEnum.class;
      }
      public ValidationStateEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          ValidationStateEnum entity = obj != null ? Enum.valueOf(ValidationStateEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(ValidationStateEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.api.shared.validation.ValidationStateEnum", t);
        }
      }
      public String marshall(ValidationStateEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.api.shared.validation.ValidationStateEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.api.shared.validation.ValidationStateEnum", ch_apkern_achilles_api_shared_validation_ValidationStateEnum);
    ch_apkern_achilles_dto_shared_module_search_criteria_LaboratorySearchCriterionEnum = new Marshaller<LaboratorySearchCriterionEnum>() {
      private LaboratorySearchCriterionEnum[] EMPTY_ARRAY = new LaboratorySearchCriterionEnum[0];
      public LaboratorySearchCriterionEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LaboratorySearchCriterionEnum.class;
      }
      public LaboratorySearchCriterionEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          LaboratorySearchCriterionEnum entity = obj != null ? Enum.valueOf(LaboratorySearchCriterionEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(LaboratorySearchCriterionEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.search.criteria.LaboratorySearchCriterionEnum", t);
        }
      }
      public String marshall(LaboratorySearchCriterionEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.search.criteria.LaboratorySearchCriterionEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.search.criteria.LaboratorySearchCriterionEnum", ch_apkern_achilles_dto_shared_module_search_criteria_LaboratorySearchCriterionEnum);
    ch_apkern_achilles_dto_shared_module_patient_PatientDetailDto = new Marshaller<PatientDetailDto>() {
      private PatientDetailDto[] EMPTY_ARRAY = new PatientDetailDto[0];
      public PatientDetailDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PatientDetailDto.class;
      }
      public PatientDetailDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(PatientDetailDto.class, objId);
          }
          PatientDetailDto entity = new PatientDetailDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("patient")) && (!obj.get("patient").isNull())) {
            entity.setPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("patient"), a1));
          }
          if ((obj.containsKey("person")) && (!obj.get("person").isNull())) {
            entity.setPerson(ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto.demarshall(obj.get("person"), a1));
          }
          if ((obj.containsKey("field1")) && (!obj.get("field1").isNull())) {
            entity.setField1(ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto.demarshall(obj.get("field1"), a1));
          }
          if ((obj.containsKey("field2")) && (!obj.get("field2").isNull())) {
            entity.setField2(ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto.demarshall(obj.get("field2"), a1));
          }
          if ((obj.containsKey("field3")) && (!obj.get("field3").isNull())) {
            entity.setField3(ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto.demarshall(obj.get("field3"), a1));
          }
          if ((obj.containsKey("field4")) && (!obj.get("field4").isNull())) {
            entity.setField4(ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto.demarshall(obj.get("field4"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.patient.PatientDetailDto", t);
        }
      }
      public String marshall(PatientDetailDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.patient.PatientDetailDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(6272).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.patient.PatientDetailDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"patient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getPatient(), a1)).append(",").append("\"person\" : ").append(ch_apkern_achilles_dto_shared_entity_address_NaturalPersonDto.marshall(a0.getPerson(), a1)).append(",").append("\"field1\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto.marshall(a0.getField1(), a1)).append(",").append("\"field2\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto.marshall(a0.getField2(), a1)).append(",").append("\"field3\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto.marshall(a0.getField3(), a1)).append(",").append("\"field4\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MetaFieldValueDto.marshall(a0.getField4(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.patient.PatientDetailDto", ch_apkern_achilles_dto_shared_module_patient_PatientDetailDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ReferenceSolutionLotDto = new Marshaller<ReferenceSolutionLotDto>() {
      private ReferenceSolutionLotDto[] EMPTY_ARRAY = new ReferenceSolutionLotDto[0];
      public ReferenceSolutionLotDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ReferenceSolutionLotDto.class;
      }
      public ReferenceSolutionLotDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ReferenceSolutionLotDto.class, objId);
          }
          ReferenceSolutionLotDto entity = new ReferenceSolutionLotDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("lotNumber")) && (!obj.get("lotNumber").isNull())) {
            entity.setLotNumber(java_lang_String.demarshall(obj.get("lotNumber"), a1));
          }
          if ((obj.containsKey("deviceType")) && (!obj.get("deviceType").isNull())) {
            entity.setDeviceType(ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceTypeDto.demarshall(obj.get("deviceType"), a1));
          }
          if ((obj.containsKey("validUntil")) && (!obj.get("validUntil").isNull())) {
            entity.setValidUntil(java_util_Date.demarshall(obj.get("validUntil"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ReferenceSolutionLotDto", t);
        }
      }
      public String marshall(ReferenceSolutionLotDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ReferenceSolutionLotDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1152).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ReferenceSolutionLotDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"lotNumber\" : ").append(java_lang_String.marshall(a0.getLotNumber(), a1)).append(",").append("\"deviceType\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceTypeDto.marshall(a0.getDeviceType(), a1)).append(",").append("\"validUntil\" : ").append(java_util_Date.marshall(a0.getValidUntil(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ReferenceSolutionLotDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ReferenceSolutionLotDto);
    java_lang_StackTraceElement = new Marshaller<StackTraceElement>() {
      private StackTraceElement[] EMPTY_ARRAY = new StackTraceElement[0];
      public StackTraceElement[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return StackTraceElement.class;
      }
      public StackTraceElement demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(StackTraceElement.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("declaringClass"), a1);
          final String c1 = java_lang_String.demarshall(obj.get("methodName"), a1);
          final String c2 = java_lang_String.demarshall(obj.get("fileName"), a1);
          final Integer c3 = java_lang_Integer.demarshall(obj.get("lineNumber"), a1);
          StackTraceElement entity = new StackTraceElement(c0, c1, c2, c3);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.StackTraceElement", t);
        }
      }
      public String marshall(StackTraceElement a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.StackTraceElement\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"java.lang.StackTraceElement\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"fileName\" : ").append(java_lang_String.marshall(a0.getFileName(), a1)).append(",").append("\"methodName\" : ").append(java_lang_String.marshall(a0.getMethodName(), a1)).append(",").append("\"lineNumber\" : ").append(java_lang_Integer.marshall(a0.getLineNumber(), a1)).append(",").append("\"declaringClass\" : ").append(java_lang_String.marshall(a0.getClassName(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.StackTraceElement", java_lang_StackTraceElement);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_ResultReferenceDto = new Marshaller<ResultReferenceDto>() {
      private ResultReferenceDto[] EMPTY_ARRAY = new ResultReferenceDto[0];
      public ResultReferenceDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ResultReferenceDto.class;
      }
      public ResultReferenceDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ResultReferenceDto.class, objId);
          }
          ResultReferenceDto entity = new ResultReferenceDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("selectionInToleranceList")) && (!obj.get("selectionInToleranceList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto");
            entity.setSelectionInToleranceList(java_util_List.demarshall(obj.get("selectionInToleranceList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("lowerBound")) && (!obj.get("lowerBound").isNull())) {
            entity.setLowerBound(java_math_BigDecimal.demarshall(obj.get("lowerBound"), a1));
          }
          if ((obj.containsKey("upperBound")) && (!obj.get("upperBound").isNull())) {
            entity.setUpperBound(java_math_BigDecimal.demarshall(obj.get("upperBound"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.ResultReferenceDto", t);
        }
      }
      public String marshall(ResultReferenceDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.ResultReferenceDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.ResultReferenceDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"selectionInToleranceList\" : ").append(java_util_List.marshall(a0.getSelectionInToleranceList(), a1)).append(",").append("\"lowerBound\" : ").append(java_math_BigDecimal.marshall(a0.getLowerBound(), a1)).append(",").append("\"upperBound\" : ").append(java_math_BigDecimal.marshall(a0.getUpperBound(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.ResultReferenceDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_ResultReferenceDto);
    ch_apkern_achilles_model_shared_entity_core_MetaFieldTypeEnum = new Marshaller<MetaFieldTypeEnum>() {
      private MetaFieldTypeEnum[] EMPTY_ARRAY = new MetaFieldTypeEnum[0];
      public MetaFieldTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MetaFieldTypeEnum.class;
      }
      public MetaFieldTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          MetaFieldTypeEnum entity = obj != null ? Enum.valueOf(MetaFieldTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(MetaFieldTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.model.shared.entity.core.MetaFieldTypeEnum", t);
        }
      }
      public String marshall(MetaFieldTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.MetaFieldTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.model.shared.entity.core.MetaFieldTypeEnum", ch_apkern_achilles_model_shared_entity_core_MetaFieldTypeEnum);
    java_lang_RuntimeException = new Marshaller<RuntimeException>() {
      private RuntimeException[] EMPTY_ARRAY = new RuntimeException[0];
      public RuntimeException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return RuntimeException.class;
      }
      public RuntimeException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(RuntimeException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          RuntimeException entity = new RuntimeException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.RuntimeException", t);
        }
      }
      public String marshall(RuntimeException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.RuntimeException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.RuntimeException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.RuntimeException", java_lang_RuntimeException);
    ch_apkern_achilles_dto_shared_module_patient_PersonAddressDto = new Marshaller<PersonAddressDto>() {
      private PersonAddressDto[] EMPTY_ARRAY = new PersonAddressDto[0];
      public PersonAddressDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PersonAddressDto.class;
      }
      public PersonAddressDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(PersonAddressDto.class, objId);
          }
          PersonAddressDto entity = new PersonAddressDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("personId")) && (!obj.get("personId").isNull())) {
            entity.setPersonId(java_lang_String.demarshall(obj.get("personId"), a1));
          }
          if ((obj.containsKey("postCode")) && (!obj.get("postCode").isNull())) {
            entity.setPostCode(java_lang_String.demarshall(obj.get("postCode"), a1));
          }
          if ((obj.containsKey("cityList")) && (!obj.get("cityList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.address.CityDto");
            entity.setCityList(java_util_List.demarshall(obj.get("cityList"), a1));
            a1.setAssumedElementType(null);
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.patient.PersonAddressDto", t);
        }
      }
      public String marshall(PersonAddressDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.patient.PersonAddressDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(512).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.patient.PersonAddressDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"personId\" : ").append(java_lang_String.marshall(a0.getPersonId(), a1)).append(",").append("\"postCode\" : ").append(java_lang_String.marshall(a0.getPostCode(), a1)).append(",").append("\"cityList\" : ").append(java_util_List.marshall(a0.getCityList(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.patient.PersonAddressDto", ch_apkern_achilles_dto_shared_module_patient_PersonAddressDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceProviderDto = new Marshaller<DeviceProviderDto>() {
      private DeviceProviderDto[] EMPTY_ARRAY = new DeviceProviderDto[0];
      public DeviceProviderDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return DeviceProviderDto.class;
      }
      public DeviceProviderDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(DeviceProviderDto.class, objId);
          }
          DeviceProviderDto entity = new DeviceProviderDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("serialNumber")) && (!obj.get("serialNumber").isNull())) {
            entity.setSerialNumber(java_lang_String.demarshall(obj.get("serialNumber"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("active")) && (!obj.get("active").isNull())) {
            entity.setActive(java_lang_Boolean.demarshall(obj.get("active"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceProviderDto", t);
        }
      }
      public String marshall(DeviceProviderDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceProviderDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceProviderDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"serialNumber\" : ").append(java_lang_String.marshall(a0.getSerialNumber(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"active\" : ").append(java_lang_Boolean.marshall(a0.getActive(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.provider.DeviceProviderDto", ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceProviderDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_ExternalLaboratoryMeasuringDto = new Marshaller<ExternalLaboratoryMeasuringDto>() {
      private ExternalLaboratoryMeasuringDto[] EMPTY_ARRAY = new ExternalLaboratoryMeasuringDto[0];
      public ExternalLaboratoryMeasuringDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ExternalLaboratoryMeasuringDto.class;
      }
      public ExternalLaboratoryMeasuringDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ExternalLaboratoryMeasuringDto.class, objId);
          }
          ExternalLaboratoryMeasuringDto entity = new ExternalLaboratoryMeasuringDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("analysisReferenceNumber")) && (!obj.get("analysisReferenceNumber").isNull())) {
            entity.setAnalysisReferenceNumber(java_lang_String.demarshall(obj.get("analysisReferenceNumber"), a1));
          }
          if ((obj.containsKey("externalProvider")) && (!obj.get("externalProvider").isNull())) {
            entity.setExternalProvider(ch_apkern_achilles_dto_shared_entity_laboratory_provider_masterdata_ExternalProviderDto.demarshall(obj.get("externalProvider"), a1));
          }
          if ((obj.containsKey("analysisDate")) && (!obj.get("analysisDate").isNull())) {
            entity.setAnalysisDate(java_util_Date.demarshall(obj.get("analysisDate"), a1));
          }
          if ((obj.containsKey("newEntry")) && (!obj.get("newEntry").isNull())) {
            entity.setNewEntry(java_lang_Boolean.demarshall(obj.get("newEntry"), a1));
          }
          if ((obj.containsKey("receiveDate")) && (!obj.get("receiveDate").isNull())) {
            entity.setReceiveDate(java_util_Date.demarshall(obj.get("receiveDate"), a1));
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("authorized")) && (!obj.get("authorized").isNull())) {
            entity.setAuthorized(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("authorized"), a1));
          }
          if ((obj.containsKey("patient")) && (!obj.get("patient").isNull())) {
            entity.setPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("patient"), a1));
          }
          if ((obj.containsKey("patientIdentification")) && (!obj.get("patientIdentification").isNull())) {
            entity.setPatientIdentification(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.demarshall(obj.get("patientIdentification"), a1));
          }
          if ((obj.containsKey("mandator")) && (!obj.get("mandator").isNull())) {
            entity.setMandator(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.demarshall(obj.get("mandator"), a1));
          }
          if ((obj.containsKey("measuringDate")) && (!obj.get("measuringDate").isNull())) {
            entity.setMeasuringDate(java_util_Date.demarshall(obj.get("measuringDate"), a1));
          }
          if ((obj.containsKey("treatment")) && (!obj.get("treatment").isNull())) {
            entity.setTreatment(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.demarshall(obj.get("treatment"), a1));
          }
          if ((obj.containsKey("manual")) && (!obj.get("manual").isNull())) {
            entity.setManual(java_lang_Boolean.demarshall(obj.get("manual"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.ExternalLaboratoryMeasuringDto", t);
        }
      }
      public String marshall(ExternalLaboratoryMeasuringDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.ExternalLaboratoryMeasuringDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(9728).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.ExternalLaboratoryMeasuringDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"analysisReferenceNumber\" : ").append(java_lang_String.marshall(a0.getAnalysisReferenceNumber(), a1)).append(",").append("\"externalProvider\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_provider_masterdata_ExternalProviderDto.marshall(a0.getExternalProvider(), a1)).append(",").append("\"analysisDate\" : ").append(java_util_Date.marshall(a0.getAnalysisDate(), a1)).append(",").append("\"newEntry\" : ").append(java_lang_Boolean.marshall(a0.getNewEntry(), a1)).append(",").append("\"receiveDate\" : ").append(java_util_Date.marshall(a0.getReceiveDate(), a1)).append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"authorized\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getAuthorized(), a1)).append(",").append("\"patient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getPatient(), a1)).append(",").append("\"patientIdentification\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.marshall(a0.getPatientIdentification(), a1)).append(",").append("\"mandator\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.marshall(a0.getMandator(), a1)).append(",").append("\"measuringDate\" : ").append(java_util_Date.marshall(a0.getMeasuringDate(), a1)).append(",").append("\"treatment\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.marshall(a0.getTreatment(), a1)).append(",").append("\"manual\" : ").append(java_lang_Boolean.marshall(a0.getManual(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.ExternalLaboratoryMeasuringDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_ExternalLaboratoryMeasuringDto);
    java_lang_NegativeArraySizeException = new Marshaller<NegativeArraySizeException>() {
      private NegativeArraySizeException[] EMPTY_ARRAY = new NegativeArraySizeException[0];
      public NegativeArraySizeException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return NegativeArraySizeException.class;
      }
      public NegativeArraySizeException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(NegativeArraySizeException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          NegativeArraySizeException entity = new NegativeArraySizeException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.NegativeArraySizeException", t);
        }
      }
      public String marshall(NegativeArraySizeException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.NegativeArraySizeException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.NegativeArraySizeException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.NegativeArraySizeException", java_lang_NegativeArraySizeException);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_CalculatedResultTypeDto = new Marshaller<CalculatedResultTypeDto>() {
      private CalculatedResultTypeDto[] EMPTY_ARRAY = new CalculatedResultTypeDto[0];
      public CalculatedResultTypeDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return CalculatedResultTypeDto.class;
      }
      public CalculatedResultTypeDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(CalculatedResultTypeDto.class, objId);
          }
          CalculatedResultTypeDto entity = new CalculatedResultTypeDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("calculationLibraries")) && (!obj.get("calculationLibraries").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.NumericResultTypeDto");
            entity.setCalculationLibraries(java_util_List.demarshall(obj.get("calculationLibraries"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("formula")) && (!obj.get("formula").isNull())) {
            entity.setFormula(java_lang_String.demarshall(obj.get("formula"), a1));
          }
          if ((obj.containsKey("validityRange")) && (!obj.get("validityRange").isNull())) {
            entity.setValidityRange(java_lang_Long.demarshall(obj.get("validityRange"), a1));
          }
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.demarshall(obj.get("unit"), a1));
          }
          if ((obj.containsKey("valueFormat")) && (!obj.get("valueFormat").isNull())) {
            entity.setValueFormat(ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto.demarshall(obj.get("valueFormat"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.CalculatedResultTypeDto", t);
        }
      }
      public String marshall(CalculatedResultTypeDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.CalculatedResultTypeDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(2048).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.CalculatedResultTypeDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"calculationLibraries\" : ").append(java_util_List.marshall(a0.getCalculationLibraries(), a1)).append(",").append("\"formula\" : ").append(java_lang_String.marshall(a0.getFormula(), a1)).append(",").append("\"validityRange\" : ").append(java_lang_Long.marshall(a0.getValidityRange(), a1)).append(",").append("\"unit\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.marshall(a0.getUnit(), a1)).append(",").append("\"valueFormat\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto.marshall(a0.getValueFormat(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.CalculatedResultTypeDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_CalculatedResultTypeDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_provider_BiometricTypeDto = new Marshaller<BiometricTypeDto>() {
      private BiometricTypeDto[] EMPTY_ARRAY = new BiometricTypeDto[0];
      public BiometricTypeDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return BiometricTypeDto.class;
      }
      public BiometricTypeDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(BiometricTypeDto.class, objId);
          }
          BiometricTypeDto entity = new BiometricTypeDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("measurandLibraryList")) && (!obj.get("measurandLibraryList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto");
            entity.setMeasurandLibraryList(java_util_List.demarshall(obj.get("measurandLibraryList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.provider.BiometricTypeDto", t);
        }
      }
      public String marshall(BiometricTypeDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.BiometricTypeDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(512).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.BiometricTypeDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"measurandLibraryList\" : ").append(java_util_List.marshall(a0.getMeasurandLibraryList(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.provider.BiometricTypeDto", ch_apkern_achilles_dto_shared_entity_laboratory_provider_BiometricTypeDto);
    ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_ResultTypeEnum = new Marshaller<ResultTypeEnum>() {
      private ResultTypeEnum[] EMPTY_ARRAY = new ResultTypeEnum[0];
      public ResultTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ResultTypeEnum.class;
      }
      public ResultTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          ResultTypeEnum entity = obj != null ? Enum.valueOf(ResultTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(ResultTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.ResultTypeEnum", t);
        }
      }
      public String marshall(ResultTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.ResultTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.ResultTypeEnum", ch_apkern_achilles_dto_shared_module_core_preferences_laboratory_library_ResultTypeEnum);
    ch_apkern_achilles_dto_shared_module_search_criteria_MeasurandLibrarySearchCriterionEnum = new Marshaller<MeasurandLibrarySearchCriterionEnum>() {
      private MeasurandLibrarySearchCriterionEnum[] EMPTY_ARRAY = new MeasurandLibrarySearchCriterionEnum[0];
      public MeasurandLibrarySearchCriterionEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasurandLibrarySearchCriterionEnum.class;
      }
      public MeasurandLibrarySearchCriterionEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          MeasurandLibrarySearchCriterionEnum entity = obj != null ? Enum.valueOf(MeasurandLibrarySearchCriterionEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(MeasurandLibrarySearchCriterionEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.search.criteria.MeasurandLibrarySearchCriterionEnum", t);
        }
      }
      public String marshall(MeasurandLibrarySearchCriterionEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.search.criteria.MeasurandLibrarySearchCriterionEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.search.criteria.MeasurandLibrarySearchCriterionEnum", ch_apkern_achilles_dto_shared_module_search_criteria_MeasurandLibrarySearchCriterionEnum);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_SelectionResultDto = new Marshaller<SelectionResultDto>() {
      private SelectionResultDto[] EMPTY_ARRAY = new SelectionResultDto[0];
      public SelectionResultDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SelectionResultDto.class;
      }
      public SelectionResultDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(SelectionResultDto.class, objId);
          }
          SelectionResultDto entity = new SelectionResultDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("selectionValue")) && (!obj.get("selectionValue").isNull())) {
            entity.setSelectionValue(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionValueDto.demarshall(obj.get("selectionValue"), a1));
          }
          if ((obj.containsKey("measuring")) && (!obj.get("measuring").isNull())) {
            entity.setMeasuring((MeasuringDto) java_lang_Object.demarshall(MeasuringDto.class, obj.get("measuring"), a1));
          }
          if ((obj.containsKey("measurandLibrary")) && (!obj.get("measurandLibrary").isNull())) {
            entity.setMeasurandLibrary((MeasurandLibraryDto) java_lang_Object.demarshall(MeasurandLibraryDto.class, obj.get("measurandLibrary"), a1));
          }
          if ((obj.containsKey("measurandReference")) && (!obj.get("measurandReference").isNull())) {
            entity.setMeasurandReference((MeasurandReferenceDto) java_lang_Object.demarshall(MeasurandReferenceDto.class, obj.get("measurandReference"), a1));
          }
          if ((obj.containsKey("chargeResult")) && (!obj.get("chargeResult").isNull())) {
            entity.setChargeResult(java_lang_Boolean.demarshall(obj.get("chargeResult"), a1));
          }
          if ((obj.containsKey("visible")) && (!obj.get("visible").isNull())) {
            entity.setVisible(java_lang_Boolean.demarshall(obj.get("visible"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.SelectionResultDto", t);
        }
      }
      public String marshall(SelectionResultDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.SelectionResultDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1792).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.SelectionResultDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"selectionValue\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionValueDto.marshall(a0.getSelectionValue(), a1)).append(",").append("\"measuring\" : ").append(java_lang_Object.marshall(a0.getMeasuring(), a1)).append(",").append("\"measurandLibrary\" : ").append(java_lang_Object.marshall(a0.getMeasurandLibrary(), a1)).append(",").append("\"measurandReference\" : ").append(java_lang_Object.marshall(a0.getMeasurandReference(), a1)).append(",").append("\"chargeResult\" : ").append(java_lang_Boolean.marshall(a0.getChargeResult(), a1)).append(",").append("\"visible\" : ").append(java_lang_Boolean.marshall(a0.getVisible(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.SelectionResultDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_SelectionResultDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ManufacturerResultReferenceDto = new Marshaller<ManufacturerResultReferenceDto>() {
      private ManufacturerResultReferenceDto[] EMPTY_ARRAY = new ManufacturerResultReferenceDto[0];
      public ManufacturerResultReferenceDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ManufacturerResultReferenceDto.class;
      }
      public ManufacturerResultReferenceDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ManufacturerResultReferenceDto.class, objId);
          }
          ManufacturerResultReferenceDto entity = new ManufacturerResultReferenceDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("nominalValue")) && (!obj.get("nominalValue").isNull())) {
            entity.setNominalValue(java_math_BigDecimal.demarshall(obj.get("nominalValue"), a1));
          }
          if ((obj.containsKey("tolerance")) && (!obj.get("tolerance").isNull())) {
            entity.setTolerance(java_math_BigDecimal.demarshall(obj.get("tolerance"), a1));
          }
          if ((obj.containsKey("referenceSolutionLot")) && (!obj.get("referenceSolutionLot").isNull())) {
            entity.setReferenceSolutionLot(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ReferenceSolutionLotDto.demarshall(obj.get("referenceSolutionLot"), a1));
          }
          if ((obj.containsKey("measurandLibrary")) && (!obj.get("measurandLibrary").isNull())) {
            entity.setMeasurandLibrary((MeasurandLibraryDto) java_lang_Object.demarshall(MeasurandLibraryDto.class, obj.get("measurandLibrary"), a1));
          }
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.demarshall(obj.get("unit"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ManufacturerResultReferenceDto", t);
        }
      }
      public String marshall(ManufacturerResultReferenceDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ManufacturerResultReferenceDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(2816).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ManufacturerResultReferenceDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"nominalValue\" : ").append(java_math_BigDecimal.marshall(a0.getNominalValue(), a1)).append(",").append("\"tolerance\" : ").append(java_math_BigDecimal.marshall(a0.getTolerance(), a1)).append(",").append("\"referenceSolutionLot\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ReferenceSolutionLotDto.marshall(a0.getReferenceSolutionLot(), a1)).append(",").append("\"measurandLibrary\" : ").append(java_lang_Object.marshall(a0.getMeasurandLibrary(), a1)).append(",").append("\"unit\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.marshall(a0.getUnit(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ManufacturerResultReferenceDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ManufacturerResultReferenceDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryOverrideDto = new Marshaller<LibraryOverrideDto>() {
      private LibraryOverrideDto[] EMPTY_ARRAY = new LibraryOverrideDto[0];
      public LibraryOverrideDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LibraryOverrideDto.class;
      }
      public LibraryOverrideDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LibraryOverrideDto.class, objId);
          }
          LibraryOverrideDto entity = new LibraryOverrideDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("measurandLibrary")) && (!obj.get("measurandLibrary").isNull())) {
            entity.setMeasurandLibrary((MeasurandLibraryDto) java_lang_Object.demarshall(MeasurandLibraryDto.class, obj.get("measurandLibrary"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryOverrideDto", t);
        }
      }
      public String marshall(LibraryOverrideDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryOverrideDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryOverrideDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"measurandLibrary\" : ").append(java_lang_Object.marshall(a0.getMeasurandLibrary(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.LibraryOverrideDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryOverrideDto);
    ch_apkern_achilles_dto_shared_module_laboratory_library_LibraryDtoList = new Marshaller<LibraryDtoList>() {
      private LibraryDtoList[] EMPTY_ARRAY = new LibraryDtoList[0];
      public LibraryDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LibraryDtoList.class;
      }
      public LibraryDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LibraryDtoList.class, objId);
          }
          LibraryDtoList entity = new LibraryDtoList();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("libraries")) && (!obj.get("libraries").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.MeasurandLibraryDto");
            entity.setLibraries(java_util_List.demarshall(obj.get("libraries"), a1));
            a1.setAssumedElementType(null);
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDtoList", t);
        }
      }
      public String marshall(LibraryDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"libraries\" : ").append(java_util_List.marshall(a0.getLibraries(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDtoList", ch_apkern_achilles_dto_shared_module_laboratory_library_LibraryDtoList);
    ch_apkern_achilles_dto_shared_entity_patient_PersonReferenceDto = new Marshaller<PersonReferenceDto>() {
      private PersonReferenceDto[] EMPTY_ARRAY = new PersonReferenceDto[0];
      public PersonReferenceDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PersonReferenceDto.class;
      }
      public PersonReferenceDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(PersonReferenceDto.class, objId);
          }
          PersonReferenceDto entity = new PersonReferenceDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("patient")) && (!obj.get("patient").isNull())) {
            entity.setPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("patient"), a1));
          }
          if ((obj.containsKey("person")) && (!obj.get("person").isNull())) {
            entity.setPerson((PersonDto) java_lang_Object.demarshall(PersonDto.class, obj.get("person"), a1));
          }
          if ((obj.containsKey("type")) && (!obj.get("type").isNull())) {
            entity.setType(ch_apkern_achilles_dto_shared_entity_patient_PersonReferenceGroupItemDto.demarshall(obj.get("type"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceDto", t);
        }
      }
      public String marshall(PersonReferenceDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(4992).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"patient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getPatient(), a1)).append(",").append("\"person\" : ").append(java_lang_Object.marshall(a0.getPerson(), a1)).append(",").append("\"type\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PersonReferenceGroupItemDto.marshall(a0.getType(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.patient.PersonReferenceDto", ch_apkern_achilles_dto_shared_entity_patient_PersonReferenceDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_DeviceQualityMeasuringDto = new Marshaller<DeviceQualityMeasuringDto>() {
      private DeviceQualityMeasuringDto[] EMPTY_ARRAY = new DeviceQualityMeasuringDto[0];
      public DeviceQualityMeasuringDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return DeviceQualityMeasuringDto.class;
      }
      public DeviceQualityMeasuringDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(DeviceQualityMeasuringDto.class, objId);
          }
          DeviceQualityMeasuringDto entity = new DeviceQualityMeasuringDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("referenceSolutionLot")) && (!obj.get("referenceSolutionLot").isNull())) {
            entity.setReferenceSolutionLot(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ReferenceSolutionLotDto.demarshall(obj.get("referenceSolutionLot"), a1));
          }
          if ((obj.containsKey("deviceProvider")) && (!obj.get("deviceProvider").isNull())) {
            entity.setDeviceProvider((DeviceProviderDto) java_lang_Object.demarshall(DeviceProviderDto.class, obj.get("deviceProvider"), a1));
          }
          if ((obj.containsKey("analysisDate")) && (!obj.get("analysisDate").isNull())) {
            entity.setAnalysisDate(java_util_Date.demarshall(obj.get("analysisDate"), a1));
          }
          if ((obj.containsKey("newEntry")) && (!obj.get("newEntry").isNull())) {
            entity.setNewEntry(java_lang_Boolean.demarshall(obj.get("newEntry"), a1));
          }
          if ((obj.containsKey("receiveDate")) && (!obj.get("receiveDate").isNull())) {
            entity.setReceiveDate(java_util_Date.demarshall(obj.get("receiveDate"), a1));
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("authorized")) && (!obj.get("authorized").isNull())) {
            entity.setAuthorized(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("authorized"), a1));
          }
          if ((obj.containsKey("patient")) && (!obj.get("patient").isNull())) {
            entity.setPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("patient"), a1));
          }
          if ((obj.containsKey("patientIdentification")) && (!obj.get("patientIdentification").isNull())) {
            entity.setPatientIdentification(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.demarshall(obj.get("patientIdentification"), a1));
          }
          if ((obj.containsKey("mandator")) && (!obj.get("mandator").isNull())) {
            entity.setMandator(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.demarshall(obj.get("mandator"), a1));
          }
          if ((obj.containsKey("measuringDate")) && (!obj.get("measuringDate").isNull())) {
            entity.setMeasuringDate(java_util_Date.demarshall(obj.get("measuringDate"), a1));
          }
          if ((obj.containsKey("treatment")) && (!obj.get("treatment").isNull())) {
            entity.setTreatment(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.demarshall(obj.get("treatment"), a1));
          }
          if ((obj.containsKey("manual")) && (!obj.get("manual").isNull())) {
            entity.setManual(java_lang_Boolean.demarshall(obj.get("manual"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.DeviceQualityMeasuringDto", t);
        }
      }
      public String marshall(DeviceQualityMeasuringDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.DeviceQualityMeasuringDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(9984).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.DeviceQualityMeasuringDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"referenceSolutionLot\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_ReferenceSolutionLotDto.marshall(a0.getReferenceSolutionLot(), a1)).append(",").append("\"deviceProvider\" : ").append(java_lang_Object.marshall(a0.getDeviceProvider(), a1)).append(",").append("\"analysisDate\" : ").append(java_util_Date.marshall(a0.getAnalysisDate(), a1)).append(",").append("\"newEntry\" : ").append(java_lang_Boolean.marshall(a0.getNewEntry(), a1)).append(",").append("\"receiveDate\" : ").append(java_util_Date.marshall(a0.getReceiveDate(), a1)).append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"authorized\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getAuthorized(), a1)).append(",").append("\"patient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getPatient(), a1)).append(",").append("\"patientIdentification\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.marshall(a0.getPatientIdentification(), a1)).append(",").append("\"mandator\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.marshall(a0.getMandator(), a1)).append(",").append("\"measuringDate\" : ").append(java_util_Date.marshall(a0.getMeasuringDate(), a1)).append(",").append("\"treatment\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.marshall(a0.getTreatment(), a1)).append(",").append("\"manual\" : ").append(java_lang_Boolean.marshall(a0.getManual(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.DeviceQualityMeasuringDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_quality_DeviceQualityMeasuringDto);
    ch_apkern_achilles_model_shared_entity_core_GroupTypeEnum = new Marshaller<GroupTypeEnum>() {
      private GroupTypeEnum[] EMPTY_ARRAY = new GroupTypeEnum[0];
      public GroupTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return GroupTypeEnum.class;
      }
      public GroupTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          GroupTypeEnum entity = obj != null ? Enum.valueOf(GroupTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(GroupTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.model.shared.entity.core.GroupTypeEnum", t);
        }
      }
      public String marshall(GroupTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.GroupTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.model.shared.entity.core.GroupTypeEnum", ch_apkern_achilles_model_shared_entity_core_GroupTypeEnum);
    ch_apkern_achilles_concurrency_client_internal_transfer_LockEventTransfer$EventCase = new Marshaller<EventCase>() {
      private EventCase[] EMPTY_ARRAY = new EventCase[0];
      public EventCase[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return EventCase.class;
      }
      public EventCase demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          EventCase entity = obj != null ? Enum.valueOf(EventCase.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(EventCase.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer$EventCase", t);
        }
      }
      public String marshall(EventCase a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer$EventCase\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer$EventCase", ch_apkern_achilles_concurrency_client_internal_transfer_LockEventTransfer$EventCase);
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.LockEventTransfer.EventCase", ch_apkern_achilles_concurrency_client_internal_transfer_LockEventTransfer$EventCase);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_InternalLaboratoryMeasuringDto = new Marshaller<InternalLaboratoryMeasuringDto>() {
      private InternalLaboratoryMeasuringDto[] EMPTY_ARRAY = new InternalLaboratoryMeasuringDto[0];
      public InternalLaboratoryMeasuringDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return InternalLaboratoryMeasuringDto.class;
      }
      public InternalLaboratoryMeasuringDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(InternalLaboratoryMeasuringDto.class, objId);
          }
          InternalLaboratoryMeasuringDto entity = new InternalLaboratoryMeasuringDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("deviceProvider")) && (!obj.get("deviceProvider").isNull())) {
            entity.setDeviceProvider((DeviceProviderDto) java_lang_Object.demarshall(DeviceProviderDto.class, obj.get("deviceProvider"), a1));
          }
          if ((obj.containsKey("analysisDate")) && (!obj.get("analysisDate").isNull())) {
            entity.setAnalysisDate(java_util_Date.demarshall(obj.get("analysisDate"), a1));
          }
          if ((obj.containsKey("newEntry")) && (!obj.get("newEntry").isNull())) {
            entity.setNewEntry(java_lang_Boolean.demarshall(obj.get("newEntry"), a1));
          }
          if ((obj.containsKey("receiveDate")) && (!obj.get("receiveDate").isNull())) {
            entity.setReceiveDate(java_util_Date.demarshall(obj.get("receiveDate"), a1));
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("authorized")) && (!obj.get("authorized").isNull())) {
            entity.setAuthorized(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("authorized"), a1));
          }
          if ((obj.containsKey("patient")) && (!obj.get("patient").isNull())) {
            entity.setPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("patient"), a1));
          }
          if ((obj.containsKey("patientIdentification")) && (!obj.get("patientIdentification").isNull())) {
            entity.setPatientIdentification(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.demarshall(obj.get("patientIdentification"), a1));
          }
          if ((obj.containsKey("mandator")) && (!obj.get("mandator").isNull())) {
            entity.setMandator(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.demarshall(obj.get("mandator"), a1));
          }
          if ((obj.containsKey("measuringDate")) && (!obj.get("measuringDate").isNull())) {
            entity.setMeasuringDate(java_util_Date.demarshall(obj.get("measuringDate"), a1));
          }
          if ((obj.containsKey("treatment")) && (!obj.get("treatment").isNull())) {
            entity.setTreatment(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.demarshall(obj.get("treatment"), a1));
          }
          if ((obj.containsKey("manual")) && (!obj.get("manual").isNull())) {
            entity.setManual(java_lang_Boolean.demarshall(obj.get("manual"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.InternalLaboratoryMeasuringDto", t);
        }
      }
      public String marshall(InternalLaboratoryMeasuringDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.InternalLaboratoryMeasuringDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(8832).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.InternalLaboratoryMeasuringDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"deviceProvider\" : ").append(java_lang_Object.marshall(a0.getDeviceProvider(), a1)).append(",").append("\"analysisDate\" : ").append(java_util_Date.marshall(a0.getAnalysisDate(), a1)).append(",").append("\"newEntry\" : ").append(java_lang_Boolean.marshall(a0.getNewEntry(), a1)).append(",").append("\"receiveDate\" : ").append(java_util_Date.marshall(a0.getReceiveDate(), a1)).append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"authorized\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getAuthorized(), a1)).append(",").append("\"patient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getPatient(), a1)).append(",").append("\"patientIdentification\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_PatientIdentificationDto.marshall(a0.getPatientIdentification(), a1)).append(",").append("\"mandator\" : ").append(ch_apkern_achilles_dto_shared_entity_core_MandatorDto.marshall(a0.getMandator(), a1)).append(",").append("\"measuringDate\" : ").append(java_util_Date.marshall(a0.getMeasuringDate(), a1)).append(",").append("\"treatment\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_TreatmentDto.marshall(a0.getTreatment(), a1)).append(",").append("\"manual\" : ").append(java_lang_Boolean.marshall(a0.getManual(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.InternalLaboratoryMeasuringDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_InternalLaboratoryMeasuringDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_MeasurandGroupReferenceDto = new Marshaller<MeasurandGroupReferenceDto>() {
      private MeasurandGroupReferenceDto[] EMPTY_ARRAY = new MeasurandGroupReferenceDto[0];
      public MeasurandGroupReferenceDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasurandGroupReferenceDto.class;
      }
      public MeasurandGroupReferenceDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasurandGroupReferenceDto.class, objId);
          }
          MeasurandGroupReferenceDto entity = new MeasurandGroupReferenceDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("measurandGroup")) && (!obj.get("measurandGroup").isNull())) {
            entity.setMeasurandGroup((MeasurandGroupDto) java_lang_Object.demarshall(MeasurandGroupDto.class, obj.get("measurandGroup"), a1));
          }
          if ((obj.containsKey("age")) && (!obj.get("age").isNull())) {
            entity.setAge(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_AgeDto.demarshall(obj.get("age"), a1));
          }
          if ((obj.containsKey("sex")) && (!obj.get("sex").isNull())) {
            entity.setSex(obj.get("sex").isObject() != null ? Enum.valueOf(SexEnum.class, obj.get("sex").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("sex").isString() != null ? Enum.valueOf(SexEnum.class, obj.get("sex").isString().stringValue()) : null);
          }
          if ((obj.containsKey("selectionInToleranceList")) && (!obj.get("selectionInToleranceList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto");
            entity.setSelectionInToleranceList(java_util_List.demarshall(obj.get("selectionInToleranceList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("lowerBound")) && (!obj.get("lowerBound").isNull())) {
            entity.setLowerBound(java_math_BigDecimal.demarshall(obj.get("lowerBound"), a1));
          }
          if ((obj.containsKey("upperBound")) && (!obj.get("upperBound").isNull())) {
            entity.setUpperBound(java_math_BigDecimal.demarshall(obj.get("upperBound"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandGroupReferenceDto", t);
        }
      }
      public String marshall(MeasurandGroupReferenceDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandGroupReferenceDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1408).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandGroupReferenceDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"measurandGroup\" : ").append(java_lang_Object.marshall(a0.getMeasurandGroup(), a1)).append(",").append("\"age\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_AgeDto.marshall(a0.getAge(), a1)).append(",").append("\"sex\" : ").append(a0.getSex() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.SexEnum\",\"^EnumStringValue\":\"").append(a0.getSex().name()).append("\"}") : "null").append(",").append("\"selectionInToleranceList\" : ").append(java_util_List.marshall(a0.getSelectionInToleranceList(), a1)).append(",").append("\"lowerBound\" : ").append(java_math_BigDecimal.marshall(a0.getLowerBound(), a1)).append(",").append("\"upperBound\" : ").append(java_math_BigDecimal.marshall(a0.getUpperBound(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandGroupReferenceDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_MeasurandGroupReferenceDto);
    ch_apkern_achilles_model_shared_entity_core_ParameterSetTypeEnum = new Marshaller<ParameterSetTypeEnum>() {
      private ParameterSetTypeEnum[] EMPTY_ARRAY = new ParameterSetTypeEnum[0];
      public ParameterSetTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ParameterSetTypeEnum.class;
      }
      public ParameterSetTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          ParameterSetTypeEnum entity = obj != null ? Enum.valueOf(ParameterSetTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(ParameterSetTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.model.shared.entity.core.ParameterSetTypeEnum", t);
        }
      }
      public String marshall(ParameterSetTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.ParameterSetTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.model.shared.entity.core.ParameterSetTypeEnum", ch_apkern_achilles_model_shared_entity_core_ParameterSetTypeEnum);
    ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryDeviceQualityMeasuring2Dto = new Marshaller<LaboratoryDeviceQualityMeasuring2Dto>() {
      private LaboratoryDeviceQualityMeasuring2Dto[] EMPTY_ARRAY = new LaboratoryDeviceQualityMeasuring2Dto[0];
      public LaboratoryDeviceQualityMeasuring2Dto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LaboratoryDeviceQualityMeasuring2Dto.class;
      }
      public LaboratoryDeviceQualityMeasuring2Dto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LaboratoryDeviceQualityMeasuring2Dto.class, objId);
          }
          LaboratoryDeviceQualityMeasuring2Dto entity = new LaboratoryDeviceQualityMeasuring2Dto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          if ((obj.containsKey("analysisDate")) && (!obj.get("analysisDate").isNull())) {
            entity.setAnalysisDate(java_util_Date.demarshall(obj.get("analysisDate"), a1));
          }
          if ((obj.containsKey("controller")) && (!obj.get("controller").isNull())) {
            entity.setController(java_lang_String.demarshall(obj.get("controller"), a1));
          }
          if ((obj.containsKey("deviationQualab")) && (!obj.get("deviationQualab").isNull())) {
            entity.setDeviationQualab(java_lang_Integer.demarshall(obj.get("deviationQualab"), a1));
          }
          if ((obj.containsKey("deviationManufacturer")) && (!obj.get("deviationManufacturer").isNull())) {
            entity.setDeviationManufacturer(java_lang_Integer.demarshall(obj.get("deviationManufacturer"), a1));
          }
          if ((obj.containsKey("deviation20Points")) && (!obj.get("deviation20Points").isNull())) {
            entity.setDeviation20Points(java_lang_Integer.demarshall(obj.get("deviation20Points"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuring2Dto", t);
        }
      }
      public String marshall(LaboratoryDeviceQualityMeasuring2Dto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuring2Dto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(896).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuring2Dto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append(",").append("\"analysisDate\" : ").append(java_util_Date.marshall(a0.getAnalysisDate(), a1)).append(",").append("\"controller\" : ").append(java_lang_String.marshall(a0.getController(), a1)).append(",").append("\"deviationQualab\" : ").append(java_lang_Integer.marshall(a0.getDeviationQualab(), a1)).append(",").append("\"deviationManufacturer\" : ").append(java_lang_Integer.marshall(a0.getDeviationManufacturer(), a1)).append(",").append("\"deviation20Points\" : ").append(java_lang_Integer.marshall(a0.getDeviation20Points(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuring2Dto", ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryDeviceQualityMeasuring2Dto);
    ch_apkern_achilles_dto_shared_module_laboratory_library_LibraryDto = new Marshaller<LibraryDto>() {
      private LibraryDto[] EMPTY_ARRAY = new LibraryDto[0];
      public LibraryDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LibraryDto.class;
      }
      public LibraryDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LibraryDto.class, objId);
          }
          LibraryDto entity = new LibraryDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("division")) && (!obj.get("division").isNull())) {
            entity.setDivision(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.demarshall(obj.get("division"), a1));
          }
          if ((obj.containsKey("measuringMethod")) && (!obj.get("measuringMethod").isNull())) {
            entity.setMeasuringMethod(ch_apkern_achilles_dto_shared_entity_core_GroupItemDto.demarshall(obj.get("measuringMethod"), a1));
          }
          if ((obj.containsKey("substance")) && (!obj.get("substance").isNull())) {
            entity.setSubstance(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SubstanceDto.demarshall(obj.get("substance"), a1));
          }
          if ((obj.containsKey("unit")) && (!obj.get("unit").isNull())) {
            entity.setUnit(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.demarshall(obj.get("unit"), a1));
          }
          if ((obj.containsKey("formula")) && (!obj.get("formula").isNull())) {
            entity.setFormula(java_lang_String.demarshall(obj.get("formula"), a1));
          }
          if ((obj.containsKey("diagram")) && (!obj.get("diagram").isNull())) {
            entity.setDiagram(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.demarshall(obj.get("diagram"), a1));
          }
          if ((obj.containsKey("type")) && (!obj.get("type").isNull())) {
            entity.setType(obj.get("type").isObject() != null ? Enum.valueOf(LibraryTypeEnum.class, obj.get("type").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("type").isString() != null ? Enum.valueOf(LibraryTypeEnum.class, obj.get("type").isString().stringValue()) : null);
          }
          if ((obj.containsKey("libraryClass")) && (!obj.get("libraryClass").isNull())) {
            entity.setLibraryClass(obj.get("libraryClass").isObject() != null ? Enum.valueOf(ResultTypeEnum.class, obj.get("libraryClass").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("libraryClass").isString() != null ? Enum.valueOf(ResultTypeEnum.class, obj.get("libraryClass").isString().stringValue()) : null);
          }
          if ((obj.containsKey("controlled")) && (!obj.get("controlled").isNull())) {
            entity.setControlled(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("controlled"), a1));
          }
          if ((obj.containsKey("modificated")) && (!obj.get("modificated").isNull())) {
            entity.setModificated(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.demarshall(obj.get("modificated"), a1));
          }
          if ((obj.containsKey("selection")) && (!obj.get("selection").isNull())) {
            entity.setSelection(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto.demarshall(obj.get("selection"), a1));
          }
          if ((obj.containsKey("valueFormat")) && (!obj.get("valueFormat").isNull())) {
            entity.setValueFormat(ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto.demarshall(obj.get("valueFormat"), a1));
          }
          if ((obj.containsKey("remark")) && (!obj.get("remark").isNull())) {
            entity.setRemark(java_lang_String.demarshall(obj.get("remark"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDto", t);
        }
      }
      public String marshall(LibraryDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(6528).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"division\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_LibraryDivisionDto.marshall(a0.getDivision(), a1)).append(",").append("\"measuringMethod\" : ").append(ch_apkern_achilles_dto_shared_entity_core_GroupItemDto.marshall(a0.getMeasuringMethod(), a1)).append(",").append("\"substance\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SubstanceDto.marshall(a0.getSubstance(), a1)).append(",").append("\"unit\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_UnitDto.marshall(a0.getUnit(), a1)).append(",").append("\"formula\" : ").append(java_lang_String.marshall(a0.getFormula(), a1)).append(",").append("\"diagram\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_DiagramDto.marshall(a0.getDiagram(), a1)).append(",").append("\"type\" : ").append(a0.getType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.LibraryTypeEnum\",\"^EnumStringValue\":\"").append(a0.getType().name()).append("\"}") : "null").append(",").append("\"libraryClass\" : ").append(a0.getLibraryClass() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.core.preferences.laboratory.library.ResultTypeEnum\",\"^EnumStringValue\":\"").append(a0.getLibraryClass().name()).append("\"}") : "null").append(",").append("\"controlled\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getControlled(), a1)).append(",").append("\"modificated\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ModificationDto.marshall(a0.getModificated(), a1)).append(",").append("\"selection\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto.marshall(a0.getSelection(), a1)).append(",").append("\"valueFormat\" : ").append(ch_apkern_achilles_dto_shared_entity_core_ValueFormatDto.marshall(a0.getValueFormat(), a1)).append(",").append("\"remark\" : ").append(java_lang_String.marshall(a0.getRemark(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.library.LibraryDto", ch_apkern_achilles_dto_shared_module_laboratory_library_LibraryDto);
    java_lang_ClassCastException = new Marshaller<ClassCastException>() {
      private ClassCastException[] EMPTY_ARRAY = new ClassCastException[0];
      public ClassCastException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ClassCastException.class;
      }
      public ClassCastException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ClassCastException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          ClassCastException entity = new ClassCastException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.ClassCastException", t);
        }
      }
      public String marshall(ClassCastException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.ClassCastException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.ClassCastException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.ClassCastException", java_lang_ClassCastException);
    ch_apkern_achilles_model_shared_entity_core_LanguageEnum = new Marshaller<LanguageEnum>() {
      private LanguageEnum[] EMPTY_ARRAY = new LanguageEnum[0];
      public LanguageEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LanguageEnum.class;
      }
      public LanguageEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          LanguageEnum entity = obj != null ? Enum.valueOf(LanguageEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(LanguageEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.model.shared.entity.core.LanguageEnum", t);
        }
      }
      public String marshall(LanguageEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.LanguageEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.model.shared.entity.core.LanguageEnum", ch_apkern_achilles_model_shared_entity_core_LanguageEnum);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionResultTypeDto = new Marshaller<SelectionResultTypeDto>() {
      private SelectionResultTypeDto[] EMPTY_ARRAY = new SelectionResultTypeDto[0];
      public SelectionResultTypeDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return SelectionResultTypeDto.class;
      }
      public SelectionResultTypeDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(SelectionResultTypeDto.class, objId);
          }
          SelectionResultTypeDto entity = new SelectionResultTypeDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("selection")) && (!obj.get("selection").isNull())) {
            entity.setSelection(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto.demarshall(obj.get("selection"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionResultTypeDto", t);
        }
      }
      public String marshall(SelectionResultTypeDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionResultTypeDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(640).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionResultTypeDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"selection\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionDto.marshall(a0.getSelection(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionResultTypeDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_SelectionResultTypeDto);
    java_lang_IndexOutOfBoundsException = new Marshaller<IndexOutOfBoundsException>() {
      private IndexOutOfBoundsException[] EMPTY_ARRAY = new IndexOutOfBoundsException[0];
      public IndexOutOfBoundsException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return IndexOutOfBoundsException.class;
      }
      public IndexOutOfBoundsException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(IndexOutOfBoundsException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          IndexOutOfBoundsException entity = new IndexOutOfBoundsException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.IndexOutOfBoundsException", t);
        }
      }
      public String marshall(IndexOutOfBoundsException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.IndexOutOfBoundsException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.IndexOutOfBoundsException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.IndexOutOfBoundsException", java_lang_IndexOutOfBoundsException);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_TextResultDto = new Marshaller<TextResultDto>() {
      private TextResultDto[] EMPTY_ARRAY = new TextResultDto[0];
      public TextResultDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return TextResultDto.class;
      }
      public TextResultDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(TextResultDto.class, objId);
          }
          TextResultDto entity = new TextResultDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("text")) && (!obj.get("text").isNull())) {
            entity.setText(java_lang_String.demarshall(obj.get("text"), a1));
          }
          if ((obj.containsKey("measuring")) && (!obj.get("measuring").isNull())) {
            entity.setMeasuring((MeasuringDto) java_lang_Object.demarshall(MeasuringDto.class, obj.get("measuring"), a1));
          }
          if ((obj.containsKey("measurandLibrary")) && (!obj.get("measurandLibrary").isNull())) {
            entity.setMeasurandLibrary((MeasurandLibraryDto) java_lang_Object.demarshall(MeasurandLibraryDto.class, obj.get("measurandLibrary"), a1));
          }
          if ((obj.containsKey("measurandReference")) && (!obj.get("measurandReference").isNull())) {
            entity.setMeasurandReference((MeasurandReferenceDto) java_lang_Object.demarshall(MeasurandReferenceDto.class, obj.get("measurandReference"), a1));
          }
          if ((obj.containsKey("chargeResult")) && (!obj.get("chargeResult").isNull())) {
            entity.setChargeResult(java_lang_Boolean.demarshall(obj.get("chargeResult"), a1));
          }
          if ((obj.containsKey("visible")) && (!obj.get("visible").isNull())) {
            entity.setVisible(java_lang_Boolean.demarshall(obj.get("visible"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.TextResultDto", t);
        }
      }
      public String marshall(TextResultDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.TextResultDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1024).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.TextResultDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"text\" : ").append(java_lang_String.marshall(a0.getText(), a1)).append(",").append("\"measuring\" : ").append(java_lang_Object.marshall(a0.getMeasuring(), a1)).append(",").append("\"measurandLibrary\" : ").append(java_lang_Object.marshall(a0.getMeasurandLibrary(), a1)).append(",").append("\"measurandReference\" : ").append(java_lang_Object.marshall(a0.getMeasurandReference(), a1)).append(",").append("\"chargeResult\" : ").append(java_lang_Boolean.marshall(a0.getChargeResult(), a1)).append(",").append("\"visible\" : ").append(java_lang_Boolean.marshall(a0.getVisible(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.TextResultDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_TextResultDto);
    ch_apkern_achilles_dto_shared_module_laboratory_library_LibrarySearchDto = new Marshaller<LibrarySearchDto>() {
      private LibrarySearchDto[] EMPTY_ARRAY = new LibrarySearchDto[0];
      public LibrarySearchDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LibrarySearchDto.class;
      }
      public LibrarySearchDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LibrarySearchDto.class, objId);
          }
          LibrarySearchDto entity = new LibrarySearchDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("valid")) && (!obj.get("valid").isNull())) {
            entity.setValid(java_lang_Boolean.demarshall(obj.get("valid"), a1));
          }
          if ((obj.containsKey("libraryCode")) && (!obj.get("libraryCode").isNull())) {
            entity.setLibraryCode(java_lang_String.demarshall(obj.get("libraryCode"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.library.LibrarySearchDto", t);
        }
      }
      public String marshall(LibrarySearchDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.LibrarySearchDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.LibrarySearchDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"valid\" : ").append(java_lang_Boolean.marshall(a0.getValid(), a1)).append(",").append("\"libraryCode\" : ").append(java_lang_String.marshall(a0.getLibraryCode(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.library.LibrarySearchDto", ch_apkern_achilles_dto_shared_module_laboratory_library_LibrarySearchDto);
    ch_apkern_achilles_api_client_exception_ServerException = new Marshaller<ServerException>() {
      private ServerException[] EMPTY_ARRAY = new ServerException[0];
      public ServerException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ServerException.class;
      }
      public ServerException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ServerException.class, objId);
          }
          ServerException entity = new ServerException();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("exceptionType")) && (!obj.get("exceptionType").isNull())) {
            entity.setExceptionType(obj.get("exceptionType").isObject() != null ? Enum.valueOf(ExceptionTypeEnum.class, obj.get("exceptionType").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("exceptionType").isString() != null ? Enum.valueOf(ExceptionTypeEnum.class, obj.get("exceptionType").isString().stringValue()) : null);
          }
          if ((obj.containsKey("throwable")) && (!obj.get("throwable").isNull())) {
            entity.setThrowable(java_lang_Throwable.demarshall(obj.get("throwable"), a1));
          }
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.api.client.exception.ServerException", t);
        }
      }
      public String marshall(ServerException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.api.client.exception.ServerException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(4224).append("{\"^EncodedType\":\"ch.apkern.achilles.api.client.exception.ServerException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"exceptionType\" : ").append(a0.getExceptionType() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum\",\"^EnumStringValue\":\"").append(a0.getExceptionType().name()).append("\"}") : "null").append(",").append("\"throwable\" : ").append(java_lang_Throwable.marshall(a0.getThrowable(), a1)).append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.api.client.exception.ServerException", ch_apkern_achilles_api_client_exception_ServerException);
    java_util_ConcurrentModificationException = new Marshaller<ConcurrentModificationException>() {
      private ConcurrentModificationException[] EMPTY_ARRAY = new ConcurrentModificationException[0];
      public ConcurrentModificationException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ConcurrentModificationException.class;
      }
      public ConcurrentModificationException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ConcurrentModificationException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          ConcurrentModificationException entity = new ConcurrentModificationException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.util.ConcurrentModificationException", t);
        }
      }
      public String marshall(ConcurrentModificationException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.util.ConcurrentModificationException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.util.ConcurrentModificationException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.util.ConcurrentModificationException", java_util_ConcurrentModificationException);
    ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_TariffDto = new Marshaller<TariffDto>() {
      private TariffDto[] EMPTY_ARRAY = new TariffDto[0];
      public TariffDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return TariffDto.class;
      }
      public TariffDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(TariffDto.class, objId);
          }
          TariffDto entity = new TariffDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("code")) && (!obj.get("code").isNull())) {
            entity.setCode(java_lang_String.demarshall(obj.get("code"), a1));
          }
          if ((obj.containsKey("analysisLibrary")) && (!obj.get("analysisLibrary").isNull())) {
            entity.setAnalysisLibrary(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_AnalysisLibraryDto.demarshall(obj.get("analysisLibrary"), a1));
          }
          if ((obj.containsKey("validFrom")) && (!obj.get("validFrom").isNull())) {
            entity.setValidFrom(java_util_Date.demarshall(obj.get("validFrom"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TariffDto", t);
        }
      }
      public String marshall(TariffDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TariffDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(4992).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TariffDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"code\" : ").append(java_lang_String.marshall(a0.getCode(), a1)).append(",").append("\"analysisLibrary\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_AnalysisLibraryDto.marshall(a0.getAnalysisLibrary(), a1)).append(",").append("\"validFrom\" : ").append(java_util_Date.marshall(a0.getValidFrom(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.TariffDto", ch_apkern_achilles_dto_shared_entity_laboratory_masterdata_TariffDto);
    ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_MeasurandLibraryReferenceDto = new Marshaller<MeasurandLibraryReferenceDto>() {
      private MeasurandLibraryReferenceDto[] EMPTY_ARRAY = new MeasurandLibraryReferenceDto[0];
      public MeasurandLibraryReferenceDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasurandLibraryReferenceDto.class;
      }
      public MeasurandLibraryReferenceDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasurandLibraryReferenceDto.class, objId);
          }
          MeasurandLibraryReferenceDto entity = new MeasurandLibraryReferenceDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("measurandLibrary")) && (!obj.get("measurandLibrary").isNull())) {
            entity.setMeasurandLibrary((MeasurandLibraryDto) java_lang_Object.demarshall(MeasurandLibraryDto.class, obj.get("measurandLibrary"), a1));
          }
          if ((obj.containsKey("age")) && (!obj.get("age").isNull())) {
            entity.setAge(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_AgeDto.demarshall(obj.get("age"), a1));
          }
          if ((obj.containsKey("sex")) && (!obj.get("sex").isNull())) {
            entity.setSex(obj.get("sex").isObject() != null ? Enum.valueOf(SexEnum.class, obj.get("sex").isObject().get("^EnumStringValue").isString().stringValue()) : obj.get("sex").isString() != null ? Enum.valueOf(SexEnum.class, obj.get("sex").isString().stringValue()) : null);
          }
          if ((obj.containsKey("selectionInToleranceList")) && (!obj.get("selectionInToleranceList").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.masterdata.SelectionValueDto");
            entity.setSelectionInToleranceList(java_util_List.demarshall(obj.get("selectionInToleranceList"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("lowerBound")) && (!obj.get("lowerBound").isNull())) {
            entity.setLowerBound(java_math_BigDecimal.demarshall(obj.get("lowerBound"), a1));
          }
          if ((obj.containsKey("upperBound")) && (!obj.get("upperBound").isNull())) {
            entity.setUpperBound(java_math_BigDecimal.demarshall(obj.get("upperBound"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandLibraryReferenceDto", t);
        }
      }
      public String marshall(MeasurandLibraryReferenceDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandLibraryReferenceDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1408).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandLibraryReferenceDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"measurandLibrary\" : ").append(java_lang_Object.marshall(a0.getMeasurandLibrary(), a1)).append(",").append("\"age\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_AgeDto.marshall(a0.getAge(), a1)).append(",").append("\"sex\" : ").append(a0.getSex() != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.model.shared.entity.core.SexEnum\",\"^EnumStringValue\":\"").append(a0.getSex().name()).append("\"}") : "null").append(",").append("\"selectionInToleranceList\" : ").append(java_util_List.marshall(a0.getSelectionInToleranceList(), a1)).append(",").append("\"lowerBound\" : ").append(java_math_BigDecimal.marshall(a0.getLowerBound(), a1)).append(",").append("\"upperBound\" : ").append(java_math_BigDecimal.marshall(a0.getUpperBound(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.result.reference.MeasurandLibraryReferenceDto", ch_apkern_achilles_dto_shared_entity_laboratory_measuring_result_reference_MeasurandLibraryReferenceDto);
    ch_apkern_achilles_api_shared_validation_ExceptionTypeEnum = new Marshaller<ExceptionTypeEnum>() {
      private ExceptionTypeEnum[] EMPTY_ARRAY = new ExceptionTypeEnum[0];
      public ExceptionTypeEnum[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ExceptionTypeEnum.class;
      }
      public ExceptionTypeEnum demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          ExceptionTypeEnum entity = obj != null ? Enum.valueOf(ExceptionTypeEnum.class, obj.get("^EnumStringValue").isString().stringValue()) : a0.isString() != null ? Enum.valueOf(ExceptionTypeEnum.class, a0.isString().stringValue()) : null;
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum", t);
        }
      }
      public String marshall(ExceptionTypeEnum a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        return new StringBuilder(256).append(a0 != null ? new StringBuilder(64).append("{\"^EncodedType\":\"ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum\",\"^EnumStringValue\":\"").append(a0.name()).append("\"}") : "null").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.api.shared.validation.ExceptionTypeEnum", ch_apkern_achilles_api_shared_validation_ExceptionTypeEnum);
    ch_apkern_achilles_dto_shared_module_laboratory_MeasuringDisplayDtoList = new Marshaller<MeasuringDisplayDtoList>() {
      private MeasuringDisplayDtoList[] EMPTY_ARRAY = new MeasuringDisplayDtoList[0];
      public MeasuringDisplayDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return MeasuringDisplayDtoList.class;
      }
      public MeasuringDisplayDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(MeasuringDisplayDtoList.class, objId);
          }
          final SimpleDateFilterCriteriaDto c0 = ch_apkern_achilles_dto_shared_module_laboratory_SimpleDateFilterCriteriaDto.demarshall(obj.get("simpleDateFilterCriteriaDto"), a1);
          final MeasuringDtoList c1 = ch_apkern_achilles_dto_shared_module_laboratory_MeasuringDtoList.demarshall(obj.get("measuringDtoList"), a1);
          final ValueLibraryDtoList c2 = ch_apkern_achilles_dto_shared_module_laboratory_library_ValueLibraryDtoList.demarshall(obj.get("valueLibraryDtoList"), a1);
          MeasuringDisplayDtoList entity = new MeasuringDisplayDtoList(c0, c1, c2);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDisplayDtoList", t);
        }
      }
      public String marshall(MeasuringDisplayDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDisplayDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1152).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDisplayDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"simpleDateFilterCriteriaDto\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_SimpleDateFilterCriteriaDto.marshall(a0.getSimpleDateFilterCriteriaDto(), a1)).append(",").append("\"measuringDtoList\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_MeasuringDtoList.marshall(a0.getMeasuringDtoList(), a1)).append(",").append("\"valueLibraryDtoList\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_library_ValueLibraryDtoList.marshall(a0.getValueLibraryDtoList(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.MeasuringDisplayDtoList", ch_apkern_achilles_dto_shared_module_laboratory_MeasuringDisplayDtoList);
    ch_apkern_achilles_dto_shared_module_patient_PatientPersonDto = new Marshaller<PatientPersonDto>() {
      private PatientPersonDto[] EMPTY_ARRAY = new PatientPersonDto[0];
      public PatientPersonDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return PatientPersonDto.class;
      }
      public PatientPersonDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(PatientPersonDto.class, objId);
          }
          PatientPersonDto entity = new PatientPersonDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("patient")) && (!obj.get("patient").isNull())) {
            entity.setPatient(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.demarshall(obj.get("patient"), a1));
          }
          if ((obj.containsKey("person")) && (!obj.get("person").isNull())) {
            entity.setPerson((PersonDto) java_lang_Object.demarshall(PersonDto.class, obj.get("person"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.patient.PatientPersonDto", t);
        }
      }
      public String marshall(PatientPersonDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.patient.PatientPersonDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(4608).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.patient.PatientPersonDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"patient\" : ").append(ch_apkern_achilles_dto_shared_entity_patient_PatientDto.marshall(a0.getPatient(), a1)).append(",").append("\"person\" : ").append(java_lang_Object.marshall(a0.getPerson(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.patient.PatientPersonDto", ch_apkern_achilles_dto_shared_module_patient_PatientPersonDto);
    ch_apkern_achilles_dto_shared_module_laboratory_quality_ReferenceSolutionLotDtoList = new Marshaller<ReferenceSolutionLotDtoList>() {
      private ReferenceSolutionLotDtoList[] EMPTY_ARRAY = new ReferenceSolutionLotDtoList[0];
      public ReferenceSolutionLotDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ReferenceSolutionLotDtoList.class;
      }
      public ReferenceSolutionLotDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ReferenceSolutionLotDtoList.class, objId);
          }
          a1.setAssumedElementType("ch.apkern.achilles.dto.shared.entity.laboratory.measuring.quality.ReferenceSolutionLotDto");
          final List<ReferenceSolutionLotDto> c0 = java_util_List.demarshall(obj.get("solutions"), a1);
          a1.setAssumedElementType(null);
          ReferenceSolutionLotDtoList entity = new ReferenceSolutionLotDtoList(c0);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.quality.ReferenceSolutionLotDtoList", t);
        }
      }
      public String marshall(ReferenceSolutionLotDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.ReferenceSolutionLotDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.ReferenceSolutionLotDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"solutions\" : ").append(java_util_List.marshall(a0.getSolutions(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.quality.ReferenceSolutionLotDtoList", ch_apkern_achilles_dto_shared_module_laboratory_quality_ReferenceSolutionLotDtoList);
    ch_apkern_achilles_dto_shared_entity_laboratory_provider_ManualDeviceProviderDto = new Marshaller<ManualDeviceProviderDto>() {
      private ManualDeviceProviderDto[] EMPTY_ARRAY = new ManualDeviceProviderDto[0];
      public ManualDeviceProviderDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ManualDeviceProviderDto.class;
      }
      public ManualDeviceProviderDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ManualDeviceProviderDto.class, objId);
          }
          ManualDeviceProviderDto entity = new ManualDeviceProviderDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("deviceType")) && (!obj.get("deviceType").isNull())) {
            entity.setDeviceType(ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceTypeDto.demarshall(obj.get("deviceType"), a1));
          }
          if ((obj.containsKey("serialNumber")) && (!obj.get("serialNumber").isNull())) {
            entity.setSerialNumber(java_lang_String.demarshall(obj.get("serialNumber"), a1));
          }
          if ((obj.containsKey("name")) && (!obj.get("name").isNull())) {
            entity.setName(java_lang_String.demarshall(obj.get("name"), a1));
          }
          if ((obj.containsKey("active")) && (!obj.get("active").isNull())) {
            entity.setActive(java_lang_Boolean.demarshall(obj.get("active"), a1));
          }
          if ((obj.containsKey("id")) && (!obj.get("id").isNull())) {
            entity.setId(java_lang_String.demarshall(obj.get("id"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.entity.laboratory.provider.ManualDeviceProviderDto", t);
        }
      }
      public String marshall(ManualDeviceProviderDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.ManualDeviceProviderDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1152).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.entity.laboratory.provider.ManualDeviceProviderDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"deviceType\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_provider_DeviceTypeDto.marshall(a0.getDeviceType(), a1)).append(",").append("\"serialNumber\" : ").append(java_lang_String.marshall(a0.getSerialNumber(), a1)).append(",").append("\"name\" : ").append(java_lang_String.marshall(a0.getName(), a1)).append(",").append("\"active\" : ").append(java_lang_Boolean.marshall(a0.getActive(), a1)).append(",").append("\"id\" : ").append(java_lang_String.marshall(a0.getId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.entity.laboratory.provider.ManualDeviceProviderDto", ch_apkern_achilles_dto_shared_entity_laboratory_provider_ManualDeviceProviderDto);
    ch_apkern_achilles_dto_shared_module_laboratory_library_ValueLibraryDtoList = new Marshaller<ValueLibraryDtoList>() {
      private ValueLibraryDtoList[] EMPTY_ARRAY = new ValueLibraryDtoList[0];
      public ValueLibraryDtoList[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ValueLibraryDtoList.class;
      }
      public ValueLibraryDtoList demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ValueLibraryDtoList.class, objId);
          }
          a1.setAssumedElementType("ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDto");
          final List<ValueLibraryDto> c0 = java_util_List.demarshall(obj.get("valueLibraryList"), a1);
          a1.setAssumedElementType(null);
          ValueLibraryDtoList entity = new ValueLibraryDtoList(c0);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDtoList", t);
        }
      }
      public String marshall(ValueLibraryDtoList a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDtoList\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(256).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDtoList\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"valueLibraryList\" : ").append(java_util_List.marshall(a0.getValueLibraryList(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.library.ValueLibraryDtoList", ch_apkern_achilles_dto_shared_module_laboratory_library_ValueLibraryDtoList);
    ch_apkern_achilles_concurrency_client_internal_transfer_LockBroadcastEventTransfer$LockBroadcastEventEntry = new Marshaller<LockBroadcastEventEntry>() {
      private LockBroadcastEventEntry[] EMPTY_ARRAY = new LockBroadcastEventEntry[0];
      public LockBroadcastEventEntry[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LockBroadcastEventEntry.class;
      }
      public LockBroadcastEventEntry demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LockBroadcastEventEntry.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("fieldId"), a1);
          final String c1 = java_lang_String.demarshall(obj.get("entityId"), a1);
          LockBroadcastEventEntry entity = new LockBroadcastEventEntry(c0, c1);
          a1.recordObject(objId, entity);
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer$LockBroadcastEventEntry", t);
        }
      }
      public String marshall(LockBroadcastEventEntry a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer$LockBroadcastEventEntry\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(384).append("{\"^EncodedType\":\"ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer$LockBroadcastEventEntry\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"entityId\" : ").append(java_lang_String.marshall(a0.getEntityId(), a1)).append(",").append("\"fieldId\" : ").append(java_lang_String.marshall(a0.getFieldId(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer$LockBroadcastEventEntry", ch_apkern_achilles_concurrency_client_internal_transfer_LockBroadcastEventTransfer$LockBroadcastEventEntry);
    marshallers.put("ch.apkern.achilles.concurrency.client.internal.transfer.LockBroadcastEventTransfer.LockBroadcastEventEntry", ch_apkern_achilles_concurrency_client_internal_transfer_LockBroadcastEventTransfer$LockBroadcastEventEntry);
    java_lang_ArithmeticException = new Marshaller<ArithmeticException>() {
      private ArithmeticException[] EMPTY_ARRAY = new ArithmeticException[0];
      public ArithmeticException[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return ArithmeticException.class;
      }
      public ArithmeticException demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(ArithmeticException.class, objId);
          }
          final String c0 = java_lang_String.demarshall(obj.get("message"), a1);
          ArithmeticException entity = new ArithmeticException(c0);
          a1.recordObject(objId, entity);
          if ((obj.containsKey("cause")) && (!obj.get("cause").isNull())) {
            entity.initCause(java_lang_Throwable.demarshall(obj.get("cause"), a1));
          }
          if ((obj.containsKey("stackTrace")) && (!obj.get("stackTrace").isNull())) {
            entity.setStackTrace((StackTraceElement[]) arrayOf_java_lang_StackTraceElement_D1.demarshall(obj.get("stackTrace"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: java.lang.ArithmeticException", t);
        }
      }
      public String marshall(ArithmeticException a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"java.lang.ArithmeticException\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(3968).append("{\"^EncodedType\":\"java.lang.ArithmeticException\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"stackTrace\" : ").append(arrayOf_java_lang_StackTraceElement_D1.marshall(a0.getStackTrace(), a1)).append(",").append("\"message\" : ").append(java_lang_String.marshall(a0.getMessage(), a1)).append(",").append("\"cause\" : ").append(java_lang_Throwable.marshall(a0.getCause(), a1)).append("}").toString();
      }
    };
    marshallers.put("java.lang.ArithmeticException", java_lang_ArithmeticException);
    ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryMeasuringDisplayDto = new Marshaller<LaboratoryMeasuringDisplayDto>() {
      private LaboratoryMeasuringDisplayDto[] EMPTY_ARRAY = new LaboratoryMeasuringDisplayDto[0];
      public LaboratoryMeasuringDisplayDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return LaboratoryMeasuringDisplayDto.class;
      }
      public LaboratoryMeasuringDisplayDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(LaboratoryMeasuringDisplayDto.class, objId);
          }
          LaboratoryMeasuringDisplayDto entity = new LaboratoryMeasuringDisplayDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("measuringDtoList")) && (!obj.get("measuringDtoList").isNull())) {
            entity.setMeasuringDtoList(ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryDeviceQualityMeasuringDtoList.demarshall(obj.get("measuringDtoList"), a1));
          }
          if ((obj.containsKey("measuringDtoList2")) && (!obj.get("measuringDtoList2").isNull())) {
            a1.setAssumedElementType("ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryDeviceQualityMeasuring2Dto");
            entity.setMeasuringDtoList2(java_util_List.demarshall(obj.get("measuringDtoList2"), a1));
            a1.setAssumedElementType(null);
          }
          if ((obj.containsKey("dateFilter")) && (!obj.get("dateFilter").isNull())) {
            entity.setDateFilter(ch_apkern_achilles_dto_shared_module_laboratory_SimpleDateFilterCriteriaDto.demarshall(obj.get("dateFilter"), a1));
          }
          if ((obj.containsKey("statisticalValuesDtoMap")) && (!obj.get("statisticalValuesDtoMap").isNull())) {
            a1.setAssumedMapKeyType("java.lang.String");
            a1.setAssumedMapValueType("ch.apkern.achilles.dto.shared.module.laboratory.quality.MeasuringStatisticalValuesDto");
            entity.setStatisticalValuesDtoMap((Map) java_util_Map.demarshall(obj.get("statisticalValuesDtoMap"), a1));
            a1.setAssumedMapKeyType(null);
            a1.setAssumedMapValueType(null);
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryMeasuringDisplayDto", t);
        }
      }
      public String marshall(LaboratoryMeasuringDisplayDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryMeasuringDisplayDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1152).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryMeasuringDisplayDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"measuringDtoList\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryDeviceQualityMeasuringDtoList.marshall(a0.getMeasuringDtoList(), a1)).append(",").append("\"measuringDtoList2\" : ").append(java_util_List.marshall(a0.getMeasuringDtoList2(), a1)).append(",").append("\"dateFilter\" : ").append(ch_apkern_achilles_dto_shared_module_laboratory_SimpleDateFilterCriteriaDto.marshall(a0.getDateFilter(), a1)).append(",").append("\"statisticalValuesDtoMap\" : ").append(java_util_Map.marshall(a0.getStatisticalValuesDtoMap(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.quality.LaboratoryMeasuringDisplayDto", ch_apkern_achilles_dto_shared_module_laboratory_quality_LaboratoryMeasuringDisplayDto);
    ch_apkern_achilles_dto_shared_module_laboratory_devices_instruments_DevicesInstrumentsDto = new Marshaller<DevicesInstrumentsDto>() {
      private DevicesInstrumentsDto[] EMPTY_ARRAY = new DevicesInstrumentsDto[0];
      public DevicesInstrumentsDto[] getEmptyArray() {
        return EMPTY_ARRAY;
      }
      public Class getTypeHandled() {
        return DevicesInstrumentsDto.class;
      }
      public DevicesInstrumentsDto demarshall(EJValue a0, MarshallingSession a1) {
        try {
          if (a0.isNull()) {
            return null;
          }
          EJObject obj = a0.isObject();
          String objId = obj.get("^ObjectID").isString().stringValue();
          if (a1.hasObject(objId)) {
            return a1.getObject(DevicesInstrumentsDto.class, objId);
          }
          DevicesInstrumentsDto entity = new DevicesInstrumentsDto();
          a1.recordObject(objId, entity);
          if ((obj.containsKey("deviceProviderDto")) && (!obj.get("deviceProviderDto").isNull())) {
            entity.setDeviceProviderDto(ch_apkern_achilles_dto_shared_entity_laboratory_provider_ManualDeviceProviderDto.demarshall(obj.get("deviceProviderDto"), a1));
          }
          if ((obj.containsKey("editable")) && (!obj.get("editable").isNull())) {
            entity.setEditable(java_lang_Boolean.demarshall(obj.get("editable"), a1));
          }
          return entity;
        } catch (Throwable t) {
          t.printStackTrace();
          throw new RuntimeException("error demarshalling entity: ch.apkern.achilles.dto.shared.module.laboratory.devices.instruments.DevicesInstrumentsDto", t);
        }
      }
      public String marshall(DevicesInstrumentsDto a0, MarshallingSession a1) {
        if (a0 == null) {
          return "null";
        }
        if (a1.hasObject(a0)) {
          String objId = a1.getObject(a0);
          return new StringBuilder(128).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.devices.instruments.DevicesInstrumentsDto\"").append(",").append("\"^ObjectID\":\"").append(objId).append("\"}").toString();
        }
        String objId = a1.getObject(a0);
        a1.recordObject(objId, objId);
        return new StringBuilder(1408).append("{\"^EncodedType\":\"ch.apkern.achilles.dto.shared.module.laboratory.devices.instruments.DevicesInstrumentsDto\",\"^ObjectID\":\"").append(objId).append("\"").append(",").append("\"deviceProviderDto\" : ").append(ch_apkern_achilles_dto_shared_entity_laboratory_provider_ManualDeviceProviderDto.marshall(a0.getDeviceProviderDto(), a1)).append(",").append("\"editable\" : ").append(java_lang_Boolean.marshall(a0.getEditable(), a1)).append("}").toString();
      }
    };
    marshallers.put("ch.apkern.achilles.dto.shared.module.laboratory.devices.instruments.DevicesInstrumentsDto", ch_apkern_achilles_dto_shared_module_laboratory_devices_instruments_DevicesInstrumentsDto);
    arrayOf_java_lang_Object_D1 = new QualifyingMarshallerWrapper(new Marshaller<Object[]>() {
      public java.lang.Object[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private Object[] _demarshall1(EJArray a0, MarshallingSession a1) {
        Object[] newArray = new Object[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Object.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(Object[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return Object.class;
      }
      public Object[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(Object[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.Object;", arrayOf_java_lang_Object_D1);
    arrayOf_java_lang_String_D1 = new QualifyingMarshallerWrapper(new Marshaller<String[]>() {
      public java.lang.String[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private String[] _demarshall1(EJArray a0, MarshallingSession a1) {
        String[] newArray = new String[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_String.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(String[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return String.class;
      }
      public String[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(String[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.String;", arrayOf_java_lang_String_D1);
    arrayOf_int_D1 = new QualifyingMarshallerWrapper(new Marshaller<int[]>() {
      public int[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private int[] _demarshall1(EJArray a0, MarshallingSession a1) {
        int[] newArray = new int[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Integer.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(int[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return int.class;
      }
      public int[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(int[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[I", arrayOf_int_D1);
    arrayOf_long_D1 = new QualifyingMarshallerWrapper(new Marshaller<long[]>() {
      public long[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private long[] _demarshall1(EJArray a0, MarshallingSession a1) {
        long[] newArray = new long[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Long.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(long[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return long.class;
      }
      public long[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(long[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[J", arrayOf_long_D1);
    arrayOf_double_D1 = new QualifyingMarshallerWrapper(new Marshaller<double[]>() {
      public double[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private double[] _demarshall1(EJArray a0, MarshallingSession a1) {
        double[] newArray = new double[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Double.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(double[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return double.class;
      }
      public double[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(double[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[D", arrayOf_double_D1);
    arrayOf_float_D1 = new QualifyingMarshallerWrapper(new Marshaller<float[]>() {
      public float[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private float[] _demarshall1(EJArray a0, MarshallingSession a1) {
        float[] newArray = new float[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Float.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(float[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return float.class;
      }
      public float[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(float[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[F", arrayOf_float_D1);
    arrayOf_short_D1 = new QualifyingMarshallerWrapper(new Marshaller<short[]>() {
      public short[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private short[] _demarshall1(EJArray a0, MarshallingSession a1) {
        short[] newArray = new short[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Short.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(short[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return short.class;
      }
      public short[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(short[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[S", arrayOf_short_D1);
    arrayOf_boolean_D1 = new QualifyingMarshallerWrapper(new Marshaller<boolean[]>() {
      public boolean[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private boolean[] _demarshall1(EJArray a0, MarshallingSession a1) {
        boolean[] newArray = new boolean[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Boolean.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(boolean[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return boolean.class;
      }
      public boolean[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(boolean[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Z", arrayOf_boolean_D1);
    arrayOf_byte_D1 = new QualifyingMarshallerWrapper(new Marshaller<byte[]>() {
      public byte[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private byte[] _demarshall1(EJArray a0, MarshallingSession a1) {
        byte[] newArray = new byte[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Byte.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(byte[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return byte.class;
      }
      public byte[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(byte[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[B", arrayOf_byte_D1);
    arrayOf_char_D1 = new QualifyingMarshallerWrapper(new Marshaller<char[]>() {
      public char[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private char[] _demarshall1(EJArray a0, MarshallingSession a1) {
        char[] newArray = new char[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Character.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(char[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return char.class;
      }
      public char[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(char[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[C", arrayOf_char_D1);
    arrayOf_java_lang_Integer_D1 = new QualifyingMarshallerWrapper(new Marshaller<Integer[]>() {
      public java.lang.Integer[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private Integer[] _demarshall1(EJArray a0, MarshallingSession a1) {
        Integer[] newArray = new Integer[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Integer.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(Integer[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return Integer.class;
      }
      public Integer[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(Integer[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.Integer;", arrayOf_java_lang_Integer_D1);
    arrayOf_java_lang_Long_D1 = new QualifyingMarshallerWrapper(new Marshaller<Long[]>() {
      public java.lang.Long[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private Long[] _demarshall1(EJArray a0, MarshallingSession a1) {
        Long[] newArray = new Long[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Long.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(Long[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return Long.class;
      }
      public Long[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(Long[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.Long;", arrayOf_java_lang_Long_D1);
    arrayOf_java_lang_Double_D1 = new QualifyingMarshallerWrapper(new Marshaller<Double[]>() {
      public java.lang.Double[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private Double[] _demarshall1(EJArray a0, MarshallingSession a1) {
        Double[] newArray = new Double[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Double.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(Double[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return Double.class;
      }
      public Double[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(Double[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.Double;", arrayOf_java_lang_Double_D1);
    arrayOf_java_lang_Float_D1 = new QualifyingMarshallerWrapper(new Marshaller<Float[]>() {
      public java.lang.Float[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private Float[] _demarshall1(EJArray a0, MarshallingSession a1) {
        Float[] newArray = new Float[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Float.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(Float[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return Float.class;
      }
      public Float[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(Float[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.Float;", arrayOf_java_lang_Float_D1);
    arrayOf_java_lang_Short_D1 = new QualifyingMarshallerWrapper(new Marshaller<Short[]>() {
      public java.lang.Short[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private Short[] _demarshall1(EJArray a0, MarshallingSession a1) {
        Short[] newArray = new Short[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Short.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(Short[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return Short.class;
      }
      public Short[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(Short[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.Short;", arrayOf_java_lang_Short_D1);
    arrayOf_java_lang_Boolean_D1 = new QualifyingMarshallerWrapper(new Marshaller<Boolean[]>() {
      public java.lang.Boolean[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private Boolean[] _demarshall1(EJArray a0, MarshallingSession a1) {
        Boolean[] newArray = new Boolean[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Boolean.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(Boolean[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return Boolean.class;
      }
      public Boolean[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(Boolean[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.Boolean;", arrayOf_java_lang_Boolean_D1);
    arrayOf_java_lang_Byte_D1 = new QualifyingMarshallerWrapper(new Marshaller<Byte[]>() {
      public java.lang.Byte[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private Byte[] _demarshall1(EJArray a0, MarshallingSession a1) {
        Byte[] newArray = new Byte[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Byte.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(Byte[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return Byte.class;
      }
      public Byte[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(Byte[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.Byte;", arrayOf_java_lang_Byte_D1);
    arrayOf_java_lang_Character_D1 = new QualifyingMarshallerWrapper(new Marshaller<Character[]>() {
      public java.lang.Character[][] getEmptyArray() {
        throw new UnsupportedOperationException("Not implemented!");
      }

      private Character[] _demarshall1(EJArray a0, MarshallingSession a1) {
        Character[] newArray = new Character[a0.size()];
        for (int i = 0; i < newArray.length; i++) {
          newArray[i] = java_lang_Character.demarshall(a0.get(i), a1);
        }
        return newArray;
      }

      private String _marshall1(Character[] a0, MarshallingSession a1) {
        StringBuilder sb = new StringBuilder("[");
        for (int i = 0; i < a0.length; i++) {
          if (i > 0) {
            sb.append(",");
          }
          sb.append(java_lang_Object.marshall(a0[i], a1));
        }
        return sb.append("]").toString();
      }
      public Class getTypeHandled() {
        return Character.class;
      }
      public Character[] demarshall(EJValue a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._demarshall1(a0.isArray(), a1);
        }
      }
      public String marshall(Character[] a0, MarshallingSession a1) {
        if (a0 == null) {
          return null;
        } else {
          return this._marshall1(a0, a1);
        }
      }
    });
    marshallers.put("[Ljava.lang.Character;", arrayOf_java_lang_Character_D1);
  }

  private native static String _1626942963_fieldname(ValidationResult instance) /*-{
    return instance.@ch.apkern.achilles.api.shared.validation.ValidationResult::fieldname;
  }-*/;

  private native static void _1626942963_fieldname(ValidationResult instance, String value) /*-{
    instance.@ch.apkern.achilles.api.shared.validation.ValidationResult::fieldname = value;
  }-*/;

  private native static List _1034140142_list(UserManagementDto instance) /*-{
    return instance.@ch.apkern.achilles.dto.shared.module.core.preferences.user.UserManagementDto::list;
  }-*/;

  private native static void _1034140142_list(UserManagementDto instance, List value) /*-{
    instance.@ch.apkern.achilles.dto.shared.module.core.preferences.user.UserManagementDto::list = value;
  }-*/;

  private native static ClientInstanceId _$411629081_clientInstanceId(SingleFieldEventInformation instance) /*-{
    return instance.@ch.apkern.achilles.concurrency.client.internal.transfer.SingleFieldEventInformation::clientInstanceId;
  }-*/;

  private native static void _$411629081_clientInstanceId(SingleFieldEventInformation instance, ClientInstanceId value) /*-{
    instance.@ch.apkern.achilles.concurrency.client.internal.transfer.SingleFieldEventInformation::clientInstanceId = value;
  }-*/;

  private native static String _$411629081_fieldId(SingleFieldEventInformation instance) /*-{
    return instance.@ch.apkern.achilles.concurrency.client.internal.transfer.SingleFieldEventInformation::fieldId;
  }-*/;

  private native static void _$411629081_fieldId(SingleFieldEventInformation instance, String value) /*-{
    instance.@ch.apkern.achilles.concurrency.client.internal.transfer.SingleFieldEventInformation::fieldId = value;
  }-*/;

  private native static String _$411629081_entityId(SingleFieldEventInformation instance) /*-{
    return instance.@ch.apkern.achilles.concurrency.client.internal.transfer.SingleFieldEventInformation::entityId;
  }-*/;

  private native static void _$411629081_entityId(SingleFieldEventInformation instance, String value) /*-{
    instance.@ch.apkern.achilles.concurrency.client.internal.transfer.SingleFieldEventInformation::entityId = value;
  }-*/;

  public Marshaller getMarshaller(String a0, String a1) {
    return marshallers.get(a1);
  }
}